@@ -1,5 +1,5 @@
 /*
- * $Id: JXCollapsiblePane.java,v 1.25 2008/04/07 02:35:47 kschaefe Exp $
+ * $Id: JXCollapsiblePane.java,v 1.28 2008/10/14 22:32:50 rah003 Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -157,26 +157,6 @@ import javax.swing.border.Border;
  * @author Karl George Schaefer
  */
 public class JXCollapsiblePane extends JXPanel {
-    /**
-     * The orientation defines in which direction the collapsible pane will
-     * expand.
-     * 
-     * @deprecated use {@link Direction}
-     */
-    @Deprecated
-    public enum Orientation {
-        /**
-         * The horizontal orientation makes the collapsible pane
-         * expand horizontally
-         */
-        HORIZONTAL,
-        /**
-         * The horizontal orientation makes the collapsible pane
-         * expand vertically
-         */
-        VERTICAL
-    }
-
     /**
      * The direction defines how the collapsible pane will collapse. The
      * constant names were designed by choosing a fixed point and then
@@ -223,17 +203,17 @@ public class JXCollapsiblePane extends JXPanel {
     }
     
     /**
-	 * Used when generating PropertyChangeEvents for the "animationState"
-	 * property. The PropertyChangeEvent will takes the following different
-	 * values for {@link PropertyChangeEvent#getNewValue()}:
-	 * <ul>
-	 * <li><code>reinit</code> every time the animation starts
-	 * <li><code>expanded</code> when the animation ends and the pane is
-	 * expanded
-	 * <li><code>collapsed</code> when the animation ends and the pane is
-	 * collapsed
-	 * </ul>
-	 */
+     * Used when generating PropertyChangeEvents for the "animationState"
+     * property. The PropertyChangeEvent will takes the following different
+     * values for {@link PropertyChangeEvent#getNewValue()}:
+     * <ul>
+     * <li><code>reinit</code> every time the animation starts
+     * <li><code>expanded</code> when the animation ends and the pane is
+     * expanded
+     * <li><code>collapsed</code> when the animation ends and the pane is
+     * collapsed
+     * </ul>
+     */
     public final static String ANIMATION_STATE_KEY = "animationState";
 
     /**
@@ -283,17 +263,6 @@ public class JXCollapsiblePane extends JXPanel {
     public JXCollapsiblePane() {
         this(Direction.UP, new BorderLayout(0, 0));
     }
-
-    /**
-     * Constructs a new JXCollapsiblePane with a {@link JXPanel} as content pane
-     * and the specified orientation.
-     * 
-     * @deprecated use {@link #JXCollapsiblePane(Direction)}
-     */
-    @Deprecated
-    public JXCollapsiblePane(Orientation orientation) {
-        this(orientation, new BorderLayout(0, 0));
-    }
     
     /**
      * Constructs a new JXCollapsiblePane with a {@link JXPanel} as content pane and the specified
@@ -313,50 +282,20 @@ public class JXCollapsiblePane extends JXPanel {
     public JXCollapsiblePane(LayoutManager layout) {
         this(Direction.UP, layout);
     }
-
+    
     /**
      * Constructs a new JXCollapsiblePane with a {@link JPanel} as content pane
-     * and the given LayoutManager and orientation. A vertical orientation enables
-     * a vertical {@link VerticalLayout} with a gap of 2 pixels as layout
-     * manager. A horizontal orientation enables a horizontal
+     * and the given LayoutManager and orientation. A vertical orientation
+     * enables a vertical {@link VerticalLayout} with a gap of 2 pixels as
+     * layout manager. A horizontal orientation enables a horizontal
      * {@link HorizontalLayout} with a gap of 2 pixels as layout manager
      * 
-     * @deprecated use {@link #JXCollapsiblePane(Direction, LayoutManager)}
+     * @param direction
+     *            the direction this pane collapses
+     * @param layout
+     *            of this collapsible pane
      */
-    @Deprecated
-    public JXCollapsiblePane(Orientation orientation, LayoutManager layout) {
-    	this(getDirection(orientation), layout);
-    }
-    	
-    /**
-	 * @deprecated only used to convent orientation to direction, remove with
-	 *             orientation
-	 */
-    @Deprecated
-    private static Direction getDirection(Orientation orientation) {
-    	switch (orientation) {
-		case HORIZONTAL:
-			return Direction.DOWN;
-		case VERTICAL:
-			return Direction.UP;
-		default:
-			throw new IllegalStateException();
-		}
-    }
-    
-	/**
-	 * Constructs a new JXCollapsiblePane with a {@link JPanel} as content pane
-	 * and the given LayoutManager and orientation. A vertical orientation
-	 * enables a vertical {@link VerticalLayout} with a gap of 2 pixels as
-	 * layout manager. A horizontal orientation enables a horizontal
-	 * {@link HorizontalLayout} with a gap of 2 pixels as layout manager
-	 * 
-	 * @param direction
-	 *            the direction this pane collapses
-	 * @param layout
-	 *            of this collapsible pane
-	 */
-	public JXCollapsiblePane(Direction direction, LayoutManager layout) {
+    public JXCollapsiblePane(Direction direction, LayoutManager layout) {
         super.setLayout(layout);
 
         this.direction = direction;
@@ -529,36 +468,6 @@ public class JXCollapsiblePane extends JXPanel {
     public boolean isAnimated() {
         return useAnimation;
     }
-
-    /**
-     * Changes the orientation of this collapsible pane. Doing so changes the
-     * layout of the underlying content pane. If the chosen orientation is
-     * vertical, a vertical layout with a gap of 2 pixels is chosen. Otherwise,
-     * a horizontal layout with a gap of 2 pixels is chosen.
-     *
-     * @see #getOrientation()
-     * @param orientation the new {@link Orientation} for this collapsible pane
-     * @throws IllegalStateException when this method is called while a
-     *                               collapsing/restore operation is running
-     * @deprecated
-     * @javabean.property
-     *    bound="true"
-     *    preferred="true"
-     */
-    @Deprecated
-    public void setOrientation(Orientation orientation) {
-    	setDirection(getDirection(orientation));
-    }
-    
-    /**
-     * @see #setOrientation(Orientation)
-     * @return the current {@link Orientation}
-     * @deprecated
-     */
-    @Deprecated
-    public Orientation getOrientation() {
-        return direction.isVertical() ? Orientation.VERTICAL : Orientation.HORIZONTAL;
-    }
     
     /**
      * Changes the direction of this collapsible pane. Doing so changes the
@@ -575,25 +484,20 @@ public class JXCollapsiblePane extends JXPanel {
      *    preferred="true"
      */
     public void setDirection(Direction direction) {
-    	if (animateTimer.isRunning()) {
-    		throw new IllegalStateException("cannot be change direction while collapsing.");
-    	}
-    	
-    	Direction oldValue = getDirection();
-    	this.direction = direction;
-    	
-    	if (direction.isVertical()) {
-    		getContentPane().setLayout(new VerticalLayout(2));
-    	} else {
-    		getContentPane().setLayout(new HorizontalLayout(2));
-    	}
-    	
-    	firePropertyChange("direction", oldValue, getDirection());
-    	firePropertyChange("orientation",
-				oldValue.isVertical() ? Orientation.VERTICAL
-						: Orientation.HORIZONTAL,
-				getDirection().isVertical() ? Orientation.VERTICAL
-						: Orientation.HORIZONTAL);
+        if (animateTimer.isRunning()) {
+            throw new IllegalStateException("cannot be change direction while collapsing.");
+        }
+        
+        Direction oldValue = getDirection();
+        this.direction = direction;
+        
+        if (direction.isVertical()) {
+            getContentPane().setLayout(new VerticalLayout(2));
+        } else {
+            getContentPane().setLayout(new HorizontalLayout(2));
+        }
+        
+        firePropertyChange("direction", oldValue, getDirection());
     }
     
     /**
@@ -601,7 +505,7 @@ public class JXCollapsiblePane extends JXPanel {
      * @return the current {@link Orientation}
      */
     public Direction getDirection() {
-    	return direction;
+        return direction;
     }
     
     /**
@@ -887,9 +791,9 @@ public class JXCollapsiblePane extends JXPanel {
                     wrapper.setBounds(bounds);
                     
                     if (direction == Direction.DOWN) {
-                    	wrapper.setViewPosition(new Point(0, wrapper.getView().getPreferredSize().height - newDimension));
+                        wrapper.setViewPosition(new Point(0, wrapper.getView().getPreferredSize().height - newDimension));
                     } else {
-                    	wrapper.setViewPosition(new Point(0, newDimension));
+                        wrapper.setViewPosition(new Point(0, newDimension));
                     }
                     
                     bounds = getBounds();
@@ -901,9 +805,9 @@ public class JXCollapsiblePane extends JXPanel {
                     wrapper.setBounds(bounds);
                     
                     if (direction == Direction.RIGHT) {
-                    	wrapper.setViewPosition(new Point(wrapper.getView().getPreferredSize().width - newDimension, 0));
+                        wrapper.setViewPosition(new Point(wrapper.getView().getPreferredSize().width - newDimension, 0));
                     } else {
-                    	wrapper.setViewPosition(new Point(newDimension, 0));
+                        wrapper.setViewPosition(new Point(newDimension, 0));
                     }
                     
                     bounds = getBounds();
