@@ -1,5 +1,5 @@
 /*
- * $Id: JXDatePicker.java,v 1.87 2008/04/01 12:21:29 kleopatra Exp $
+ * $Id: JXDatePicker.java,v 1.91 2008/09/17 16:22:37 kleopatra Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -147,6 +147,8 @@ public class JXDatePicker extends JComponent {
 
     public static final String EDITOR = "editor";
     public static final String MONTH_VIEW = "monthView";
+    /** @deprecated pre-0.9.4 no longer used - all "millis" are replaced by date */ 
+    @Deprecated
     public static final String DATE_IN_MILLIS = "dateInMillis";
     public static final String LINK_PANEL = "linkPanel";
 
@@ -175,7 +177,6 @@ public class JXDatePicker extends JComponent {
     private Date linkDate;
     
     private JXMonthView _monthView;
-    private String _actionCommand = "selectionChanged";
     private boolean editable = true;
     private EventListenerMap listenerMap;
     protected boolean lightWeightPopupEnabled = JPopupMenu.getDefaultLightWeightPopupEnabled();
@@ -559,7 +560,7 @@ public class JXDatePicker extends JComponent {
      * a new one with the requested date and format.
      * 
      * 
-     * @param linkDay         Date in milliseconds
+     * @param linkDay     the Date to set on the LinkPanel 
      * @param linkFormatString String used to format the link
      * @see java.text.MessageFormat
      */
@@ -944,7 +945,11 @@ public class JXDatePicker extends JComponent {
                 String key = select ? JXDatePicker.HOME_COMMIT_KEY : JXDatePicker.HOME_NAVIGATE_KEY;
                 select = false;
                 Action delegate = getActionMap().get(key);
-                if (delegate !=  null) {
+                /*
+                 * PatrykRy: Commit today date only when commit action is enabled.
+                 * Home navigate is always enabled.
+                 */
+                if (delegate !=  null && delegate.isEnabled()) {  
                     delegate.actionPerformed(null);
                 }
                 
@@ -952,8 +957,6 @@ public class JXDatePicker extends JComponent {
         }
     }
 
-//----------------------- deprecated
-    
 
 }    
  
\ No newline at end of file
