@@ -1,5 +1,5 @@
 /*
- * $Id: JXEditorPane.java,v 1.27 2008/03/25 01:09:47 kschaefe Exp $
+ * $Id: JXEditorPane.java,v 1.28 2008/06/16 15:02:13 kleopatra Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -23,6 +23,8 @@ package org.jdesktop.swingx;
 
 import org.jdesktop.swingx.action.ActionManager;
 import org.jdesktop.swingx.action.Targetable;
+import org.jdesktop.swingx.search.SearchFactory;
+import org.jdesktop.swingx.search.Searchable;
 
 import javax.swing.*;
 import javax.swing.event.CaretEvent;
