@@ -1,5 +1,5 @@
 /*
- * $Id: JXLabel.java,v 1.23 2008/06/08 21:00:56 rah003 Exp $
+ * $Id: JXLabel.java,v 1.28 2008/12/31 12:26:47 rah003 Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -21,6 +21,7 @@
 
 package org.jdesktop.swingx;
 
+import java.applet.Applet;
 import java.awt.Color;
 import java.awt.Container;
 import java.awt.Dimension;
@@ -30,8 +31,9 @@ import java.awt.Graphics2D;
 import java.awt.Insets;
 import java.awt.Rectangle;
 import java.awt.Shape;
-import java.awt.event.ComponentAdapter;
-import java.awt.event.ComponentEvent;
+import java.awt.Window;
+import java.awt.event.HierarchyBoundsAdapter;
+import java.awt.event.HierarchyEvent;
 import java.awt.geom.Point2D;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
@@ -42,9 +44,13 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
 import java.util.List;
+
 import javax.swing.Icon;
 import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JViewport;
 import javax.swing.SizeRequirements;
+import javax.swing.border.Border;
 import javax.swing.event.DocumentEvent;
 import javax.swing.event.DocumentEvent.ElementChange;
 import javax.swing.plaf.basic.BasicHTML;
@@ -80,7 +86,7 @@ import org.jdesktop.swingx.painter.Painter;
  * </p>
  *
  * <p>
- * Painter support consists of the <code>foregroundPainter</code> and <code>backgroundpainter</code> properties. The
+ * Painter support consists of the <code>foregroundPainter</code> and <code>backgroundPainter</code> properties. The
  * <code>backgroundPainter</code> refers to a painter responsible for painting <i>beneath</i> the text and icon. This
  * painter, if set, will paint regardless of the <code>opaque</code> property. If the background painter does not
  * fully paint each pixel, then you should make sure the <code>opaque</code> property is set to false.
@@ -105,9 +111,8 @@ import org.jdesktop.swingx.painter.Painter;
  *
  * <p>
  * The text (actually, the entire foreground and background) of the JXLabel may be rotated. Set the
- * <code>rotation</code> property to specify what the rotation should be.
+ * <code>rotation</code> property to specify what the rotation should be. Specify rotation angle in radian units.
  * </p>
- * TODO not yet determined what API this will use.
  *
  * @author joshua.marinacci@sun.com
  * @author rbair
@@ -115,6 +120,7 @@ import org.jdesktop.swingx.painter.Painter;
  * @author mario_cesar
  */
 public class JXLabel extends JLabel {
+    
     // textOrientation value declarations...
     public static final double NORMAL = 0;
 
@@ -138,10 +144,10 @@ public class JXLabel extends JLabel {
 
     private int pHeight;
 
-    // using reverse logic ... some methods causing reflow of text are called from super constructor, but private variables are initialized only after call to super so have to rely on default for boolean being false
+    // using reverse logic ... some methods causing re-flow of text are called from super constructor, but private variables are initialized only after call to super so have to rely on default for boolean being false
     private boolean dontIgnoreRepaint = false;
 
-    private int prevTlaWidth;
+    private int occupiedWidth;
 
     private static final String oldRendererKey = "was" + BasicHTML.propertyKey;
 
@@ -215,13 +221,19 @@ public class JXLabel extends JLabel {
     }
 
     private void initPainterSupport() {
-        foregroundPainter = new AbstractPainter() {
-            protected void doPaint(Graphics2D g, Object object, int width, int height) {
+        foregroundPainter = new AbstractPainter<JXLabel>() {
+            protected void doPaint(Graphics2D g, JXLabel label, int width, int height) {
                 Insets i = getInsets();
                 g = (Graphics2D) g.create(-i.left, -i.top, width, height);
-                JXLabel.super.paintComponent(g);
+                label.paint(g);
                 g.dispose();
             }
+            //if any of the state of the JButton that affects the foreground has changed,
+            //then I must clear the cache. This is really hard to get right, there are
+            //bound to be bugs. An alternative is to NEVER cache.
+            protected boolean shouldUseCache() {
+                return false;
+            }
         };
     }
 
@@ -230,14 +242,21 @@ public class JXLabel extends JLabel {
      */
     private void initLineWrapSupport() {
         addPropertyChangeListener(new MultiLineSupport());
-        addComponentListener(new ComponentAdapter() {
-            public void componentResized(ComponentEvent e) {
-                if (!isLineWrap()) {
-                    return;
-                }
-                View view = (View) getClientProperty(BasicHTML.propertyKey);
-                if (view != null && view instanceof Renderer) {
-                    view.setSize(getWidth() - 1, ((Renderer) view).height);
+        // FYI: no more listening for componentResized. Those events are delivered out
+        // of order and without old values are meaningless and forcing us to react when
+        // not necessary. Instead overriding reshape() ensures we have control over old AND new size.
+        addHierarchyBoundsListener(new HierarchyBoundsAdapter() {
+            public void ancestorResized(HierarchyEvent e) {
+                // if one of the parents is viewport, resized events will not be propagated down unless viewport is changing visibility of scrollbars.
+                // To make sure Label is able to re-wrap text when viewport size changes, initiate re-wrapping here by changing size of view
+                if (e.getChanged() instanceof JViewport) {
+                    Rectangle viewportBounds = e.getChanged().getBounds();
+                    if (viewportBounds.getWidth() < getWidth()) {
+                        View view = getWrappingView();
+                        if (view != null) {
+                            view.setSize(viewportBounds.width, viewportBounds.height);
+                        }
+                    }
                 }
             }});
     }
@@ -252,6 +271,29 @@ public class JXLabel extends JLabel {
         return foregroundPainter;
     }
 
+    @Override
+    public void reshape(int x, int y, int w, int h) {
+        int oldH = getHeight();
+        super.reshape(x, y, w, h);
+        if (!isLineWrap()) {
+            return;
+        }
+        if (oldH == 0) {
+            return;
+        }
+        if (w > getVisibleRect().width) {
+            w = getVisibleRect().width;
+        }
+        View view = (View) getClientProperty(BasicHTML.propertyKey);
+        if (view != null && view instanceof Renderer) {
+            Insets i = getInsets();
+            int dx = i.left + i.right;
+            Rectangle iconR = calculateIconRect();
+            view.setSize(w - occupiedWidth, h);
+        }
+
+    }
+
     /**
      * Sets a new foregroundPainter on the label. This will replace the existing foreground painter. Existing painters
      * can be wrapped by using a CompoundPainter.
@@ -304,7 +346,9 @@ public class JXLabel extends JLabel {
     @Override
     public Dimension getPreferredSize() {
         Dimension size = super.getPreferredSize();
+        //if (true) return size;
         if (isPreferredSizeSet()) {
+            //log.fine("ret 0");
             return size;
         } else if (this.textRotation != NORMAL) {
             // #swingx-680 change the preferred size when rotation is set ... ideally this would be solved in the LabelUI rather then here
@@ -313,52 +357,202 @@ public class JXLabel extends JLabel {
             theta));
         } else {
             // #swingx-780 preferred size is not set properly when parent container doesn't enforce the width
-            View view = (View) getClientProperty(BasicHTML.propertyKey);
-            Container tla = super.getTopLevelAncestor();
-            if (view == null || tla == null || !(view instanceof Renderer)) {
-                return size;
+            View view = getWrappingView();
+            if (view == null) {
+                if (isLineWrap() && !MultiLineSupport.isHTML(getText())) {
+                    // view might get lost on LAF change ...
+                    putClientProperty(BasicHTML.propertyKey, 
+                            getMultiLineSupport().createView(this));
+                    view = (View) getClientProperty(BasicHTML.propertyKey);
+                } else {
+                    return size;
+                }
             }
-            Rectangle tlaBounds = tla.getBounds();
-            int modTlaWidth = tlaBounds.width;
-            //#swingx-780 watch out for ancestor providing more width to us
-            Insets tlaInsets = tla.getInsets();
-            if (tlaInsets != null) {
-                modTlaWidth -= tlaInsets.left + tlaInsets.right + 3;
+            Insets insets = getInsets();
+            int dx = insets.left + insets.right;
+            int dy = insets.top + insets.bottom;
+            //log.fine("INSETS:" + insets);
+            //log.fine("BORDER:" + this.getBorder());
+            Rectangle textR = new Rectangle();
+            Rectangle viewR = new Rectangle();
+            textR.x = textR.y = textR.width = textR.height = 0;
+            viewR.x = dx;
+            viewR.y = dy;
+            viewR.width = viewR.height = Short.MAX_VALUE;
+            // layout label
+            // 1) icon
+            Rectangle iconR = calculateIconRect();
+            // 2) init textR
+            boolean textIsEmpty = (getText() == null) || getText().equals("");
+            int lsb = 0;
+            /* Unless both text and icon are non-null, we effectively ignore
+             * the value of textIconGap.
+             */
+            int gap;
+            if (textIsEmpty) {
+                textR.width = textR.height = 0;
+                gap = 0;
             }
-            int w = ((Renderer) view).getWidth();
-            int h = ((Renderer) view).getHeight();
-            Icon ic = getIcon();
-            int iconWidth = ic != null ? (ic.getIconWidth() + getIconTextGap()) : 0;
-            if (this.prevTlaWidth == modTlaWidth && (getWidth() - iconWidth) == w ) {
-                // no change bail out
-                size.width = Math.max(size.width - iconWidth, w);
-                size.height =  Math.max(getHeight(), size.height);
-                this.prevTlaWidth = modTlaWidth;
-                return size;
-            }
-            //#swingx-780 - incorrect reflow on resize when parent embeded in scrollpane
-            Rectangle superBounds = super.getBounds();
-            int newW = tlaBounds.width <= 0 ? w : (tlaBounds.width - 1);//was: Math.min(superBounds.width, tlaBounds.width);
-            this.prevTlaWidth = modTlaWidth;
+            else {
+                int availTextWidth;
+                gap = (iconR.width == 0) ? 0 : getIconTextGap();
 
-            if (ic != null) {
-                newW -= iconWidth;
+                occupiedWidth = dx + iconR.width + gap;
+                Object parent = getParent();
+                if (parent != null && (parent instanceof JPanel)) {
+                    JPanel panel = ((JPanel) parent);
+                    Border b = panel.getBorder();
+                    if (b != null) {
+                        Insets in = b.getBorderInsets(panel);
+                        occupiedWidth += in.left + in.right;
+                    }
+                }
+                if (getHorizontalTextPosition() == CENTER) {
+                    availTextWidth = viewR.width;
+                }
+                else {
+                    availTextWidth = viewR.width - (iconR.width + gap);
+                }
+                float xPrefSpan = view.getPreferredSpan(View.X_AXIS);
+                //log.fine("atw:" + availTextWidth + ", vps:" + xPrefSpan);
+                textR.width = Math.min(availTextWidth, (int) xPrefSpan);
+                if (maxLineSpan > 0) {
+                    textR.width = Math.min(textR.width, maxLineSpan);
+                    if (xPrefSpan > maxLineSpan) {
+                        view.setSize(maxLineSpan, textR.height);
+                    }
+                }
+                textR.height = (int) view.getPreferredSpan(View.Y_AXIS);
+                if (textR.height == 0) {
+                    textR.height = getFont().getSize();
+                }
+                //log.fine("atw:" + availTextWidth + ", vps:" + xPrefSpan + ", h:" + textR.height);
 
             }
-            //#swingx-780 take into account top level ancestor insets
-            if (tlaInsets != null) {
-                newW -= tlaInsets.left + tlaInsets.right + 3;
+            // 3) set text xy based on h/v text pos
+            if (getVerticalTextPosition() == TOP) {
+                if (getHorizontalTextPosition() != CENTER) {
+                    textR.y = 0;
+                }
+                else {
+                    textR.y = -(textR.height + gap);
+                }
             }
-            Insets i = getInsets();
-            if (i != null) {
-                newW -= i.left + i.right;
+            else if (getVerticalTextPosition() == CENTER) {
+                textR.y = (iconR.height / 2) - (textR.height / 2);
             }
-            view.setSize(newW, (int) Math.max(super.getPreferredSize().height, view.getPreferredSpan(View.Y_AXIS)));
-            size.setSize(newW,  view.getPreferredSpan(View.Y_AXIS) + (i != null ? (i.top + i.bottom) : 0) );
+            else { // (verticalTextPosition == BOTTOM)
+                if (getVerticalTextPosition() != CENTER) {
+                    textR.y = iconR.height - textR.height;
+                }
+                else {
+                    textR.y = (iconR.height + gap);
+                }
+            }
+
+            if (getHorizontalTextPosition() == LEFT) {
+                textR.x = -(textR.width + gap);
+            }
+            else if (getHorizontalTextPosition() == CENTER) {
+                textR.x = (iconR.width / 2) - (textR.width / 2);
+            }
+            else { // (horizontalTextPosition == RIGHT)
+                textR.x = (iconR.width + gap);
+            }
+
+            // 4) shift label around based on its alignment
+            int labelR_x = Math.min(iconR.x, textR.x);
+            int labelR_width = Math.max(iconR.x + iconR.width,
+                                        textR.x + textR.width) - labelR_x;
+            int labelR_y = Math.min(iconR.y, textR.y);
+            int labelR_height = Math.max(iconR.y + iconR.height,
+                                         textR.y + textR.height) - labelR_y;
+
+            int dax, day;
+
+            if (getVerticalAlignment() == TOP) {
+                day = viewR.y - labelR_y;
+            }
+            else if (getVerticalAlignment() == CENTER) {
+                day = (viewR.y + (viewR.height / 2)) - (labelR_y + (labelR_height / 2));
+            }
+            else { // (verticalAlignment == BOTTOM)
+                day = (viewR.y + viewR.height) - (labelR_y + labelR_height);
+            }
+
+            if (getHorizontalAlignment() == LEFT) {
+                dax = viewR.x - labelR_x;
+            }
+            else if (getHorizontalAlignment() == RIGHT) {
+                dax = (viewR.x + viewR.width) - (labelR_x + labelR_width);
+            }
+            else { // (horizontalAlignment == CENTER)
+                dax = (viewR.x + (viewR.width / 2)) -
+                     (labelR_x + (labelR_width / 2));
+            }
+
+            textR.x += dax;
+            textR.y += day;
+
+            iconR.x += dax;
+            iconR.y += day;
+
+            if (lsb < 0) {
+                // lsb is negative. Shift the x location so that the text is
+                // visually drawn at the right location.
+                textR.x -= lsb;
+            }
+            // EO layout label
+
+            int x1 = Math.min(iconR.x, textR.x);
+            int x2 = Math.max(iconR.x + iconR.width, textR.x + textR.width);
+            int y1 = Math.min(iconR.y, textR.y);
+            int y2 = Math.max(iconR.y + iconR.height, textR.y + textR.height);
+            Dimension rv = new Dimension(x2 - x1, y2 - y1);
+
+            rv.width += dx;
+            rv.height += dy;
+            //log.fine("returning: " + rv);
+            return rv;
         }
+        //log.fine("ret 3");
         return size;
     }
 
+    private View getWrappingView() {
+        if (super.getTopLevelAncestor() == null) {
+            return null;
+        }
+        View view = (View) getClientProperty(BasicHTML.propertyKey);
+        if (!(view instanceof Renderer)) {
+            return null;
+        }
+        return view;
+    }
+
+    private Container getViewport() {
+        for(Container p = this; p != null; p = p.getParent()) {
+            if(p instanceof Window || p instanceof Applet || p instanceof JViewport) {
+                return p;
+            }
+        }
+        return null;
+    }
+
+    private Rectangle calculateIconRect() {
+        Rectangle iconR = new Rectangle();
+        Icon icon = isEnabled() ? getIcon() : getDisabledIcon();
+        iconR.x = iconR.y = iconR.width = iconR.height = 0;
+        if (icon != null) {
+            iconR.width = icon.getIconWidth();
+            iconR.height = icon.getIconHeight();
+        }
+        else {
+            iconR.width = iconR.height = 0;
+        }
+        return iconR;
+    }
+
     public int getMaxLineSpan() {
         return maxLineSpan ;
     }
@@ -442,6 +636,11 @@ public class JXLabel extends JLabel {
     public boolean isPaintBorderInsets() {
         return paintBorderInsets;
     }
+    
+    @Override
+    public boolean isOpaque() {
+        return painting ? false : super.isOpaque();
+    }
 
     /**
      * Sets the paintBorderInsets property.
@@ -464,14 +663,15 @@ public class JXLabel extends JLabel {
      */
     @Override
     protected void paintComponent(Graphics g) {
+        //log.fine("in");
         // resizing the text view causes recursive callback to the paint down the road. In order to prevent such
         // computationally intensive series of repaints every call to paint is skipped while top most call is being
         // executed.
-        if (!dontIgnoreRepaint) {
-            return;
-        }
+//        if (!dontIgnoreRepaint) {
+//            return;
+//        }
         painted = true;
-        if (backgroundPainter == null && foregroundPainter == null) {
+        if (painting || backgroundPainter == null && foregroundPainter == null) {
             super.paintComponent(g);
         } else {
             pWidth = getWidth();
@@ -510,6 +710,7 @@ public class JXLabel extends JLabel {
                 // g2.setColor(Color.RED);
                 // g2.fillRect(0, 0, getWidth(), getHeight());
                 // g2.setColor(c);
+                //log.fine("PW:" + pWidth + ", PH:" + pHeight);
                 foregroundPainter.paint(tmp, this, pWidth, pHeight);
                 tmp.dispose();
                 painting = false;
@@ -719,7 +920,7 @@ public class JXLabel extends JLabel {
                 } else if ("lineWrap".equals(name) && !isHTML(src.getText())) {
                     src.putClientProperty(BasicHTML.propertyKey, createView(src));
                 }
-            } else if ("lineWrap".equals(name)) {
+            } else if ("lineWrap".equals(name) && !((Boolean)evt.getNewValue())) {
                 restoreHtmlRenderer(src);
             }
         }
@@ -862,6 +1063,8 @@ public class JXLabel extends JLabel {
 
         JXLabel host;
 
+        boolean invalidated = false;
+
         private float width;
 
         private float height;
@@ -872,8 +1075,18 @@ public class JXLabel extends JLabel {
             view = v;
             view.setParent(this);
             host = c;
+            //log.fine("vir: " +  host.getVisibleRect());
+            int w;
+            if (host.getVisibleRect().width == 0) {
+                invalidated = true;
+                return;
+            } else {
+                w = host.getVisibleRect().width;
+            }
+            //log.fine("w:" + w);
             // initially layout to the preferred size
-            setSize(c.getMaxLineSpan() > -1 ? c.getMaxLineSpan() : view.getPreferredSpan(X_AXIS), view.getPreferredSpan(Y_AXIS));
+            //setSize(c.getMaxLineSpan() > -1 ? c.getMaxLineSpan() : view.getPreferredSpan(X_AXIS), view.getPreferredSpan(Y_AXIS));
+            setSize(c.getMaxLineSpan() > -1 ? c.getMaxLineSpan() : w, host.getVisibleRect().height);
         }
 
         @Override
@@ -912,9 +1125,9 @@ public class JXLabel extends JLabel {
          */
         public void paint(Graphics g, Shape allocation) {
             Rectangle alloc = allocation.getBounds();
-            view.setSize(alloc.width, alloc.height);
-            this.width = alloc.width;
-            this.height = alloc.height;
+            //view.setSize(alloc.width, alloc.height);
+            //this.width = alloc.width;
+            //this.height = alloc.height;
             if (g.getClipBounds() == null) {
                 g.setClip(alloc);
                 view.paint(g, allocation);
@@ -972,18 +1185,36 @@ public class JXLabel extends JLabel {
          * @param height the height
          */
         public void setSize(float width, float height) {
+            if (host.maxLineSpan > 0) {
+                width = Math.min(width, host.maxLineSpan);
+            }
             if (width == this.width && height == this.height) {
                 return;
             }
             this.width = (int) width;
             this.height = (int) height;
-            view.setSize(width, height);
+            view.setSize(width, height == 0 ? Short.MAX_VALUE : height);
+            if (this.height == 0) {
+                this.height = view.getPreferredSpan(View.Y_AXIS);
+            }
         }
 
         @Override
         public float getPreferredSpan(int axis) {
             if (axis == X_AXIS) {
+                //log.fine("inv: " + invalidated + ", w:" + width + ", vw:" + host.getVisibleRect());
                 // width currently laid out to
+                if (invalidated) {
+                    int w = host.getVisibleRect().width;
+                    if (w != 0) {
+                        //log.fine("vrh: " + host.getVisibleRect().height);
+                        invalidated = false;
+                        // JXLabelTest4 works
+                        setSize(w - (host.getOccupiedWidth()), host.getVisibleRect().height);
+                        // JXLabelTest3 works; 20 == width of the parent border!!! ... why should this screw with us?
+                        //setSize(w - (host.getOccupiedWidth()+20), host.getVisibleRect().height);
+                    }
+                }
                 return width > 0 ? width : view.getPreferredSpan(axis);
             } else {
                 return  view.getPreferredSpan(axis);
@@ -1660,4 +1891,8 @@ public class JXLabel extends JLabel {
             super(s);
         }
     }
+
+    protected int getOccupiedWidth() {
+        return occupiedWidth;
+    }
 }
\ No newline at end of file
