@@ -1,5 +1,5 @@
 /*
- * $Id: JXList.java,v 1.72 2008/03/19 14:48:34 kleopatra Exp $
+ * $Id: JXList.java,v 1.78 2008/12/23 18:12:34 kschaefe Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -22,7 +22,6 @@
 package org.jdesktop.swingx;
 
 import java.awt.Component;
-import java.awt.Cursor;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.event.ActionEvent;
@@ -32,8 +31,6 @@ import java.util.Comparator;
 import java.util.List;
 import java.util.Vector;
 import java.util.logging.Logger;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 
 import javax.swing.AbstractListModel;
 import javax.swing.Action;
@@ -43,6 +40,7 @@ import javax.swing.KeyStroke;
 import javax.swing.ListCellRenderer;
 import javax.swing.ListModel;
 import javax.swing.ListSelectionModel;
+import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.ListDataEvent;
@@ -59,8 +57,16 @@ import org.jdesktop.swingx.decorator.SelectionMapper;
 import org.jdesktop.swingx.decorator.SortController;
 import org.jdesktop.swingx.decorator.SortKey;
 import org.jdesktop.swingx.decorator.SortOrder;
+import org.jdesktop.swingx.renderer.AbstractRenderer;
 import org.jdesktop.swingx.renderer.DefaultListRenderer;
 import org.jdesktop.swingx.renderer.StringValue;
+import org.jdesktop.swingx.renderer.StringValues;
+import org.jdesktop.swingx.rollover.ListRolloverController;
+import org.jdesktop.swingx.rollover.RolloverProducer;
+import org.jdesktop.swingx.rollover.RolloverRenderer;
+import org.jdesktop.swingx.search.ListSearchable;
+import org.jdesktop.swingx.search.SearchFactory;
+import org.jdesktop.swingx.search.Searchable;
 
 /**
  * JXList.
@@ -106,7 +112,7 @@ public class JXList extends JList {
      * RolloverController: listens to cell over events and repaints
      * entered/exited rows.
      */
-    private ListRolloverController linkController;
+    private ListRolloverController<JXList> linkController;
 
     /** A wrapper around the default renderer enabling decoration. */
     private DelegatingRenderer delegatingRenderer;
@@ -259,7 +265,7 @@ public class JXList extends JList {
      */
     public Searchable getSearchable() {
         if (searchable == null) {
-            searchable = new ListSearchable();
+            searchable = new ListSearchable(this);
         }
         return searchable;
     }
@@ -275,86 +281,6 @@ public class JXList extends JList {
     }
     
 
-    public class ListSearchable extends AbstractSearchable {
-
-        @Override
-        protected void findMatchAndUpdateState(Pattern pattern, int startRow, boolean backwards) {
-            SearchResult searchResult = null;
-            if (backwards) {
-                for (int index = startRow; index >= 0 && searchResult == null; index--) {
-                    searchResult = findMatchAt(pattern, index);
-                }
-            } else {
-                for (int index = startRow; index < getSize() && searchResult == null; index++) {
-                    searchResult = findMatchAt(pattern, index);
-                }
-            }
-            updateState(searchResult);
-        }
-
-        @Override
-        protected SearchResult findExtendedMatch(Pattern pattern, int row) {
-            
-            return findMatchAt(pattern, row);
-        }
-        /**
-         * Matches the cell content at row/col against the given Pattern.
-         * Returns an appropriate SearchResult if matching or null if no
-         * matching
-         * 
-         * @param pattern 
-         * @param row a valid row index in view coordinates
-         * @return <code>SearchResult</code> if matched otherwise null
-         */
-        protected SearchResult findMatchAt(Pattern pattern, int row) {
-            String text = getStringAt(row);
-            if ((text != null) && (text.length() > 0 )) {
-                Matcher matcher = pattern.matcher(text);
-                if (matcher.find()) {
-                    return createSearchResult(matcher, row, -1);
-                }
-            }
-            return null;
-// this is pre-767-swingx: consistent string api
-//            Object value = getElementAt(row);
-//            if (value != null) {
-//                Matcher matcher = pattern.matcher(value.toString());
-//                if (matcher.find()) {
-//                    return createSearchResult(matcher, row, -1);
-//                }
-//            }
-//            return null;
-        }
-        
-        @Override
-        protected int getSize() {
-            return getElementCount();
-        }
-
-        /**
-         * @param result
-         * @return {@code true} if the {@code result} contains a match;
-         *         {@code false} otherwise
-         */
-        protected boolean hasMatch(SearchResult result) {
-            return result.getFoundRow() >= 0;
-        }
-        
-        @Override
-        protected void moveMatchMarker() {
-            // PENDING JW: #718-swingx - don't move selection on not found
-            // complying here is accidental, defaultListSelectionModel doesn't
-            // clear on -1 but silently does nothing
-            // isn't doc'ed anywhere - so we back out
-            if (!hasMatch(lastSearchResult)) {
-                return;
-            }
-            setSelectedIndex(lastSearchResult.foundRow);
-            ensureIndexIsVisible(lastSearchResult.foundRow);
-
-        }
-
-    }
     /**
      * Property to enable/disable rollover support. This can be enabled to show
      * "live" rollover behaviour, f.i. the cursor over LinkModel cells. Default
@@ -381,15 +307,15 @@ public class JXList extends JList {
     }
 
     
-    protected ListRolloverController getLinkController() {
+    protected ListRolloverController<JXList> getLinkController() {
         if (linkController == null) {
             linkController = createLinkController();
         }
         return linkController;
     }
 
-    protected ListRolloverController createLinkController() {
-        return new ListRolloverController();
+    protected ListRolloverController<JXList> createLinkController() {
+        return new ListRolloverController<JXList>();
     }
 
 
@@ -429,95 +355,7 @@ public class JXList extends JList {
         return rolloverProducer != null;
     }
 
-    /**
-     * listens to rollover properties. Repaints effected component regions.
-     * Updates link cursor.
-     * 
-     * @author Jeanette Winzenburg
-     */
-    public static class ListRolloverController<T extends JList> extends
-            RolloverController<T> {
-
-        private Cursor oldCursor;
-
-        // --------------------------------- JList rollover
-
-        @Override
-        protected void rollover(Point oldLocation, Point newLocation) {
-            // PENDING JW - track down the -1 in location.y
-            if (oldLocation != null) {
-                Rectangle r = component.getCellBounds(oldLocation.y, oldLocation.y);
-                // LOG.info("old index/cellbounds: " + index + "/" + r);
-                if (r != null) {
-                    component.repaint(r);
-                }
-            }
-            if (newLocation != null) {
-                Rectangle r = component.getCellBounds(newLocation.y, newLocation.y);
-                // LOG.info("new index/cellbounds: " + index + "/" + r);
-                if (r != null) {
-                    component.repaint(r);
-                }
-            }
-            setRolloverCursor(newLocation);
-        }
-
-        /**
-         * something weird: cursor in JList behaves different from JTable?
-         * Hmm .. no: using the table code snippets seems to fix #503-swingx
-         * @param location
-         */
-        private void setRolloverCursor(Point location) {
-            if (hasRollover(location)) {
-                if (oldCursor == null) {
-                    oldCursor = component.getCursor();
-                    component.setCursor(Cursor
-                            .getPredefinedCursor(Cursor.HAND_CURSOR));
-                }
-            } else {
-                if (oldCursor != null) {
-                    component.setCursor(oldCursor);
-                    oldCursor = null;
-                }
-            }
-//            if (hasRollover(location)) {
-//                oldCursor = component.getCursor();
-//                component.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
-//            } else {
-//                component.setCursor(oldCursor);
-//                oldCursor = null;
-//            }
-
-        }
-
-        @Override
-        protected RolloverRenderer getRolloverRenderer(Point location,
-                boolean prepare) {
-            ListCellRenderer renderer = component.getCellRenderer();
-            RolloverRenderer rollover = renderer instanceof RolloverRenderer 
-                ? (RolloverRenderer) renderer : null;
-            if ((rollover != null) && !rollover.isEnabled()) {
-                rollover = null;
-            }
-            if ((rollover != null) && prepare) {
-                Object element = component.getModel().getElementAt(location.y);
-                renderer.getListCellRendererComponent(component, element,
-                        location.y, false, true);
-            }
-            return rollover;
-        }
-
-        @Override
-        protected Point getFocusedCell() {
-            int leadRow = component.getLeadSelectionIndex();
-            if (leadRow < 0)
-                return null;
-            return new Point(0, leadRow);
-        }
-
-    }
-
-//--------------------- public sort api
+    //--------------------- public sort api
 //    /** 
 //     * Returns the sortable property.
 //     * Here: same as filterEnabled.
@@ -1232,7 +1070,7 @@ public class JXList extends JList {
             if (renderer instanceof StringValue) {
                 return ((StringValue) renderer).getString(getValueAt(row, column));
             }
-            return StringValue.TO_STRING.getString(getValueAt(row, column));
+            return StringValues.TO_STRING.getString(getValueAt(row, column));
         }
         
         
@@ -1290,51 +1128,19 @@ public class JXList extends JList {
 
     // ------------------------------ renderers
 
-    /**
-     * Returns the CompoundHighlighter assigned to the list, null if none.
-     * PENDING: open up for subclasses again?.
-     * 
-     * @return the CompoundHighlighter assigned to the table.
-     * @see #setCompoundHighlighter(CompoundHighlighter)
-     */
-    private CompoundHighlighter getCompoundHighlighter() {
-        return compoundHighlighter;
-    }
 
+    
     /**
-     * Assigns a CompoundHighlighter to the list, maybe null to remove all
-     * Highlighters.<p>
-     * 
-     * The default value is <code>null</code>. <p>
-     * 
-     * PENDING: open up for subclasses again?.
-     * @param pipeline the CompoundHighlighter to use for renderer decoration. 
-     * @see #getCompoundHighlighter()
-     * @see #addHighlighter(Highlighter)
-     * @see #removeHighlighter(Highlighter)
-     */
-    private void setCompoundHighlighter(CompoundHighlighter pipeline) {
-        CompoundHighlighter old = getCompoundHighlighter();
-        if (old != null) {
-            old.removeChangeListener(getHighlighterChangeListener());
-        }
-        compoundHighlighter = pipeline;
-        if (compoundHighlighter != null) {
-            compoundHighlighter.addChangeListener(getHighlighterChangeListener());
-        }
-        firePropertyChange("highlighters", old, getCompoundHighlighter());
-    }
-
-    /**
-     * Sets the <code>Highlighter</code>s to the list, replacing any old settings.
+     * Sets the <code>Highlighter</code>s to the table, replacing any old settings.
      * None of the given Highlighters must be null.<p>
      * 
-     * Note: the implementation is lenient with a single null highighter
-     * to ease the api change from previous versions.
+     * This is a bound property. <p> 
      * 
-     * PENDING: property change? 
+     * Note: as of version #1.257 the null constraint is enforced strictly. To remove
+     * all highlighters use this method without param.
      * 
      * @param highlighters zero or more not null highlighters to use for renderer decoration.
+     * @throws NullPointerException if array is null or array contains null values.
      * 
      * @see #getHighlighters()
      * @see #addHighlighter(Highlighter)
@@ -1342,44 +1148,36 @@ public class JXList extends JList {
      * 
      */
     public void setHighlighters(Highlighter... highlighters) {
-        CompoundHighlighter pipeline = null;
-        if ((highlighters != null) && (highlighters.length > 0) && 
-            (highlighters[0] != null)) {    
-           pipeline = new CompoundHighlighter(highlighters);
-        }
-        setCompoundHighlighter(pipeline);
+        Highlighter[] old = getHighlighters();
+        getCompoundHighlighter().setHighlighters(highlighters);
+        firePropertyChange("highlighters", old, getHighlighters());
     }
 
     /**
-     * Returns the <code>Highlighter</code>s used by this list.
+     * Returns the <code>Highlighter</code>s used by this table.
      * Maybe empty, but guarantees to be never null.
-     * @return the Highlighters used by this list, guaranteed to never null.
+     * 
+     * @return the Highlighters used by this table, guaranteed to never null.
      * @see #setHighlighters(Highlighter[])
      */
     public Highlighter[] getHighlighters() {
-        return getCompoundHighlighter() != null ? 
-                getCompoundHighlighter().getHighlighters() : 
-                    CompoundHighlighter.EMPTY_HIGHLIGHTERS;
+        return getCompoundHighlighter().getHighlighters();
     }
-    
     /**
-     * Adds a Highlighter. Appends to the end of the list of used
-     * Highlighters.
+     * Appends a <code>Highlighter</code> to the end of the list of used
+     * <code>Highlighter</code>s. The argument must not be null. 
      * <p>
      * 
-     * @param highlighter the <code>Highlighter</code> to add.
+     * @param highlighter the <code>Highlighter</code> to add, must not be null.
      * @throws NullPointerException if <code>Highlighter</code> is null.
      * 
      * @see #removeHighlighter(Highlighter)
      * @see #setHighlighters(Highlighter[])
      */
     public void addHighlighter(Highlighter highlighter) {
-        CompoundHighlighter pipeline = getCompoundHighlighter();
-        if (pipeline == null) {
-           setCompoundHighlighter(new CompoundHighlighter(highlighter)); 
-        } else {
-            pipeline.addHighlighter(highlighter);
-        }
+        Highlighter[] old = getHighlighters();
+        getCompoundHighlighter().addHighlighter(highlighter);
+        firePropertyChange("highlighters", old, getHighlighters());
     }
 
     /**
@@ -1392,30 +1190,56 @@ public class JXList extends JList {
      * @see #setHighlighters(Highlighter...)
      */
     public void removeHighlighter(Highlighter highlighter) {
-        if ((getCompoundHighlighter() == null)) return;
+        Highlighter[] old = getHighlighters();
         getCompoundHighlighter().removeHighlighter(highlighter);
+        firePropertyChange("highlighters", old, getHighlighters());
     }
     
+    /**
+     * Returns the CompoundHighlighter assigned to the table, null if none.
+     * PENDING: open up for subclasses again?.
+     * 
+     * @return the CompoundHighlighter assigned to the table.
+     * @see #setCompoundHighlighter(CompoundHighlighter)
+     */
+    protected CompoundHighlighter getCompoundHighlighter() {
+        if (compoundHighlighter == null) {
+            compoundHighlighter = new CompoundHighlighter();
+            compoundHighlighter.addChangeListener(getHighlighterChangeListener());
+        }
+        return compoundHighlighter;
+    }
 
     /**
-     * returns the ChangeListener to use with highlighters. Creates one if
-     * necessary.
+     * Returns the <code>ChangeListener</code> to use with highlighters. Lazily 
+     * creates the listener.
      * 
-     * @return != null
+     * @return the ChangeListener for observing changes of highlighters, 
+     *   guaranteed to be <code>not-null</code>
      */
     protected ChangeListener getHighlighterChangeListener() {
         if (highlighterChangeListener == null) {
-            highlighterChangeListener = new ChangeListener() {
-
-                public void stateChanged(ChangeEvent e) {
-                    repaint();
-                }
-
-            };
+            highlighterChangeListener = createHighlighterChangeListener();
         }
         return highlighterChangeListener;
     }
 
+    /**
+     * Creates and returns the ChangeListener observing Highlighters.
+     * <p>
+     * Here: repaints the table on receiving a stateChanged.
+     * 
+     * @return the ChangeListener defining the reaction to changes of
+     *         highlighters.
+     */
+    protected ChangeListener createHighlighterChangeListener() {
+        return new ChangeListener() {
+            public void stateChanged(ChangeEvent e) {
+                repaint();
+            }
+        };
+    }
+
     
     /**
      * Returns the string representation of the cell value at the given position. 
@@ -1429,7 +1253,7 @@ public class JXList extends JList {
         if (renderer instanceof StringValue) {
             return ((StringValue) renderer).getString(getElementAt(row));
         }
-        return StringValue.TO_STRING.getString(getElementAt(row));
+        return StringValues.TO_STRING.getString(getElementAt(row));
     }
 
     private DelegatingRenderer getDelegatingRenderer() {
@@ -1563,15 +1387,22 @@ public class JXList extends JList {
           * @param renderer the renderer to update the ui of.
           */
          private void updateRendererUI(ListCellRenderer renderer) {
-             // PENDING JW: use updateComponentTree instead?
-             if (renderer instanceof JComponent) {
-                 ((JComponent) renderer).updateUI();
-             } else if (renderer != null) {
-                 Component comp = renderer.getListCellRendererComponent(
-                         JXList.this, null, -1, false, false);
-                 if (comp instanceof JComponent) {
-                     ((JComponent) comp).updateUI();
-                 }
+             if (renderer == null) return;
+             Component comp = null;
+             if (renderer instanceof AbstractRenderer) {
+                 comp = ((AbstractRenderer) renderer).getComponentProvider().getRendererComponent(null);
+             } else if (renderer instanceof Component) {
+                 comp = (Component) renderer;
+             } else {
+                 try {
+                     comp = renderer.getListCellRendererComponent(
+                             JXList.this, null, -1, false, false);
+                } catch (Exception e) {
+                    // nothing to do - renderer barked on off-range row
+                }
+             }
+             if (comp != null) {
+                 SwingUtilities.updateComponentTreeUI(comp);
              }
 
          }
@@ -1622,6 +1453,7 @@ public class JXList extends JList {
     public void updateUI() {
         super.updateUI();
         updateRendererUI();
+        updateHighlighterUI();
     }
 
     private void updateRendererUI() {
@@ -1629,10 +1461,20 @@ public class JXList extends JList {
             delegatingRenderer.updateUI();
         } else {
             ListCellRenderer renderer = getCellRenderer();
-            if (renderer instanceof JComponent) {
-                ((JComponent) renderer).updateUI();
+            if (renderer instanceof Component) {
+                SwingUtilities.updateComponentTreeUI((Component) renderer);
             }
         }
     }
 
+    /**
+     * Updates highlighter after <code>updateUI</code> changes.
+     * 
+     * @see org.jdesktop.swingx.decorator.UIDependent
+     */
+    protected void updateHighlighterUI() {
+        if (compoundHighlighter == null) return;
+        compoundHighlighter.updateUI();
+    }
+
 }
\ No newline at end of file
