@@ -1,5 +1,5 @@
 /*
- * $Id: JXRootPane.java,v 1.15 2008/02/15 15:08:20 kleopatra Exp $
+ * $Id: JXRootPane.java,v 1.18 2008/09/24 11:39:05 kleopatra Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -27,6 +27,7 @@ import java.awt.Container;
 import java.awt.Dimension;
 import java.awt.Insets;
 import java.awt.LayoutManager;
+import java.awt.LayoutManager2;
 import java.awt.Rectangle;
 import java.awt.event.ActionEvent;
 import java.awt.event.KeyEvent;
@@ -41,9 +42,6 @@ import javax.swing.JRootPane;
 import javax.swing.JToolBar;
 import javax.swing.KeyStroke;
 
-import org.jdesktop.swingx.event.MessageSource;
-import org.jdesktop.swingx.event.ProgressSource;
-
 /**
  * Extends the JRootPane by supporting specific placements for a toolbar and a
  * status bar. If a status bar exists, then toolbars, menus and any
@@ -57,91 +55,55 @@ import org.jdesktop.swingx.event.ProgressSource;
  */
 public class JXRootPane extends JRootPane {
     protected class XRootLayout extends RootLayout {
+
+        LayoutManager2 delegate;
+
+        public void setLayoutManager(LayoutManager2 delegate) {
+            this.delegate = delegate;
+        }
+
         /**
          * {@inheritDoc}
          */
         @Override
         public Dimension preferredLayoutSize(Container parent) {
-            Dimension rd, mbd, sbd;
-            Insets i = getInsets();
-        
-            if(contentPane != null) {
-                rd = contentPane.getPreferredSize();
-            } else {
-                rd = parent.getSize();
+            Dimension pref = delegatePreferredLayoutSize(parent);
+            if (statusBar != null && statusBar.isVisible()) {
+                Dimension statusPref = statusBar.getPreferredSize();
+                pref.width = Math.max(pref.width, statusPref.width);
+                pref.height += statusPref.height;
             }
-            if(menuBar != null && menuBar.isVisible()) {
-                mbd = menuBar.getPreferredSize();
-            } else {
-                mbd = new Dimension(0, 0);
-            }
-            if(statusBar != null && statusBar.isVisible()) {
-                sbd = statusBar.getPreferredSize();
-            } else {
-                sbd = new Dimension(0, 0);
-            }
-            
-            return new Dimension(Math.max(rd.width, Math.max(mbd.width, sbd.width))
-                    + i.left + i.right, rd.height + mbd.height + sbd.height
-                    + i.top + i.bottom);
+            return pref;
         }
-        
+
         /**
          * {@inheritDoc}
          */
         @Override
         public Dimension minimumLayoutSize(Container parent) {
-            Dimension rd, mbd, sbd;
-            Insets i = getInsets();
-            
-            if(contentPane != null) {
-                rd = contentPane.getMinimumSize();
-            } else {
-                rd = parent.getSize();
+            Dimension pref = delegateMinimumLayoutSize(parent);
+            if (statusBar != null && statusBar.isVisible()) {
+                Dimension statusPref = statusBar.getMinimumSize();
+                pref.width = Math.max(pref.width, statusPref.width);
+                pref.height += statusPref.height;
             }
-            if(menuBar != null && menuBar.isVisible()) {
-                mbd = menuBar.getMinimumSize();
-            } else {
-                mbd = new Dimension(0, 0);
-            }
-            if(statusBar != null && statusBar.isVisible()) {
-                sbd = statusBar.getMinimumSize();
-            } else {
-                sbd = new Dimension(0, 0);
-            }
-            
-            return new Dimension(Math.max(rd.width, Math.max(mbd.width, sbd.width))
-                    + i.left + i.right, rd.height + mbd.height + sbd.height
-                    + i.top + i.bottom);
+            return pref;
+
         }
-        
+
         /**
          * {@inheritDoc}
          */
         @Override
         public Dimension maximumLayoutSize(Container target) {
-            Dimension rd, mbd, sbd;
-            Insets i = getInsets();
-            if(menuBar != null && menuBar.isVisible()) {
-                mbd = menuBar.getMaximumSize();
-            } else {
-                mbd = new Dimension(0, 0);
+            Dimension pref = delegateMaximumLayoutSize(target);
+            if (statusBar != null && statusBar.isVisible()) {
+                Dimension statusPref = statusBar.getMaximumSize();
+                pref.width = Math.max(pref.width, statusPref.width);
+                // PENDING JW: overflow?
+                pref.height += statusPref.height;
             }
-            if(statusBar != null && statusBar.isVisible()) {
-                sbd = statusBar.getMaximumSize();
-            } else {
-                sbd = new Dimension(0, 0);
-            }
-            if(contentPane != null) {
-                rd = contentPane.getMaximumSize();
-            } else {
-                // This is silly, but should stop an overflow error
-                rd = new Dimension(Integer.MAX_VALUE, 
-                        Integer.MAX_VALUE - i.top - i.bottom - mbd.height - sbd.height - 1);
-            }
-            
-            return new Dimension(Math.min(rd.width, Math.min(mbd.width, sbd.width)) + i.left + i.right,
-                                         rd.height + mbd.height + sbd.height + i.top + i.bottom);
+            return pref;
         }
 
         /**
@@ -149,33 +111,63 @@ public class JXRootPane extends JRootPane {
          */
         @Override
         public void layoutContainer(Container parent) {
+            delegateLayoutContainer(parent);
+            if (statusBar == null || !statusBar.isVisible())
+                return;
             Rectangle b = parent.getBounds();
             Insets i = getInsets();
-            int contentY = 0;
-            int adjustH = 0;
             int w = b.width - i.right - i.left;
             int h = b.height - i.top - i.bottom;
-        
-            if(layeredPane != null) {
-                layeredPane.setBounds(i.left, i.top, w, h);
+            Dimension statusPref = statusBar.getPreferredSize();
+            statusBar.setBounds(i.right, b.height - i.bottom
+                    - statusPref.height, w, statusPref.height);
+            if (contentPane != null) {
+                Rectangle bounds = contentPane.getBounds();
+                contentPane.setBounds(bounds.x, bounds.y, bounds.width,
+                        bounds.height - statusPref.height);
             }
-            if(glassPane != null) {
-                glassPane.setBounds(i.left, i.top, w, h);
-            }
-            // Note: This is laying out the children in the layeredPane,
-            // technically, these are not our children.
-            if(menuBar != null && menuBar.isVisible()) {
-                Dimension mbd = menuBar.getPreferredSize();
-                menuBar.setBounds(0, 0, w, mbd.height);
-                contentY += mbd.height;
-            }
-            if(statusBar != null && statusBar.isVisible()) {
-                Dimension sbd = statusBar.getPreferredSize();
-                statusBar.setBounds(0, h - sbd.height, w, sbd.height);
-                adjustH += sbd.height;
-            }
-            if(contentPane != null) {
-                contentPane.setBounds(0, contentY, w, h - contentY - adjustH);
+
+        }
+
+        /**
+         * @param parent
+         * @return
+         */
+        private Dimension delegatePreferredLayoutSize(Container parent) {
+            if (delegate == null)
+                return super.preferredLayoutSize(parent);
+            return delegate.preferredLayoutSize(parent);
+        }
+
+        /**
+         * @param parent
+         * @return
+         */
+        private Dimension delegateMinimumLayoutSize(Container parent) {
+            if (delegate == null)
+                return super.minimumLayoutSize(parent);
+            return delegate.minimumLayoutSize(parent);
+        }
+
+        /**
+         * @param target
+         * @return
+         */
+        private Dimension delegateMaximumLayoutSize(Container parent) {
+            if (delegate == null)
+
+                return super.maximumLayoutSize(parent);
+            return delegate.maximumLayoutSize(parent);
+        }
+
+        /**
+         * @param parent
+         */
+        private void delegateLayoutContainer(Container parent) {
+            if (delegate == null) {
+                super.layoutContainer(parent);
+            } else {
+                delegate.layoutContainer(parent);
             }
         }
     }
@@ -253,6 +245,25 @@ public class JXRootPane extends JRootPane {
         return c;
     }
 
+    
+    @Override
+    public void setLayout(LayoutManager layout) {
+        if (layout instanceof XRootLayout) {
+            // happens if decoration is uninstalled by ui
+            if ((layout != null) && (layout == getLayout())) {
+                ((XRootLayout) layout).setLayoutManager(null);
+            }
+            super.setLayout(layout);
+        } else {
+            if (layout instanceof LayoutManager2) {
+                ((XRootLayout) getLayout()).setLayoutManager((LayoutManager2) layout);
+                if (!isValid()) {
+                    invalidate();
+                }
+            }
+        }
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -302,14 +313,14 @@ public class JXRootPane extends JRootPane {
         if (statusBar == null || comp == null) {
             return;
         }
-        if (comp instanceof MessageSource) {
-            MessageSource source = (MessageSource) comp;
+//        if (comp instanceof MessageSource) {
+//            MessageSource source = (MessageSource) comp;
 //            source.addMessageListener(statusBar);
-        }
-        if (comp instanceof ProgressSource) {
-            ProgressSource source = (ProgressSource) comp;
+//        }
+//        if (comp instanceof ProgressSource) {
+//            ProgressSource source = (ProgressSource) comp;
 //            source.addProgressListener(statusBar);
-        }
+//        }
         if (comp instanceof Container) {
             Component[] comps = ((Container) comp).getComponents();
             for (int i = 0; i < comps.length; i++) {
@@ -322,14 +333,14 @@ public class JXRootPane extends JRootPane {
         if (statusBar == null || comp == null) {
             return;
         }
-        if (comp instanceof MessageSource) {
-            MessageSource source = (MessageSource) comp;
+//        if (comp instanceof MessageSource) {
+//            MessageSource source = (MessageSource) comp;
 //            source.removeMessageListener(statusBar);
-        }
-        if (comp instanceof ProgressSource) {
-            ProgressSource source = (ProgressSource) comp;
+//        }
+//        if (comp instanceof ProgressSource) {
+//            ProgressSource source = (ProgressSource) comp;
 //            source.removeProgressListener(statusBar);
-        }
+//        }
         if (comp instanceof Container) {
             Component[] comps = ((Container) comp).getComponents();
             for (int i = 0; i < comps.length; i++) {
@@ -350,21 +361,21 @@ public class JXRootPane extends JRootPane {
         JXStatusBar oldStatusBar = this.statusBar;
         this.statusBar = statusBar;
 
-        if (statusBar != null) {
-            if (handler == null) {
+//        if (statusBar != null) {
+//            if (handler == null) {
                 // Create the new mouse handler and register the toolbar
                 // and menu components.
 //                handler = new MouseMessagingHandler(this, statusBar);
-                if (toolBar != null) {
+//                if (toolBar != null) {
 //                    handler.registerListeners(toolBar.getComponents());
-                }
-                if (menuBar != null) {
+//                }
+//                if (menuBar != null) {
 //                    handler.registerListeners(menuBar.getSubElements());
-                }
-            } else {
+//                }
+//            } else {
 //                handler.setMessageListener(statusBar);
-            }
-        }
+//            }
+//        }
 
         Component[] comps = getContentPane().getComponents();
         for (int i = 0; i < comps.length; i++) {
@@ -387,7 +398,7 @@ public class JXRootPane extends JRootPane {
         return statusBar;
     }
 
-    private MouseMessagingHandler handler;
+//    private MouseMessagingHandler handler;
 
     /**
      * Set the toolbar bar for this root pane. If the status bar exists, then
@@ -410,14 +421,14 @@ public class JXRootPane extends JRootPane {
         if (oldToolBar != null) {
             getContentPane().remove(oldToolBar);
             
-            if (handler != null) {
-                handler.unregisterListeners(oldToolBar.getComponents());
-            }
+//            if (handler != null) {
+//                handler.unregisterListeners(oldToolBar.getComponents());
+//            }
         }
         
-        if (handler != null && this.toolBar != null) {
-            handler.registerListeners(this.toolBar.getComponents());
-        }
+//        if (handler != null && this.toolBar != null) {
+//            handler.registerListeners(this.toolBar.getComponents());
+//        }
 
         getContentPane().add(BorderLayout.NORTH, this.toolBar);
         
@@ -446,13 +457,13 @@ public class JXRootPane extends JRootPane {
 
         super.setJMenuBar(menuBar);
 
-        if (handler != null && oldMenuBar != null) {
-            handler.unregisterListeners(oldMenuBar.getSubElements());
-        }
-
-        if (handler != null && menuBar != null) {
-            handler.registerListeners(menuBar.getSubElements());
-        }
+//        if (handler != null && oldMenuBar != null) {
+//            handler.unregisterListeners(oldMenuBar.getSubElements());
+//        }
+//
+//        if (handler != null && menuBar != null) {
+//            handler.registerListeners(menuBar.getSubElements());
+//        }
     }
 
     /**
