@@ -1,5 +1,5 @@
 /*
- * $Id: MultiSplitLayout.java,v 1.15 2008/04/02 07:57:39 luano Exp $
+ * $Id: MultiSplitLayout.java,v 1.19 2008/12/04 17:46:49 luano Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -228,19 +228,30 @@ public class MultiSplitLayout implements LayoutManager
    */
   public Node getNodeForComponent( Component comp )
   {   
-    return getNodeForComponent( getNameForComponent( comp ));
+    return getNodeForName( getNameForComponent( comp ));
   }
 
   /**
    * Get the MultiSplitLayout.Node associated with a component 
    * @param name the name used to associate a component with the layout
    * @return the node associated with the component
+   * @deprecated please use getNodeForName instead
    */
+  @Deprecated
   public Node getNodeForComponent( String name )
   {   
+    return getNodeForName( name );
+  }
+  /**
+   * Get the MultiSplitLayout.Node associated with a component
+   * @param name the name used to associate a component with the layout
+   * @return the node associated with the component
+   */
+  public Node getNodeForName( String name )
+  {
     if ( model instanceof Split ) {
       Split split = ((Split)model);
-      return getNodeForComponent( split, name );
+      return getNodeForName( split, name );
     }
     else
       return null;
@@ -272,16 +283,28 @@ public class MultiSplitLayout implements LayoutManager
    */
   public Node getNodeForComponent( Split split, Component comp )
   {    
-    return getNodeForComponent( split, getNameForComponent( comp ));
+    return getNodeForName( split, getNameForComponent( comp ));
   }
   
+  /**
+   * Get the MultiSplitLayout.Node associated with a component
+   * @param split the layout split that owns the requested node
+   * @param name the name used to associate a component with the layout
+   * @return the node associated with the component
+   * @deprecated please use getNodeForName instead
+   */
+  @Deprecated
+  public Node getNodeForComponent( Split split, String name )
+  {
+    return getNodeForName( split, name );
+  }
   /**
    * Get the MultiSplitLayout.Node associated with a component 
    * @param split the layout split that owns the requested node
    * @param name the name used to associate a component with the layout
    * @return the node associated with the component
    */
-  public Node getNodeForComponent( Split split, String name )
+  public Node getNodeForName( Split split, String name )
   {    
       for(Node n : split.getChildren()) {
         if ( n instanceof Leaf ) {
@@ -289,7 +312,7 @@ public class MultiSplitLayout implements LayoutManager
             return n;
         }
         else if ( n instanceof Split ) {
-          Node n1 = getNodeForComponent( (Split)n, name );
+          Node n1 = getNodeForName( (Split)n, name );
           if ( n1 != null )
             return n1;
         }
@@ -485,7 +508,7 @@ public class MultiSplitLayout implements LayoutManager
       if ( !( model instanceof Split ))
         n = model;
       else
-        n = getNodeForComponent( name );
+        n = getNodeForName( name );
 
       childMap.remove(name);
 
@@ -519,6 +542,44 @@ public class MultiSplitLayout implements LayoutManager
     }
   }
   
+  /**
+   * Show/Hide nodes. Any dividers that are no longer required due to one of the 
+   * nodes being made visible/invisible are also shown/hidder. The visibility of 
+   * the component managed by the node is also changed by this method
+   * @param name the node name
+   * @param visible the new node visible state
+   */
+  public void displayNode( String name, boolean visible )
+  {
+    Node node = getNodeForName( name );
+    if ( node != null ) {
+      Component comp = getComponentForNode( node );
+      comp.setVisible( visible );      
+      node.setVisible( visible );
+      
+      MultiSplitLayout.Split p = node.getParent();
+      if ( !visible ) {
+        p.hide( node );
+        if ( !p.isVisible()) 
+          p.getParent().hide( p );
+
+        p.checkDividers( p );
+        // If the split has become invisible then the parent may also have a 
+        // divider that needs to be hidden.
+        while ( !p.isVisible()) {
+          p = p.getParent();
+          if ( p != null )
+            p.checkDividers( p );
+          else
+            break;        
+        }
+      }
+      else  
+        p.restoreDividers( p );
+    }
+    setFloatingDividers( false );
+  }  
+  
   private Component childForNode(Node node) {
     if (node instanceof Leaf) {
       Leaf leaf = (Leaf)node;
@@ -546,8 +607,8 @@ public class MultiSplitLayout implements LayoutManager
     else if (root instanceof Divider) {
       if ( !((Divider)root).isVisible()  )
         return new Dimension(0,0);
-      int dividerSize = getDividerSize();
-      return new Dimension(dividerSize, dividerSize);
+      int divSize = getDividerSize();
+      return new Dimension(divSize, divSize);
     }
     else {
       Split split = (Split)root;
@@ -564,7 +625,7 @@ public class MultiSplitLayout implements LayoutManager
         }
       }
       else {
-    		for(Node splitChild : splitChildren) {
+            for(Node splitChild : splitChildren) {
           if ( !splitChild.isVisible())
             continue;
           Dimension size = preferredNodeSize(splitChild);
@@ -592,8 +653,8 @@ public class MultiSplitLayout implements LayoutManager
     else if (root instanceof Divider) {
       if ( !((Divider)root).isVisible()  )
         return new Dimension(0,0);
-      int dividerSize = getDividerSize();
-      return new Dimension(dividerSize, dividerSize);
+      int divSize = getDividerSize();
+      return new Dimension(divSize, divSize);
     }
     else {
       Split split = (Split)root;
@@ -601,7 +662,7 @@ public class MultiSplitLayout implements LayoutManager
       int width = 0;
       int height = 0;
       if (split.isRowLayout()) {
-    		for(Node splitChild : splitChildren) {
+            for(Node splitChild : splitChildren) {
           if ( !splitChild.isVisible())
             continue;
           Dimension size = minimumNodeSize(splitChild);
@@ -610,7 +671,7 @@ public class MultiSplitLayout implements LayoutManager
         }
       }
       else {
-    		for(Node splitChild : splitChildren) {
+            for(Node splitChild : splitChildren) {
           if ( !splitChild.isVisible())
             continue;
           Dimension size = minimumNodeSize(splitChild);
@@ -638,8 +699,8 @@ public class MultiSplitLayout implements LayoutManager
     else if (root instanceof Divider) {
       if ( !((Divider)root).isVisible()  )
         return new Dimension(0,0);
-      int dividerSize = getDividerSize();
-      return new Dimension(dividerSize, dividerSize);
+      int divSize = getDividerSize();
+      return new Dimension(divSize, divSize);
     }
     else {
       Split split = (Split)root;
@@ -647,7 +708,7 @@ public class MultiSplitLayout implements LayoutManager
       int width = Integer.MAX_VALUE;
       int height = Integer.MAX_VALUE;
       if (split.isRowLayout()) {
-    	for(Node splitChild : splitChildren) {
+        for(Node splitChild : splitChildren) {
           if ( !splitChild.isVisible())
             continue;
           Dimension size = maximumNodeSize(splitChild);
@@ -656,7 +717,7 @@ public class MultiSplitLayout implements LayoutManager
         }
       }
       else {
-    	for(Node splitChild : splitChildren) {
+        for(Node splitChild : splitChildren) {
           if ( !splitChild.isVisible())
             continue;
           Dimension size = maximumNodeSize(splitChild);
@@ -736,7 +797,7 @@ public class MultiSplitLayout implements LayoutManager
       int totalWidth = 0;          // sum of the children's widths
       int minWeightedWidth = 0;    // sum of the weighted childrens' min widths
       int totalWeightedWidth = 0;  // sum of the weighted childrens' widths
-	    for(Node splitChild : split.getChildren()) {
+        for(Node splitChild : split.getChildren()) {
         if ( !splitChild.isVisible())
             continue;
         int nodeWidth = splitChild.getBounds().width;
@@ -809,7 +870,7 @@ public class MultiSplitLayout implements LayoutManager
       int totalHeight = 0;          // sum of the children's heights
       int minWeightedHeight = 0;    // sum of the weighted childrens' min heights
       int totalWeightedHeight = 0;  // sum of the weighted childrens' heights
-	    for(Node splitChild : split.getChildren()) {
+        for(Node splitChild : split.getChildren()) {
         if ( !splitChild.isVisible())
           continue;
         int nodeHeight = splitChild.getBounds().height;
@@ -1067,8 +1128,8 @@ public class MultiSplitLayout implements LayoutManager
       Split split = (Split)root;
       Iterator<Node> splitChildren = split.getChildren().iterator();
       Rectangle childBounds = null;
-      int dividerSize = getDividerSize();
-       boolean initSplit = false;
+      int divSize = getDividerSize();
+      boolean initSplit = false;
       
       
       /* Layout the Split's child Nodes' along the X axis.  The bounds
@@ -1114,7 +1175,7 @@ public class MultiSplitLayout implements LayoutManager
           if (( initSplit || getFloatingDividers()) && (dividerChild != null) && dividerChild.isVisible()) {
             double dividerX = childBounds.getMaxX();
             Rectangle dividerBounds;
-            dividerBounds = boundsWithXandWidth(bounds, dividerX, dividerSize);
+            dividerBounds = boundsWithXandWidth(bounds, dividerX, divSize);
             dividerChild.setBounds(dividerBounds);
           }
           if ((dividerChild != null) && dividerChild.isVisible()) {
@@ -1163,7 +1224,7 @@ public class MultiSplitLayout implements LayoutManager
           
           if (( initSplit || getFloatingDividers()) && (dividerChild != null) && dividerChild.isVisible()) {
             double dividerY = childBounds.getMaxY();
-            Rectangle dividerBounds = boundsWithYandHeight(bounds, dividerY, dividerSize);
+            Rectangle dividerBounds = boundsWithYandHeight(bounds, dividerY, divSize);
             dividerChild.setBounds(dividerBounds);
           }
           if ((dividerChild != null) && dividerChild.isVisible()) {
@@ -1303,7 +1364,7 @@ public class MultiSplitLayout implements LayoutManager
     }
     else if (root instanceof Split) {
       Split split = (Split)root;
-	    for(Node child : split.getChildren()) {
+        for(Node child : split.getChildren()) {
         if ( !child.isVisible())
           continue;
         if (child.getBounds().contains(x, y)) {
@@ -1335,8 +1396,8 @@ public class MultiSplitLayout implements LayoutManager
   
   private List<Divider> dividersThatOverlap(Node root, Rectangle r) {
     if (nodeOverlapsRectangle(root, r) && (root instanceof Split)) {
-	    List<Divider> dividers = new ArrayList();
-	    for(Node child : ((Split)root).getChildren()) {
+        List<Divider> dividers = new ArrayList();
+        for(Node child : ((Split)root).getChildren()) {
         if (child instanceof Divider) {
           if (nodeOverlapsRectangle(child, r)) {
             dividers.add((Divider)child);
@@ -1469,9 +1530,9 @@ public class MultiSplitLayout implements LayoutManager
     }
     
     private Node siblingAtOffset(int offset) {
-      Split parent = getParent();
-      if (parent == null) { return null; }
-      List<Node> siblings = parent.getChildren();
+      Split p = getParent();
+      if (p == null) { return null; }
+      List<Node> siblings = p.getChildren();
       int index = siblings.indexOf(this);
       if (index == -1) { return null; }
       index += offset;
@@ -1522,6 +1583,7 @@ public class MultiSplitLayout implements LayoutManager
      * @return the value of the rowLayout property.
      * @see #setRowLayout
      */
+    @Override
     public final boolean isRowLayout() { return true; }
   }
     
@@ -1542,6 +1604,7 @@ public class MultiSplitLayout implements LayoutManager
      * @return the value of the rowLayout property.
      * @see #setRowLayout
      */
+    @Override
     public final boolean isRowLayout() { return false; }
   }
 
@@ -1572,8 +1635,9 @@ public class MultiSplitLayout implements LayoutManager
      * @return <code>true</code> if the node is visible,
      * <code>false</code> otherwise
      */
+    @Override
     public boolean isVisible() {
-	    for(Node child : children) {
+        for(Node child : children) {
         if ( child.isVisible() && !( child instanceof Divider ))
           return true;
       }
@@ -1745,26 +1809,26 @@ public class MultiSplitLayout implements LayoutManager
       if (children == null) {
         throw new IllegalArgumentException("children must be a non-null List");
       }
-	    for(Node child : this.children) {
+        for(Node child : this.children) {
         child.setParent(null);
       }
 
       this.children = new ArrayList<Node>(children);
-	    for(Node child : this.children) {
+        for(Node child : this.children) {
         child.setParent(this);
       }
     }
        
-	/**
-	 * Convenience method for setting the children of this Split node.  The parent
-	 * of each new child is set to this Split node, and the parent
-	 * of each old child (if any) is set to null.  This method
-	 * defensively copies the incoming array.
-	 * 
-	 * @param children array of children
-	 * @see #getChildren
-	 * @throws IllegalArgumentException if children is null
-	 */
+    /**
+     * Convenience method for setting the children of this Split node.  The parent
+     * of each new child is set to this Split node, and the parent
+     * of each old child (if any) is set to null.  This method
+     * defensively copies the incoming array.
+     * 
+     * @param children array of children
+     * @see #getChildren
+     * @throws IllegalArgumentException if children is null
+     */
     public void setChildren(Node... children) {
         setChildren(children == null ? null : Arrays.asList(children));
     }
@@ -1778,9 +1842,9 @@ public class MultiSplitLayout implements LayoutManager
      * @see Node#getWeight
      */
     public final Node lastWeightedChild() {
-      List<Node> children = getChildren();
+      List<Node> kids = getChildren();
       Node weightedChild = null;
-	    for(Node child : children) {
+        for(Node child : kids) {
         if ( !child.isVisible())
           continue;
         if (child.getWeight() > 0.0) {
@@ -1811,6 +1875,7 @@ public class MultiSplitLayout implements LayoutManager
       this.name = name;
     }
         
+    @Override
     public String toString() {
       int nChildren = getChildren().size();
       StringBuffer sb = new StringBuffer("MultiSplitLayout.Split");
@@ -1873,6 +1938,7 @@ public class MultiSplitLayout implements LayoutManager
       this.name = name;
     }
     
+    @Override
     public String toString() {
       StringBuffer sb = new StringBuffer("MultiSplitLayout.Leaf");
       sb.append(" \"");
@@ -1908,10 +1974,12 @@ public class MultiSplitLayout implements LayoutManager
      * Dividers can't have a weight, they don't grow or shrink.
      * @throws UnsupportedOperationException
      */
+    @Override
     public void setWeight(double weight) {
       throw new UnsupportedOperationException();
     }
     
+    @Override
     public String toString() {
       return "MultiSplitLayout.Divider " + getBounds().toString();
     }
@@ -2093,7 +2161,7 @@ public class MultiSplitLayout implements LayoutManager
     if (root instanceof Split) {
       Split split = (Split)root;
       System.out.println(indent + split);
-	    for(Node child : split.getChildren()) {
+        for(Node child : split.getChildren()) {
         printModel(indent + "  ", child);
       }
     }
