@@ -1,5 +1,5 @@
 /*
- * $Id: HighlightPredicate.java,v 1.21 2008/05/15 11:12:47 kleopatra Exp $
+ * $Id: HighlightPredicate.java,v 1.26 2008/10/14 22:31:38 rah003 Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -17,7 +17,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
  */
 package org.jdesktop.swingx.decorator;
 
@@ -29,7 +28,7 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 
-import org.jdesktop.swingx.RolloverProducer;
+import org.jdesktop.swingx.rollover.RolloverProducer;
 import org.jdesktop.swingx.util.Contract;
 
 /**
@@ -38,6 +37,13 @@ import org.jdesktop.swingx.util.Contract;
  * This is a on/off <b>decision</b> only, the actual decoration is
  * left to the AbstractHighlighter which typically respects this predicate. <p>
  * 
+ * Note: implementations should be immutable because <code>Highlighter</code>s 
+ * guarantee to notify listeners on any state change which might effect the highlight. 
+ * They can't comply to that contract if predicate internal state changes under their 
+ * feet. If dynamic predicate state is required, the safe alternative is to create 
+ * and set a new predicate.<p>
+ * 
+ * 
  * @author Jeanette Winzenburg
  * 
  * @see AbstractHighlighter
@@ -103,13 +109,10 @@ public interface HighlightPredicate {
          * the row of its rollover property equals the adapter's row, returns
          * false otherwise.
          * 
-         * @see org.jdesktop.swingx.RolloverProducer
+         * @see org.jdesktop.swingx.rollover.RolloverProducer
          */
         public boolean isHighlighted(Component renderer, ComponentAdapter adapter) {
             if (!adapter.getComponent().isEnabled()) return false;
-            // JW: where to put constants? 
-            // this is a back-reference into swingx simply to access
-            // a string constant. Hmmm...
             Point p = (Point) adapter.getComponent().getClientProperty(
                     RolloverProducer.ROLLOVER_KEY);
             return p != null &&  p.y == adapter.row;
@@ -173,6 +176,19 @@ public interface HighlightPredicate {
         }
     };
     
+    /**
+     * Focus predicate.
+     */
+    public static final HighlightPredicate HAS_FOCUS = new HighlightPredicate() {
+        /**
+         * {@inheritDoc} <p>
+         * 
+         * Implemented to return truw if the given adapter hasFocus, false otherwise.
+         */
+        public boolean isHighlighted(Component renderer, ComponentAdapter adapter) {
+            return adapter.hasFocus();
+        }
+    };
     /**
      * Even rows.
      * 
@@ -228,6 +244,11 @@ public interface HighlightPredicate {
         }
         
     };
+
+    // PENDING: these general type empty arrays don't really belong here?
+    public static final HighlightPredicate[] EMPTY_PREDICATE_ARRAY = new HighlightPredicate[0];
+    public static final Object[] EMPTY_OBJECT_ARRAY = new Object[0];
+    public static final Integer[] EMPTY_INTEGER_ARRAY = new Integer[0];
     
 //----------------- logical implementations amongst HighlightPredicates
     
@@ -256,7 +277,14 @@ public interface HighlightPredicate {
         public boolean isHighlighted(Component renderer, ComponentAdapter adapter) {
             return !predicate.isHighlighted(renderer, adapter);
         }
-        
+
+        /**
+         * @return the contained HighlightPredicate.
+         */
+        public HighlightPredicate getHighlightPredicate() {
+            return predicate;
+        }
+
     }
     
     /**
@@ -295,6 +323,15 @@ public interface HighlightPredicate {
             }
             return !predicate.isEmpty();
         }
+
+        /**
+         * @return the contained HighlightPredicates.
+         */
+        public HighlightPredicate[] getHighlightPredicates() {
+            if (predicate.isEmpty()) return EMPTY_PREDICATE_ARRAY;
+            return predicate.toArray(new HighlightPredicate[predicate.size()]);
+        }
+        
         
     }
     
@@ -334,6 +371,13 @@ public interface HighlightPredicate {
             }
             return false;
         }
+        /**
+         * @return 
+         */
+        public HighlightPredicate[] getHighlightPredicates() {
+            if (predicate.isEmpty()) return EMPTY_PREDICATE_ARRAY;
+            return predicate.toArray(new HighlightPredicate[predicate.size()]);
+        }
         
     }
     
@@ -365,6 +409,14 @@ public interface HighlightPredicate {
             // JW: oddness check is okay - adapter.row must be a valid view coordinate
             return (adapter.row / linesPerGroup) % 2 == 1;
         }
+
+        /**
+         * 
+         * @return the number of lines per group.
+         */
+        public int getLinesPerGroup() {
+            return linesPerGroup;
+        }
         
     }
     
@@ -399,6 +451,16 @@ public interface HighlightPredicate {
             int modelIndex = adapter.viewToModel(adapter.column);
             return columnList.contains(modelIndex);
         }
+
+        /**
+         * PENDING JW: get array of int instead of Integer?
+         * 
+         * @return the columns indices in model coordinates to highlight
+         */
+        public Integer[] getColumns() {
+            if (columnList.isEmpty()) return EMPTY_INTEGER_ARRAY;
+            return columnList.toArray(new Integer[columnList.size()]);
+        }
         
     }
     
@@ -435,6 +497,14 @@ public interface HighlightPredicate {
             Object identifier = adapter.getColumnIdentifierAt(modelIndex);
             return identifier != null ? columnList.contains(identifier) : false;
         }
+
+        /**
+         * @return the identifiers
+         */
+        public Object[] getIdentifiers() {
+            if (columnList.isEmpty()) return EMPTY_OBJECT_ARRAY;
+            return columnList.toArray(new Object[0]);
+        }
         
     }
     
@@ -446,33 +516,42 @@ public interface HighlightPredicate {
      * @author Karl Schaefer
      */
     public static class DepthHighlightPredicate implements HighlightPredicate {
-    	private List<Integer> depthList;
-    	
+        private List<Integer> depthList;
+        
         /**
          * Instantiates a predicate which returns true for the
          * given depths.
          * 
          * @param depths the depths to highlight
          */
-    	public DepthHighlightPredicate(int... depths) {
-    		depthList = new ArrayList<Integer>();
+        public DepthHighlightPredicate(int... depths) {
+            depthList = new ArrayList<Integer>();
             for (int i = 0; i < depths.length; i++) {
                 depthList.add(depths[i]);
             }
-    	}
-    	
+        }
+        
         /**
          * {@inheritDoc}
          * 
-         * This implementation returns true if the adapter's depth
-         * is contained in this predicates list.
+         * This implementation returns true if the adapter's depth is contained
+         * in this predicates list.
          * 
          */
-		public boolean isHighlighted(Component renderer, ComponentAdapter adapter) {
+        public boolean isHighlighted(Component renderer,
+                ComponentAdapter adapter) {
             int depth = adapter.getDepth();
             return depthList.contains(depth);
-		}
-    	
+        }
+
+        /**
+         * @return
+         */
+        public Integer[] getDepths() {
+            if (depthList.isEmpty()) return EMPTY_INTEGER_ARRAY;
+            return depthList.toArray(new Integer[depthList.size()]);
+        }
+        
     }
     
     //--------------------- value testing
@@ -494,6 +573,7 @@ public interface HighlightPredicate {
         }
         /**
          * Instantitates a predicate with the given compare value.
+         * PENDING JW: support array? 
          * @param compareValue the fixed value to compare the 
          *   adapter against.
          */
@@ -512,6 +592,13 @@ public interface HighlightPredicate {
             return compareValue.equals(adapter.getValue());
         }
         
+        /**
+         * @return the value this predicate checks against.
+         */
+        public Object getCompareValue() {
+            return compareValue;
+        }
+        
     }
 
     /**
@@ -520,7 +607,7 @@ public interface HighlightPredicate {
      */
     public static class TypeHighlightPredicate implements HighlightPredicate {
 
-        private Class clazz;
+        private Class<?> clazz;
         
         /**
          * Instantitates a predicate with Object.clazz. This is essentially the
@@ -531,7 +618,10 @@ public interface HighlightPredicate {
             this(Object.class);
         }
         /**
-         * Instantitates a predicate with the given compare class.
+         * Instantitates a predicate with the given compare class.<p>
+         * 
+         * PENDING JW: support array? 
+         * 
          * @param compareValue the fixed class to compare the 
          *   adapter value against.
          */
@@ -549,6 +639,12 @@ public interface HighlightPredicate {
             return adapter.getValue() != null ? 
                     clazz.isAssignableFrom(adapter.getValue().getClass()) : false;
         }
+        /**
+         * @return
+         */
+        public Class<?> getType() {
+            return clazz;
+        }
         
     }
 
