@@ -1,5 +1,5 @@
 /*
- * $Id: BasicDatePickerUI.java,v 1.78 2008/02/21 14:29:27 kleopatra Exp $
+ * $Id: BasicDatePickerUI.java,v 1.83 2008/10/30 16:38:41 kleopatra Exp $
  * 
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -26,6 +26,7 @@ import java.awt.Container;
 import java.awt.Dimension;
 import java.awt.FontMetrics;
 import java.awt.Insets;
+import java.awt.KeyboardFocusManager;
 import java.awt.LayoutManager;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
@@ -62,14 +63,13 @@ import javax.swing.JFormattedTextField.AbstractFormatter;
 import javax.swing.JFormattedTextField.AbstractFormatterFactory;
 import javax.swing.border.Border;
 import javax.swing.plaf.ComponentUI;
-import javax.swing.plaf.InsetsUIResource;
 import javax.swing.plaf.UIResource;
-import javax.swing.text.DefaultCaret;
 import javax.swing.text.DefaultFormatterFactory;
 import javax.swing.text.View;
 
 import org.jdesktop.swingx.JXDatePicker;
 import org.jdesktop.swingx.JXMonthView;
+import org.jdesktop.swingx.SwingXUtilities;
 import org.jdesktop.swingx.calendar.CalendarUtils;
 import org.jdesktop.swingx.calendar.DatePickerFormatter;
 import org.jdesktop.swingx.calendar.DateSelectionModel;
@@ -123,6 +123,8 @@ public class BasicDatePickerUI extends DatePickerUI {
     private ActionListener monthViewActionListener;
     private PropertyChangeListener monthViewPropertyListener;
 
+    private PopupRemover popupRemover;
+
 
     @SuppressWarnings({"UnusedDeclaration"})
     public static ComponentUI createUI(JComponent c) {
@@ -209,8 +211,15 @@ public class BasicDatePickerUI extends DatePickerUI {
         }
     }
 
+    /**
+     * Installs DatePicker default properties.
+     */
     protected void installDefaults() {
-
+        // PENDING JW: currently this is for testing only. 
+        boolean zoomable = Boolean.TRUE.equals(UIManager.get("JXDatePicker.forceZoomable")); 
+        if (zoomable) {
+            datePicker.getMonthView().setZoomable(true);
+        }
     }
 
     protected void uninstallDefaults() {
@@ -313,6 +322,7 @@ public class BasicDatePickerUI extends DatePickerUI {
         monthViewActionListener = createMonthViewActionListener();
         monthViewPropertyListener = createMonthViewPropertyListener();
         
+        popupRemover = new PopupRemover();
         /*
          * install the listeners
          */
@@ -336,7 +346,6 @@ public class BasicDatePickerUI extends DatePickerUI {
         //
         updateFromMonthViewChanged(null);
     }
-    
     /**
      * Uninstalls and nulls all listeners which had been installed 
      * by this delegate.
@@ -364,6 +373,9 @@ public class BasicDatePickerUI extends DatePickerUI {
             popupButton.removeMouseMotionListener(mouseMotionListener);
         }
 
+        popupRemover.unload();
+        
+        popupRemover = null;
         propertyChangeListener = null;
         mouseListener = null;
         mouseMotionListener = null;
@@ -772,6 +784,36 @@ public class BasicDatePickerUI extends DatePickerUI {
     }
 
     //---------------------- updating other properties
+
+    
+    /**
+     * Updates properties which depend on the picker's editable. <p>
+     * 
+     */
+    protected void updateFromEditableChanged() {
+        boolean isEditable = datePicker.isEditable();
+        datePicker.getMonthView().setEnabled(isEditable);
+        datePicker.getEditor().setEditable(isEditable);
+        /*
+         * PatrykRy: Commit today date is not allowed if datepicker is not editable!
+         */
+        setActionEnabled(JXDatePicker.HOME_COMMIT_KEY, isEditable);
+        // for consistency, synch navigation as well 
+        setActionEnabled(JXDatePicker.HOME_NAVIGATE_KEY, isEditable);
+    }
+
+    /**
+     * 
+     * @param key
+     * @param enabled
+     */
+    private void setActionEnabled(String key, boolean enabled) {
+        Action action = datePicker.getActionMap().get(key);
+        if (action != null) {
+            action.setEnabled(enabled);
+        }
+    }
+
     /**
      * Updates the picker's formats to the given TimeZone.
      * @param zone the timezone to set on the formats.
@@ -871,12 +913,19 @@ public class BasicDatePickerUI extends DatePickerUI {
     }
 
     /**
-     * 
+     * PENDING: widened access for debugging - need api to
+     * control popup visibility?
      */
-    private void hidePopup() {
+    public void hidePopup() {
         if (popup != null) popup.setVisible(false);
     }
 
+    public boolean isPopupVisible() {
+        if (popup != null) {
+            return popup.isVisible();
+        }
+        return false;
+    }
     /**
      * Navigates to linkDate. If commit, the linkDate is selected
      * and committed. If not commit, the linkDate is scrolled to visible, if the 
@@ -1201,9 +1250,7 @@ public class BasicDatePickerUI extends DatePickerUI {
                 popupButton.setEnabled(isEnabled);
                 datePicker.getEditor().setEnabled(isEnabled);
             } else if ("editable".equals(property)) {
-                boolean isEditable = datePicker.isEditable();
-                datePicker.getMonthView().setEnabled(isEditable);
-                datePicker.getEditor().setEditable(isEditable);
+                updateFromEditableChanged();
             } else if (JComponent.TOOL_TIP_TEXT_KEY.equals(property)) {
                 String tip = datePicker.getToolTipText();
                 datePicker.getEditor().setToolTipText(tip);
@@ -1241,7 +1288,7 @@ public class BasicDatePickerUI extends DatePickerUI {
                 updateFromSelectionModelChanged((DateSelectionModel) e.getOldValue());
             } else if ("timeZone".equals(e.getPropertyName())) {
                 updateTimeZone((TimeZone) e.getOldValue());
-            } else if ("todayInMillis".equals(e.getPropertyName())) {
+            } else if ("today".equals(e.getPropertyName())) {
                 updateLinkDate();
             }
         }
@@ -1338,8 +1385,8 @@ public class BasicDatePickerUI extends DatePickerUI {
          */
         public void focusGained(FocusEvent e) {
             if (e.isTemporary()) return;
+            popupRemover.load();
             if (e.getSource() == datePicker) {
-//                LOG.info("focusGained in ui " + e.getSource().getClass().getSimpleName() );
                datePicker.getEditor().requestFocusInWindow(); 
             }
         }
@@ -1362,20 +1409,70 @@ public class BasicDatePickerUI extends DatePickerUI {
          * transferred permanently from the temporary focusowner
          * to a new "normal" permanentFocusOwner (like a textfield),
          * we don't get it if transfered to a tricksing owner (like
-         * a combo or picker) 
+         * a combo or picker). So can't do anything here. 
          * 
          * listen to keyboardFocusManager?
          */
         public void focusLost(FocusEvent e) {
-//            LOG.info("lost - old " + e);
-//            if (e.isTemporary()) return;
-//            if (e.getSource() == datePicker.getEditor()) {
-//                hidePopup();
-//            }
             
         }
     }
 
+    public class PopupRemover implements PropertyChangeListener {
+
+        private KeyboardFocusManager manager;
+        private boolean loaded;
+        
+        public void load() {
+            if (manager != KeyboardFocusManager.getCurrentKeyboardFocusManager()) {
+                unload();
+                manager = KeyboardFocusManager.getCurrentKeyboardFocusManager();
+            }
+            if (!loaded) {
+                manager.addPropertyChangeListener("permanentFocusOwner", this);
+                loaded = true;
+            }
+        }
+        
+        /**
+         * @param b
+         */
+        private void unload(boolean nullManager) {
+            if (manager != null) {
+                manager.removePropertyChangeListener("permanentFocusOwner", this);
+                if (nullManager) {
+                    manager = null;
+                }
+            }
+            loaded = false;
+         }
+
+        public void unload() {
+            unload(true);
+        }
+        
+        public void propertyChange(PropertyChangeEvent evt) {
+            if (!isPopupVisible()) {
+                unload(false);
+                return;
+            }
+            Component comp = manager.getPermanentFocusOwner();
+            if ((comp != null) && !SwingXUtilities.isDescendingFrom(comp, datePicker)) {
+                 unload(false);
+                // on hiding the popup the focusmanager transfers 
+                // focus back to the old permanentFocusOwner
+                // before showing the popup, that is the picker
+                // or the editor. So we have to force it back ... 
+                hidePopup();
+                comp.requestFocusInWindow();
+                // this has no effect as focus changes are asynchronous
+//                inHide = false;
+            }
+        }
+        
+        
+    }
+
     
 //  ------------------ listener creation
 
