@@ -1,5 +1,5 @@
 /*
- * $Id: BasicHeaderUI.java,v 1.24 2008/02/29 08:35:12 rah003 Exp $
+ * $Id: BasicHeaderUI.java,v 1.31 2008/10/14 22:31:43 rah003 Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -21,6 +21,31 @@
 
 package org.jdesktop.swingx.plaf.basic;
 
+import java.awt.Color;
+import java.awt.Container;
+import java.awt.Font;
+import java.awt.GradientPaint;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.RenderingHints;
+import java.awt.event.HierarchyBoundsAdapter;
+import java.awt.event.HierarchyBoundsListener;
+import java.awt.event.HierarchyEvent;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
+import java.util.logging.Logger;
+
+import javax.swing.JComponent;
+import javax.swing.JLabel;
+import javax.swing.UIManager;
+import javax.swing.plaf.ComponentUI;
+import javax.swing.plaf.UIResource;
+import javax.swing.plaf.basic.BasicHTML;
+import javax.swing.text.View;
+
 import org.jdesktop.swingx.JXHeader;
 import org.jdesktop.swingx.JXLabel;
 import org.jdesktop.swingx.JXHeader.IconPosition;
@@ -28,44 +53,53 @@ import org.jdesktop.swingx.painter.MattePainter;
 import org.jdesktop.swingx.painter.Painter;
 import org.jdesktop.swingx.plaf.HeaderUI;
 import org.jdesktop.swingx.plaf.PainterUIResource;
-
-import javax.swing.*;
-import javax.swing.plaf.ColorUIResource;
-import javax.swing.plaf.ComponentUI;
-import javax.swing.plaf.FontUIResource;
-import javax.swing.plaf.basic.BasicHTML;
-import javax.swing.text.View;
-
-import java.awt.*;
-import java.awt.event.HierarchyBoundsAdapter;
-import java.awt.event.HierarchyBoundsListener;
-import java.awt.event.HierarchyEvent;
-import java.beans.PropertyChangeEvent;
-import java.beans.PropertyChangeListener;
+import org.jdesktop.swingx.plaf.UIManagerExt;
 
 /**
- *
+ * Base implementation of <code>Header</code> UI. <p>
+ * 
+ * PENDING JW: This implementation is unusual in that it does not keep a reference
+ * to the component it controls. Typically, such is only the case if the ui is
+ * shared between instances. Historical? A consequence is that the un/install methods 
+ * need to carry the header as parameter. Which looks funny when at the same time 
+ * the children of the header are instance fields in this. Should think about cleanup:
+ * either get rid off the instance fields here, or reference the header and remove
+ * the param (would break subclasses).<p>
+ * 
+ * PENDING JW: keys for uidefaults are inconsistent - most have prefix "JXHeader." while
+ * defaultIcon has prefix "Header." <p>
+ * 
  * @author rbair
  * @author rah003
+ * @author Jeanette Winzenburg
  */
 public class BasicHeaderUI extends HeaderUI {
-	// Implementation detail. Neeeded to expose getMultiLineSupport() method to allow restoring view
-	// lost after LAF switch 
+    @SuppressWarnings("unused")
+    private static final Logger LOG = Logger.getLogger(BasicHeaderUI.class
+            .getName());
+    // Implementation detail. Neeeded to expose getMultiLineSupport() method to allow restoring view
+    // lost after LAF switch
     protected class DescriptionPane extends JXLabel {
             @Override
             public void paint(Graphics g) {
+//                LOG.info(getText() + ": all hints " + ((Graphics2D)g).getRenderingHints()
+//                        + "\n     " + ": aliased " + ((Graphics2D)g).getRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING));
                 // switch off jxlabel default antialiasing
+                // JW: that cost me dearly to track down - it's the default foreground painter
+                // which is an AbstractPainter which has _global_ antialiased on by default
+                // and here the _text_ antialiased is turned off
                 ((Graphics2D)g).setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING,
                         RenderingHints.VALUE_TEXT_ANTIALIAS_OFF);
                 super.paint(g);
             }
-            
-            public MultiLineSupport getMultiLineSupport() {
-            	return super.getMultiLineSupport();
-            }
-	}
 
-	protected JLabel titleLabel;
+            @Override
+            public MultiLineSupport getMultiLineSupport() {
+                return super.getMultiLineSupport();
+            }
+    }
+
+    protected JLabel titleLabel;
     protected DescriptionPane descriptionPane;
     protected JLabel imagePanel;
     private PropertyChangeListener propListener;
@@ -122,16 +156,7 @@ public class BasicHeaderUI extends HeaderUI {
         assert c instanceof JXHeader;
         JXHeader header = (JXHeader)c;
 
-        titleLabel = new JLabel();
-        descriptionPane = new DescriptionPane();
-        descriptionPane.setLineWrap(true);
-        descriptionPane.setOpaque(false);
-
         installDefaults(header);
-
-        imagePanel = new JLabel();
-        imagePanel.setIcon(header.getIcon() == null ? UIManager.getIcon("Header.defaultIcon") : header.getIcon());
-        
         installComponents(header);
         installListeners(header);
     }
@@ -166,71 +191,182 @@ public class BasicHeaderUI extends HeaderUI {
         assert c instanceof JXHeader;
         JXHeader header = (JXHeader)c;
 
-        uninstallDefaults(header);
         uninstallListeners(header);
         uninstallComponents(header);
+        uninstallDefaults(header);
+    }
 
+    /**
+     * Installs default header properties.
+     * <p>
+     * 
+     * NOTE: this method is called before the children are created, so must not
+     * try to access any of those!.
+     * 
+     * @param the header to install.
+     */
+    protected void installDefaults(JXHeader h) {
+        gradientLightColor = UIManagerExt.getColor("JXHeader.startBackground");
+        if (gradientLightColor == null) {
+            // fallback to white
+            gradientLightColor = Color.WHITE;
+        }
+        gradientDarkColor = UIManagerExt.getColor("JXHeader.background");
+        // for backwards compatibility (mostly for substance and synthetica,
+        // I suspect) I'll fall back on the "control" color if
+        // JXHeader.background
+        // isn't specified.
+        if (gradientDarkColor == null) {
+            gradientDarkColor = UIManagerExt.getColor("control");
+        }
+
+        if (isUIInstallable(h.getBackgroundPainter())) {
+            h.setBackgroundPainter(createBackgroundPainter());
+        }
+
+        // title properties
+        if (isUIInstallable(h.getTitleFont())) {
+            Font titleFont = UIManager.getFont("JXHeader.titleFont");
+            // fallback to label font
+            h.setTitleFont(titleFont != null ? titleFont : UIManager
+                    .getFont("Label.font"));
+        }
+        if (isUIInstallable(h.getTitleForeground())) {
+            Color titleForeground = UIManagerExt
+                    .getColor("JXHeader.titleForeground");
+            // fallback to label foreground
+            h.setTitleForeground(titleForeground != null ? titleForeground
+                    : UIManagerExt.getColor("Label.foreground"));
+        }
+
+        // description properties
+        if (isUIInstallable(h.getDescriptionFont())) {
+            Font descFont = UIManager.getFont("JXHeader.descriptionFont");
+            // fallback to label font
+            h.setDescriptionFont(descFont != null ? descFont : UIManager
+                    .getFont("Label.font"));
+        }
+        if (isUIInstallable(h.getDescriptionForeground())) {
+            Color descForeground = UIManagerExt
+                    .getColor("JXHeader.descriptionForeground");
+            // fallback to label foreground
+            h.setDescriptionForeground(descForeground != null ? descForeground
+                    : UIManagerExt.getColor("Label.foreground"));
+        }
+        
+        // icon label properties
+        if (isUIInstallable(h.getIcon())) {
+            h.setIcon(UIManager.getIcon("Header.defaultIcon"));
+        }
+    }
+    
+    /**
+     * Uninstalls the given header's default properties. This implementation
+     * does nothing.
+     * 
+     * @param h the header to ininstall the properties from.
+     */
+    protected void uninstallDefaults(JXHeader h) {
+    }
+
+    /**
+     * Creates, configures, adds contained components.
+     * PRE: header's default properties must be set before calling this.
+     * 
+     * @param the header to install the components into.
+     */
+    protected void installComponents(JXHeader h) {
+        titleLabel = new JLabel();
+        descriptionPane = new DescriptionPane();
+        imagePanel = new JLabel();
+        installComponentDefaults(h);
+        h.setLayout(new GridBagLayout());
+        resetLayout(h);
+    }
+
+    /**
+     * Unconfigures, removes and nulls contained components.
+     * 
+     * @param the header to install the components into.
+     */
+    protected void uninstallComponents(JXHeader h) {
+        uninstallComponentDefaults(h);
+        h.remove(titleLabel);
+        h.remove(descriptionPane);
+        h.remove(imagePanel);
         titleLabel = null;
         descriptionPane = null;
         imagePanel = null;
     }
 
-    protected void installDefaults(JXHeader h) {
-        gradientLightColor = UIManager.getColor("JXHeader.startBackground");
-        if (gradientLightColor == null) {
-        	// fallback to white
-        	gradientLightColor = Color.WHITE;
-        }
-        gradientDarkColor = UIManager.getColor("JXHeader.background");
-        //for backwards compatibility (mostly for substance and synthetica,
-        //I suspect) I'll fall back on the "control" color if JXHeader.background
-        //isn't specified.
-        if (gradientDarkColor == null) {
-            gradientDarkColor = UIManager.getColor("control"); 
-        }
-        
-        Painter p = h.getBackgroundPainter();
-        if (p == null || p instanceof PainterUIResource) {
-            h.setBackgroundPainter(createBackgroundPainter());
-        }
- 
-        // title properties
-        Font titleFont = h.getTitleFont();
-        if (titleFont == null || titleFont instanceof FontUIResource) {
-        	titleFont = UIManager.getFont("JXHeader.titleFont");
-        	// fallback to label font
-        	titleLabel.setFont(titleFont != null ? titleFont : UIManager.getFont("Label.font"));
-        }
-        
-        Color titleForeground = h.getTitleForeground();
-        if (titleForeground == null || titleForeground instanceof ColorUIResource) {
-        	titleForeground = UIManager.getColor("JXHeader.titleForeground");
-        	// fallback to label foreground
-        	titleLabel.setForeground(titleForeground != null ? titleForeground : UIManager.getColor("Label.foreground"));
-        }
-
+    /**
+     * Configures the component default properties from the given header.
+     * 
+     * @param the header to install the components into.
+     */
+    protected void installComponentDefaults(JXHeader h) {
+        // JW: force a not UIResource for properties which have ui default values
+        // like color, font, ??
+        titleLabel.setFont(getAsNotUIResource(h.getTitleFont()));
+        titleLabel.setForeground(getAsNotUIResource(h.getTitleForeground()));
         titleLabel.setText(h.getTitle());
-        
-        // description properties
-        Font descFont = h.getDescriptionFont();
-        if (descFont == null || descFont instanceof FontUIResource) {
-        	descFont = UIManager.getFont("JXHeader.descriptionFont");
-        	// fallback to label font
-        	descriptionPane.setFont(descFont != null ? descFont : UIManager.getFont("Label.font"));
-        }
-            
-        Color descForeground = h.getDescriptionForeground();
-        if (descForeground == null || descForeground instanceof ColorUIResource) {
-        	descForeground = UIManager.getColor("JXHeader.descriptionForeground");
-        	// fallback to label foreground
-        	descriptionPane.setForeground(descForeground != null ? descForeground : UIManager.getColor("Label.foreground"));
-        }
-        
+        descriptionPane.setFont(getAsNotUIResource(h.getDescriptionFont()));
+        descriptionPane.setForeground(getAsNotUIResource(h.getDescriptionForeground()));
+        descriptionPane.setOpaque(false);
         descriptionPane.setText(h.getDescription());
+        descriptionPane.setLineWrap(true);
+
+        imagePanel.setIcon(h.getIcon());
+
+    }
+    
+    /**
+     * Returns a Font based on the param which is not of type UIResource. 
+     * 
+     * @param font the base font
+     * @return a font not of type UIResource, may be null.
+     */
+    private Font getAsNotUIResource(Font font) {
+        if (!(font instanceof UIResource)) return font;
+        // PENDING JW: correct way to create another font instance?
+       return font.deriveFont(font.getAttributes());
+    }
+    
+    /**
+     * Returns a Color based on the param which is not of type UIResource. 
+     * 
+     * @param color the base color
+     * @return a color not of type UIResource, may be null.
+     */
+    private Color getAsNotUIResource(Color color) {
+        if (!(color instanceof UIResource)) return color;
+        // PENDING JW: correct way to create another color instance?
+        float[] rgb = color.getRGBComponents(null);
+        return new Color(rgb[0], rgb[1], rgb[2], rgb[3]);
+    }
+    
+    /**
+     * Checks and returns whether the given property should be replaced
+     * by the UI's default value.<p>
+     * 
+     * PENDING JW: move as utility method ... where?
+     * 
+     * @param property the property to check.
+     * @return true if the given property should be replaced by the UI#s
+     *   default value, false otherwise. 
+     */
+    private boolean isUIInstallable(Object property) {
+       return (property == null) || (property instanceof UIResource);
+    }
+    
+    /**
+     * Uninstalls component defaults. This implementation does nothing.
+     * 
+     * @param the header to uninstall from.
+     */
+    protected void uninstallComponentDefaults(JXHeader h) {
     }
 
-    protected void uninstallDefaults(JXHeader h) {
-    }
 
     protected void installListeners(final JXHeader header) {
         propListener = new PropertyChangeListener() {
@@ -239,21 +375,30 @@ public class BasicHeaderUI extends HeaderUI {
             }
         };
         boundsListener = new HierarchyBoundsAdapter() {
+            @Override
             public void ancestorResized(HierarchyEvent e) {
                 if (header == e.getComponent()) {
                     View v = (View) descriptionPane.getClientProperty(BasicHTML.propertyKey);
                     // view might get lost on LAF change ...
                     if (v == null) {
-                    	descriptionPane.putClientProperty(BasicHTML.propertyKey, descriptionPane.getMultiLineSupport().createView(descriptionPane));
-                    	v = (View) descriptionPane.getClientProperty(BasicHTML.propertyKey);
+                        descriptionPane.putClientProperty(BasicHTML.propertyKey, 
+                                descriptionPane.getMultiLineSupport().createView(descriptionPane));
+                        v = (View) descriptionPane.getClientProperty(BasicHTML.propertyKey);
                     }
                     if (v != null) {
-                        int h = Math.max(descriptionPane.getHeight(), header.getTopLevelAncestor().getHeight());
-                        int w = Math.min(header.getTopLevelAncestor().getWidth(), header.getParent().getWidth());
+                        Container tla = header.getTopLevelAncestor();
+                        if (tla == null) {
+                            tla = header.getParent();
+                            while (tla.getParent() != null) {
+                                tla = tla.getParent();
+                            }
+                        }
+                        int h = Math.max(descriptionPane.getHeight(), tla.getHeight());
+                        int w = Math.min(tla.getWidth(), header.getParent().getWidth());
                         // 35 = description pane insets, TODO: obtain dynamically
                         w -= 35 + header.getInsets().left + header.getInsets().right + descriptionPane.getInsets().left + descriptionPane.getInsets().right + imagePanel.getInsets().left + imagePanel.getInsets().right + imagePanel.getWidth() + descriptionPane.getBounds().x;
-                    	v.setSize(w, h);
-                    	descriptionPane.setSize(w, (int) Math.ceil(v.getPreferredSpan(View.Y_AXIS)));
+                        v.setSize(w, h);
+                        descriptionPane.setSize(w, (int) Math.ceil(v.getPreferredSpan(View.Y_AXIS)));
                     }
                 }
             }};
@@ -291,35 +436,28 @@ public class BasicHeaderUI extends HeaderUI {
         }
     }
 
-    protected void installComponents(JXHeader h) {
-        h.setLayout(new GridBagLayout());
-        resetLayout(h);
-    }
-
     private void resetLayout(JXHeader h) {
-    	h.remove(titleLabel);
-    	h.remove(descriptionPane);
-    	h.remove(imagePanel);
-    	if (h.getIconPosition() == null || h.getIconPosition() == IconPosition.RIGHT) {
-	        h.add(titleLabel, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.HORIZONTAL, new Insets(12, 12, 0, 11), 0, 0));
-	        h.add(descriptionPane, new GridBagConstraints(0, 1, 1, 1, 1.0, 1.0, GridBagConstraints.FIRST_LINE_START, GridBagConstraints.BOTH, new Insets(0, 24, 12, 11), 0, 0));
-	        h.add(imagePanel, new GridBagConstraints(1, 0, 1, 2, 0.0, 1.0, GridBagConstraints.FIRST_LINE_END, GridBagConstraints.NONE, new Insets(12, 0, 11, 11), 0, 0));
-    	} else {
-	        h.add(titleLabel, new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.HORIZONTAL, new Insets(12, 12, 0, 11), 0, 0));
-	        h.add(descriptionPane, new GridBagConstraints(1, 1, 1, 1, 1.0, 1.0, GridBagConstraints.FIRST_LINE_START, GridBagConstraints.BOTH, new Insets(0, 24, 12, 11), 0, 0));
-	        h.add(imagePanel, new GridBagConstraints(0, 0, 1, 2, 0.0, 1.0, GridBagConstraints.FIRST_LINE_END, GridBagConstraints.NONE, new Insets(12, 11, 0, 11), 0, 0));
-    	}
-	}
-
-	protected void uninstallComponents(JXHeader h) {
         h.remove(titleLabel);
         h.remove(descriptionPane);
         h.remove(imagePanel);
+        if (h.getIconPosition() == null || h.getIconPosition() == IconPosition.RIGHT) {
+            h.add(titleLabel, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.HORIZONTAL, new Insets(12, 12, 0, 11), 0, 0));
+            h.add(descriptionPane, new GridBagConstraints(0, 1, 1, 1, 1.0, 1.0, GridBagConstraints.FIRST_LINE_START, GridBagConstraints.BOTH, new Insets(0, 24, 12, 11), 0, 0));
+            h.add(imagePanel, new GridBagConstraints(1, 0, 1, 2, 0.0, 1.0, GridBagConstraints.FIRST_LINE_END, GridBagConstraints.NONE, new Insets(12, 0, 11, 11), 0, 0));
+        } else {
+            h.add(titleLabel, new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0, GridBagConstraints.LINE_START, GridBagConstraints.HORIZONTAL, new Insets(12, 12, 0, 11), 0, 0));
+            h.add(descriptionPane, new GridBagConstraints(1, 1, 1, 1, 1.0, 1.0, GridBagConstraints.FIRST_LINE_START, GridBagConstraints.BOTH, new Insets(0, 24, 12, 11), 0, 0));
+            h.add(imagePanel, new GridBagConstraints(0, 0, 1, 2, 0.0, 1.0, GridBagConstraints.FIRST_LINE_END, GridBagConstraints.NONE, new Insets(12, 11, 0, 11), 0, 0));
+        }
     }
+    
+    
 
     protected Painter createBackgroundPainter() {
         MattePainter p = new MattePainter(new GradientPaint(0, 0, gradientLightColor, 1, 0, gradientDarkColor));
         p.setPaintStretched(true);
         return new PainterUIResource(p);
     }
+    
+    
 }
