@@ -1,5 +1,5 @@
 /*
- * $Id: TableColumnExt.java,v 1.23 2008/03/20 18:27:42 kschaefe Exp $
+ * $Id: TableColumnExt.java,v 1.30 2008/10/14 22:31:40 rah003 Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -20,11 +20,15 @@
  */
 
 package org.jdesktop.swingx.table;
+import java.awt.Component;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.util.Comparator;
 import java.util.Hashtable;
 
+import javax.swing.DefaultCellEditor;
+import javax.swing.JComponent;
+import javax.swing.SwingUtilities;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.table.TableCellEditor;
@@ -33,22 +37,23 @@ import javax.swing.table.TableColumn;
 
 import org.jdesktop.swingx.decorator.CompoundHighlighter;
 import org.jdesktop.swingx.decorator.Highlighter;
-import org.jdesktop.swingx.util.Contract;
+import org.jdesktop.swingx.decorator.UIDependent;
+import org.jdesktop.swingx.renderer.AbstractRenderer;
 
 /**
  * <code>TableColumn</code> extension for enhanced view column configuration.
  * The general drift is to strengthen the TableColumn abstraction as <b>the</b>
  * place to configure and dynamically update view column properties, covering a
- * broad range of customization requirements. Using collaborators are 
- * expected to listen to property changes and update themselves accordingly.
+ * broad range of customization requirements. Using collaborators are expected
+ * to listen to property changes and update themselves accordingly.
  * <p>
  * 
- * A functionality enhancement is the notion of column visibility: 
- * <code>TableColumnModelExt</code> manages sets of visible/hidden 
- * <code>TableColumnExt</code>s controlled by the columns' <code>visible</code>
- * property. Typically, users can toggle column visibility at runtime, f.i.
- * through a dedicated control in the upper trailing corner of a 
- * <code>JScrollPane</code>.
+ * A functionality enhancement is the notion of column visibility:
+ * <code>TableColumnModelExt</code> manages sets of visible/hidden
+ * <code>TableColumnExt</code>s controlled by the columns'
+ * <code>visible</code> property. Typically, users can toggle column
+ * visibility at runtime, f.i. through a dedicated control in the upper trailing
+ * corner of a <code>JScrollPane</code>.
  * <p>
  * 
  * A prominent group of properties allows fine-grained, per-column control of
@@ -56,8 +61,8 @@ import org.jdesktop.swingx.util.Contract;
  * 
  * <ul>
  * <li><b>Sorting</b>: <code>sortable</code> controls whether this column
- * should be sortable by user's sort gestures; <code>Comparator</code> can hold a
- * column specific type.
+ * should be sortable by user's sort gestures; <code>Comparator</code> can
+ * hold a column specific type.
  * 
  * <li><b>Editing</b>: <code>editable</code> controls whether cells of this
  * column should be accessible to in-table editing.
@@ -67,9 +72,11 @@ import org.jdesktop.swingx.util.Contract;
  * 
  * <li><b>Highlighter</b>: <code>highlighters</code> holds the column
  * highlighters; these are applied to the renderer after the table highlighters.
- * Any change to the highlighters (setting them, adding one, removing one, or
- * changing one) will result in a {@code PropertyChangeEvent} being fired for
- * "highlighters".
+ * Any modification of the list of contained <code>Highlighter</code>s
+ * (setting them, adding one or removing one) will result in a
+ * {@code PropertyChangeEvent} being fired for "highlighters". State changes on
+ * contained <code>Highlighter</code>s will result in a PropertyChangeEvent
+ * for "highlighterStateChanged".
  * </ul>
  * 
  * 
@@ -80,6 +87,11 @@ import org.jdesktop.swingx.util.Contract;
  * example?
  * <p>
  * 
+ * A <code>TableColumnExt</code> implements UIDependent, that is it takes over
+ * responsibility to update LAF dependent properties of contained elements when
+ * messaged with updateUI. This implementation updates its <code>Highlighter</code>s,
+ * Cell-/HeaderRenderer and CellEditor. <p>
+ * 
  * TODO: explain prototype (sizing, collaborator-used-by ColumnFactory (?))
  * <p>
  * 
@@ -90,10 +102,10 @@ import org.jdesktop.swingx.util.Contract;
  * 
  * @see TableColumnModelExt
  * @see ColumnFactory
+ * @see org.jdesktop.swingx.UIDependent
  * @see javax.swing.JComponent#putClientProperty
  */
-public class TableColumnExt extends TableColumn
-    implements Cloneable {
+public class TableColumnExt extends TableColumn implements UIDependent {
     
     /** visible property. Initialized to <code>true</code>.*/
     protected boolean visible = true;
@@ -120,6 +132,8 @@ public class TableColumnExt extends TableColumn
     protected CompoundHighlighter compoundHighlighter;
     
     private ChangeListener highlighterChangeListener;
+
+    private boolean ignoreHighlighterStateChange;
     
     /**
      * Creates new table view column with a model index = 0.
@@ -134,7 +148,7 @@ public class TableColumnExt extends TableColumn
      *        is bound.
      */
     public TableColumnExt(int modelIndex) {
-        this(modelIndex, 75);	// default width taken from javax.swing.table.TableColumn
+        this(modelIndex, 75);    // default width taken from javax.swing.table.TableColumn
     }
 
     /**
@@ -163,48 +177,30 @@ public class TableColumnExt extends TableColumn
     }
 
     /**
-     * Returns the CompoundHighlighter assigned to the table, null if none.
-     * PENDING: open up for subclasses again?.
+     * Instantiates a new table view column with all properties copied from the 
+     * given original.
      * 
-     * @return the CompoundHighlighter assigned to the table.
-     * @see #setCompoundHighlighter(CompoundHighlighter)
+     * @param columnExt the column to copy properties from
+     * @see #copyFrom(TableColumnExt)
      */
-    private CompoundHighlighter getCompoundHighlighter() {
-        return compoundHighlighter;
+    public TableColumnExt(TableColumnExt columnExt) {
+        this(columnExt.getModelIndex(), columnExt.getWidth(), columnExt
+                .getCellRenderer(), columnExt.getCellEditor());
+        copyFrom(columnExt);
     }
 
-    /**
-     * Assigns a CompoundHighlighter to the table, maybe null to remove all
-     * Highlighters.<p>
-     * 
-     * The default value is <code>null</code>. <p>
-     * 
-     * PENDING: open up for subclasses again?.
-     * @param pipeline the CompoundHighlighter to use for renderer decoration. 
-     * @see #getCompoundHighlighter()
-     * @see #addHighlighter(Highlighter)
-     * @see #removeHighlighter(Highlighter)
-     * 
-     */
-    private void setCompoundHighlighter(CompoundHighlighter pipeline) {
-        CompoundHighlighter old = getCompoundHighlighter();
-        if (old != null) {
-            old.removeChangeListener(getHighlighterChangeListener());
-        }
-        compoundHighlighter = pipeline;
-        if (compoundHighlighter != null) {
-            compoundHighlighter.addChangeListener(getHighlighterChangeListener());
-        }
-        // PENDING: wrong event - the property is either "compoundHighlighter"
-        // or "highlighters" with the old/new array as value
-        firePropertyChange("highlighters", old, getCompoundHighlighter());
-    }
     
     /**
-     * Sets the <code>Highlighter</code>s to the column, replacing any old settings.
+     * Sets the <code>Highlighter</code>s to the table, replacing any old settings.
      * None of the given Highlighters must be null.<p>
      * 
+     * This is a bound property. <p> 
+     * 
+     * Note: as of version #1.257 the null constraint is enforced strictly. To remove
+     * all highlighters use this method without param.
+     * 
      * @param highlighters zero or more not null highlighters to use for renderer decoration.
+     * @throws NullPointerException if array is null or array contains null values.
      * 
      * @see #getHighlighters()
      * @see #addHighlighter(Highlighter)
@@ -212,45 +208,40 @@ public class TableColumnExt extends TableColumn
      * 
      */
     public void setHighlighters(Highlighter... highlighters) {
-        Contract.asNotNull(highlighters, "highlighters cannot be null or contain null");
-
-        CompoundHighlighter pipeline = null;
-        if (highlighters.length > 0) {    
-           pipeline = new CompoundHighlighter(highlighters);
-        }
-        
-        setCompoundHighlighter(pipeline);
+        ignoreHighlighterStateChange = true;
+        Highlighter[] old = getHighlighters();
+        getCompoundHighlighter().setHighlighters(highlighters);
+        firePropertyChange("highlighters", old, getHighlighters());
+        ignoreHighlighterStateChange = false;
     }
 
     /**
-     * Returns the <code>Highlighter</code>s used by this column.
+     * Returns the <code>Highlighter</code>s used by this table.
      * Maybe empty, but guarantees to be never null.
-     * @return the Highlighters used by this column, guaranteed to never null.
+     * 
+     * @return the Highlighters used by this table, guaranteed to never null.
      * @see #setHighlighters(Highlighter[])
      */
     public Highlighter[] getHighlighters() {
-        return getCompoundHighlighter() != null ? 
-                getCompoundHighlighter().getHighlighters() : 
-                    CompoundHighlighter.EMPTY_HIGHLIGHTERS;
+        return getCompoundHighlighter().getHighlighters();
     }
     /**
-     * Adds a Highlighter. Appends to the end of the list of used
-     * Highlighters.
+     * Appends a <code>Highlighter</code> to the end of the list of used
+     * <code>Highlighter</code>s. The argument must not be null. 
      * <p>
      * 
-     * @param highlighter the <code>Highlighter</code> to add.
+     * @param highlighter the <code>Highlighter</code> to add, must not be null.
      * @throws NullPointerException if <code>Highlighter</code> is null.
      * 
      * @see #removeHighlighter(Highlighter)
      * @see #setHighlighters(Highlighter[])
      */
     public void addHighlighter(Highlighter highlighter) {
-        CompoundHighlighter pipeline = getCompoundHighlighter();
-        if (pipeline == null) {
-           setCompoundHighlighter(new CompoundHighlighter(highlighter)); 
-        } else {
-            pipeline.addHighlighter(highlighter);
-        }
+        ignoreHighlighterStateChange = true;
+        Highlighter[] old = getHighlighters();
+        getCompoundHighlighter().addHighlighter(highlighter);
+        firePropertyChange("highlighters", old, getHighlighters());
+        ignoreHighlighterStateChange = false;
     }
 
     /**
@@ -263,10 +254,28 @@ public class TableColumnExt extends TableColumn
      * @see #setHighlighters(Highlighter...)
      */
     public void removeHighlighter(Highlighter highlighter) {
-        if ((getCompoundHighlighter() == null)) return;
+        ignoreHighlighterStateChange = true;
+        Highlighter[] old = getHighlighters();
         getCompoundHighlighter().removeHighlighter(highlighter);
+        firePropertyChange("highlighters", old, getHighlighters());
+        ignoreHighlighterStateChange = false;
     }
     
+    /**
+     * Returns the CompoundHighlighter assigned to the table, null if none.
+     * PENDING: open up for subclasses again?.
+     * 
+     * @return the CompoundHighlighter assigned to the table.
+     * @see #setCompoundHighlighter(CompoundHighlighter)
+     */
+    protected CompoundHighlighter getCompoundHighlighter() {
+        if (compoundHighlighter == null) {
+            compoundHighlighter = new CompoundHighlighter();
+            compoundHighlighter.addChangeListener(getHighlighterChangeListener());
+        }
+        return compoundHighlighter;
+    }
+
     /**
      * Returns the <code>ChangeListener</code> to use with highlighters. Lazily 
      * creates the listener.
@@ -284,7 +293,7 @@ public class TableColumnExt extends TableColumn
     /**
      * Creates and returns the ChangeListener observing Highlighters.
      * <p>
-     * A property change event is create for a state change.
+     * Here: repaints the table on receiving a stateChanged.
      * 
      * @return the ChangeListener defining the reaction to changes of
      *         highlighters.
@@ -292,12 +301,12 @@ public class TableColumnExt extends TableColumn
     protected ChangeListener createHighlighterChangeListener() {
         return new ChangeListener() {
             public void stateChanged(ChangeEvent e) {
-                //return null for old state since it is unknown
-                firePropertyChange("highlighters", null, getCompoundHighlighter());
+                if (ignoreHighlighterStateChange) return;
+                firePropertyChange("highlighterStateChanged", false, true);
             }
         };
     }
-    
+
     /** 
      * Returns true if the user <i>can</i> resize the TableColumn's width, 
      * false otherwise. This is a usability override: it takes into account
@@ -467,7 +476,7 @@ public class TableColumnExt extends TableColumn
      * @param title String containing the title of this view column
      */
     public void setTitle(String title) {
-        setHeaderValue(title);				// simple wrapper
+        setHeaderValue(title);                // simple wrapper
     }
 
     /**
@@ -478,7 +487,7 @@ public class TableColumnExt extends TableColumn
      */
     public String getTitle() {
         Object header = getHeaderValue();
-        return header != null ? header.toString() : null;	// simple wrapper
+        return header != null ? header.toString() : null; // simple wrapper
     }
 
     /**
@@ -570,58 +579,52 @@ public class TableColumnExt extends TableColumn
         return clientProperties;
     }
 
-    /**
-      * Returns a copy of this TableColumn. Some implementations of TableColumn
-      * may assume that all TableColumnModels are unique, therefore it is
-      * recommended that the same TableColumn instance not be added more than
-      * once to a TableColumnModel. To show TableColumns with the same column of
-      * data from the model, create a new instance with the same modelIndex.
-      * <p>
-      * This implementation is not compatible with {@link Object#clone()}.
-      *
-      * @return a clone of this TableColumn
-      */
-     @Override
-     public Object clone() {
-         final TableColumnExt copy = new TableColumnExt(
-             this.getModelIndex(), this.getWidth(),
-             this.getCellRenderer(), this.getCellEditor());
-         
-         copy.setEditable(this.isEditable());
-         copy.setHeaderValue(this.getHeaderValue());	// no need to copy setTitle();
-         copy.setToolTipText(getToolTipText());
-         copy.setIdentifier(this.getIdentifier());
-         copy.setMaxWidth(this.getMaxWidth());
-         copy.setMinWidth(this.getMinWidth());
-         copy.setPreferredWidth(this.getPreferredWidth());
-         copy.setPrototypeValue(this.getPrototypeValue());
-         // JW: isResizable is overridden to return a calculated property!
-         copy.setResizable(super.getResizable());
-         copy.setVisible(this.isVisible());
-         copy.setSortable(this.isSortable());
-         copy.setComparator(getComparator());
-         copyClientPropertiesTo(copy);
-         
-         if (compoundHighlighter != null) {
-             copy.setHighlighters(getHighlighters());
-         }
-         
-         return copy;
-     }
 
+     /**
+      * Copies properties from original. Handles all properties except
+      * modelIndex, width, cellRenderer, cellEditor. Called from copy 
+      * constructor.
+      *  
+      * @param original the tableColumn to copy from
+      * 
+      * @see #TableColumnExt(TableColumnExt)
+      */
+     protected void copyFrom(TableColumnExt original) {
+             setEditable(original.isEditable());
+             setHeaderValue(original.getHeaderValue());    // no need to copy setTitle();
+             setToolTipText(original.getToolTipText());
+             setIdentifier(original.getIdentifier());
+             setMaxWidth(original.getMaxWidth());
+             setMinWidth(original.getMinWidth());
+             setPreferredWidth(original.getPreferredWidth());
+             setPrototypeValue(original.getPrototypeValue());
+             // JW: isResizable is overridden to return a calculated property!
+             setResizable(original.isResizable);
+             setVisible(original.isVisible());
+             setSortable(original.isSortable());
+             setComparator(original.getComparator());
+             copyClientPropertiesFrom(original);
+             
+             if (original.compoundHighlighter != null) {
+                 setHighlighters(original.getHighlighters());
+             }
+         
+     }
+     
      /**
       * Copies all clientProperties of this <code>TableColumnExt</code>
       * to the target column.
       * 
       * @param copy the target column.
       */
-     protected void copyClientPropertiesTo(TableColumnExt copy) {
-        if (clientProperties == null) return;
-        for(Object key: clientProperties.keySet()) {
-            copy.putClientProperty(key, getClientProperty(key));
+     protected void copyClientPropertiesFrom(TableColumnExt original) {
+        if (original.clientProperties == null) return;
+        for(Object key: original.clientProperties.keySet()) {
+            putClientProperty(key, original.getClientProperty(key));
         }
     }
 
+
     /**
      * Notifies registered <code>PropertyChangeListener</code>s 
      * about property changes. This method must be invoked internally
@@ -650,4 +653,75 @@ public class TableColumnExt extends TableColumn
              }
          }
      }
+
+//---------------- implement UIDependent
+    
+    /**
+     * Update ui of owned ui-dependent parts. This implementation
+     * updates the contained highlighters.
+     * 
+     */
+    public void updateUI() {
+        updateHighlighterUI();
+        updateRendererUI(getCellRenderer());
+        updateRendererUI(getHeaderRenderer());
+        updateEditorUI(getCellEditor());
+    }
+
+    /**
+     * @param editor 
+     * 
+     */
+    private void updateEditorUI(TableCellEditor editor) {
+        if (editor == null) return;
+        // internal knowledge of core table - already updated
+        if ((editor instanceof JComponent)
+                || (editor instanceof DefaultCellEditor))
+            return;
+        try {
+            Component comp = editor
+                    .getTableCellEditorComponent(null, null, false, -1, -1);
+            if (comp != null) {
+                SwingUtilities.updateComponentTreeUI(comp);
+            }
+        } catch (Exception e) {
+            // can't do anything - renderer can't cope with off-range cells
+        }
+    }
+
+    /**
+     * @param tableCellRenderer 
+     * 
+     */
+    private void updateRendererUI(TableCellRenderer renderer) {
+        if (renderer == null) return;
+        // internal knowledge of core table - already updated
+        if (renderer instanceof JComponent) {
+            return;
+        }
+        Component comp = null;
+        if (renderer instanceof AbstractRenderer) {
+            comp = ((AbstractRenderer) renderer).getComponentProvider().getRendererComponent(null);
+        } else {
+            try {
+                comp = renderer
+                .getTableCellRendererComponent(null, null, false, false,
+                        -1, -1);
+              
+            } catch (Exception e) {
+                // can't do anything - renderer can't cope with off-range cells
+            }
+        }
+        if (comp != null) {
+            SwingUtilities.updateComponentTreeUI(comp);
+        }
+    }
+
+    /**
+     * 
+     */
+    private void updateHighlighterUI() {
+        if (compoundHighlighter == null) return;
+        compoundHighlighter.updateUI();
+    }
 }
