@@ -1,5 +1,5 @@
 /*
- * $Id: PaintUtils.java,v 1.16 2007/11/19 16:20:37 kschaefe Exp $
+ * $Id: PaintUtils.java,v 1.17 2008/10/14 22:31:46 rah003 Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -453,9 +453,9 @@ public class PaintUtils {
                 new Point(0,0), new Point(10,0),
                 new float[] {0f, 0.5f, 1f},
                 new Color[] {Color.RED, Color.GREEN, Color.BLUE});
-        System.out.println("in  = " + toString(in));
+        log.fine("in  = " + toString(in));
         Paint out = resizeGradient(in,100,100);
-        System.out.println("out = " + toString((MultipleGradientPaint) out));
+        log.fine(("out = " + toString((MultipleGradientPaint) out));
     }*/
     /*
     private static String toString(MultipleGradientPaint paint) {
@@ -483,7 +483,7 @@ public class PaintUtils {
     }*/
     
 //    private static void p(String string) {
-//        System.out.println(string);
+//        log.fine((string);
 //    }
 
 }
