@@ -1,5 +1,5 @@
 /*
- * $Id: JXDatePickerIssues.java,v 1.66 2008/05/13 11:40:51 kleopatra Exp $
+ * $Id: JXDatePickerIssues.java,v 1.71 2008/12/01 14:14:42 kleopatra Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -21,6 +21,7 @@
  */
 package org.jdesktop.swingx;
 
+import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
@@ -42,11 +43,14 @@ import javax.swing.JFormattedTextField;
 import javax.swing.JInternalFrame;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
+import javax.swing.JSpinner;
 import javax.swing.JTextField;
 import javax.swing.KeyStroke;
+import javax.swing.SpinnerDateModel;
 
 import org.jdesktop.swingx.calendar.CalendarUtils;
 import org.jdesktop.swingx.calendar.DatePickerFormatter;
+import org.junit.Test;
 
 /**
  * Known issues of <code>JXDatePicker</code> and picker related 
@@ -59,13 +63,13 @@ public class JXDatePickerIssues extends InteractiveTestCase {
     private static final Logger LOG = Logger.getLogger(JXDatePickerIssues.class
             .getName());
     public static void main(String[] args) {
-        setSystemLF(true);
+//        setSystemLF(true);
 //        Trace14.keyboardFocusManager(true);
         JXDatePickerIssues  test = new JXDatePickerIssues();
         try {
 //            test.runInteractiveTests();
 //          test.runInteractiveTests("interactive.*UpdateUI.*");
-          test.runInteractiveTests("interactive.*Focus.*");
+          test.runInteractiveTests("interactive.*Editor.*");
 //          test.runInteractiveTests("interactive.*Visible.*");
           
         } catch (Exception e) {
@@ -77,6 +81,55 @@ public class JXDatePickerIssues extends InteractiveTestCase {
 
     private Calendar calendar;
 
+    /**
+     * Issue #955-swingx: editor should have same visual props as picker
+     */
+    public void interactivePickerToEditorVisuals() {
+        JXDatePicker picker = new JXDatePicker(calendar.getTime());
+        picker.setBackground(Color.RED);
+        picker.setForeground(Color.BLUE);
+        picker.setToolTipText("Colored editor");
+        JComboBox combo = new JComboBox(new Object[] {"just something", "and something else"});
+        combo.setEditable(true);
+        combo.setBackground(Color.RED);
+        combo.setForeground(Color.BLUE);
+        combo.setToolTipText("Colored combo editor");
+        JComponent box = new JXPanel();
+        box.add(picker);
+        box.add(combo);
+        showInFrame(box, "Colored editor");
+    }
+    
+    /**
+     * Issue #913-swingx: Datepicker looks bad in some LFs (f.i. Nimbus)
+     * 
+     * not only Nimbus ...
+     * - Metal: starts with different height than textfield, shrinks when coming
+     *   back from another LF
+     * - motif: button is shrunkenn always
+     * - win: halfway okay, but should have buttons "nearer/integrated" to the field
+     *   as spinner, combo does
+     * - Vista: button should visually "merge" into field until rollover (as combo does,
+     *   Spinner not
+     * - Can't remember the reason why combo's button isn't re-used?
+     *       
+     */
+    public void interactiveDatePickerNimbus() {
+        JXDatePicker picker = new JXDatePicker(new Date());
+        JFormattedTextField field = new JFormattedTextField();
+        field.setValue(picker.getDate());
+        JSpinner spinner = new JSpinner(new SpinnerDateModel());
+        spinner.setValue(picker.getDate());
+        JComboBox box = new JComboBox(new Object[] {picker.getDate()});
+        box.setEditable(true);
+        JComponent panel = new JXPanel();
+        panel.add(field);
+        panel.add(picker);
+        panel.add(spinner);
+        panel.add(box);
+        showInFrame(panel, "Nimbus and picker");
+    }
+
     /**
      * Compare behaviour of notifyAction: DatePicker vs. core components.
      * 
@@ -141,24 +194,7 @@ public class JXDatePickerIssues extends InteractiveTestCase {
     }
     
 
-    /**
-     * Compare picker and combo behaviour on toggle lf.
-     * 
-     * Not really comparable: the combo has complete control over the popup, re-creates
-     * both popup and content on install.
-     * 
-     */
-    public void interactiveUpdateUIPickerCompareCombo() {
-        JXDatePicker picker = new JXDatePicker();
-        JComboBox box = new JComboBox(new Object[] {"one", "twooooooo", "threeeeeeeeeeee", "GOOO!"});
-        box.setEditable(true);
-        JComponent comp = new JPanel();
-        comp.add(picker);
-        comp.add(box);
-        JXFrame frame = wrapInFrame(comp, "compare combo <-> picker", true);
-        frame.setVisible(true);
-    }
-    
+
     
     /**
      * Issue #709-swingx: DatePicker should have empty constructor which doesn't select.
@@ -166,7 +202,6 @@ public class JXDatePickerIssues extends InteractiveTestCase {
      * Plus deprecate constructors with long - replace by Date parameters.
      * Deprecate other methods taking long.
      */
-    @SuppressWarnings("deprecation")
     public void interactiveNullDate() {
         JComponent comp = Box.createVerticalBox();
         comp.add(new JLabel("setDate(null)"));
@@ -396,6 +431,59 @@ public class JXDatePickerIssues extends InteractiveTestCase {
         frame.setVisible(true);
     }
 //-------------------- unit tests
+    
+    
+    /**
+     * Issue #955-swingx: editor should have same visual props as picker
+     */
+    @Test
+    public void testPickerSynchEditorColorsInitial() {
+        JXDatePicker picker = new JXDatePicker();
+        assertEquals(picker.getForeground(), picker.getEditor().getForeground());
+        assertEquals(picker.getBackground(), picker.getEditor().getBackground());
+    }
+    
+    /**
+     * Issue #955-swingx: editor should have same visual props as picker
+     * for comparison: combobox.
+     */
+    @Test
+    public void testComboSynchEditorColorsInitial() {
+        JComboBox picker = new JComboBox();
+        // make sure we have an editor
+        picker.setEditable(true);
+        assertEquals(picker.getForeground(), picker.getEditor().getEditorComponent().getForeground());
+        assertEquals(picker.getBackground(), picker.getEditor().getEditorComponent().getBackground());
+    }
+    
+    /**
+     * Issue #955-swingx: editor should have same visual props as picker
+     */
+    @Test
+    public void testPickerSynchEditorColors() {
+        JXDatePicker picker = new JXDatePicker();
+        picker.setBackground(Color.RED);
+        picker.setForeground(Color.BLUE);
+       assertEquals(picker.getForeground(), picker.getEditor().getForeground());
+        assertEquals(picker.getBackground(), picker.getEditor().getBackground());
+    }
+    
+    /**
+     * Issue #955-swingx: editor should have same visual props as picker
+     * for comparison: combobox.
+     */
+    @Test
+    public void testComboSynchEditorColors() {
+        JComboBox picker = new JComboBox();
+        // make sure we have an editor
+        picker.setEditable(true);
+        picker.setBackground(Color.RED);
+        picker.setForeground(Color.BLUE);
+        assertEquals(picker.getForeground(), picker.getEditor().getEditorComponent().getForeground());
+        assertEquals(picker.getBackground(), picker.getEditor().getEditorComponent().getBackground());
+    }
+
+    
     /**
      * Issue #764-swingx: picker prefsize too narrow
      */
@@ -462,24 +550,6 @@ public class JXDatePickerIssues extends InteractiveTestCase {
         
     }
 
-    
-    /**
-     * test that selectionListener is uninstalled.
-     * 
-     * Hmm ... missing api or overshooting?
-     */
-    public void testSelectionListening() {
-//        JXMonthView monthView = new JXMonthView();
-//        int selectionListenerCount = monthView.getSelectionModel()).getListeners().length;
-//        JXDatePicker picker = new JXDatePicker();
-//        assertEquals("ui must have installed one listener", selectionListenerCount + 1, 
-//                picker.getMonthView().getSelectionModel().getListeners().length);
-//        picker.getUI().uninstallUI(picker);
-//        assertEquals("", selectionListenerCount, 
-//                picker.getMonthView().getSelectionModel().getListeners().length);
-    }
-    
-
     /**
      * Returns a timezone different from the given.
      * @param defaultZone
