@@ -1,5 +1,5 @@
 /*
- * $Id: JXDatePickerTest.java,v 1.67 2008/04/01 12:21:28 kleopatra Exp $
+ * $Id: JXDatePickerTest.java,v 1.71 2008/12/01 14:14:42 kleopatra Exp $
  * 
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -59,10 +59,17 @@ import org.jdesktop.swingx.test.XTestUtils;
 import org.jdesktop.test.ActionReport;
 import org.jdesktop.test.PropertyChangeReport;
 import org.jdesktop.test.TestUtils;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+
 
 /**
  * Unit tests for JXDatePicker.
  */
+@RunWith(JUnit4.class)
 public class JXDatePickerTest extends InteractiveTestCase {
     private static final Logger LOG = Logger.getLogger(JXDatePickerTest.class
             .getName());
@@ -70,12 +77,75 @@ public class JXDatePickerTest extends InteractiveTestCase {
     private Calendar calendar;
 
     @Override
-    public void setUp() {
+    @Before
+       public void setUp() {
         calendar = Calendar.getInstance();
     }
 
     @Override
-    public void tearDown() {
+    @After
+       public void tearDown() {
+    }
+
+    
+    /**
+     * Issue #910-swingx: home commit must be disabled if picker not editable.
+     * 
+     */
+    @Test
+    public void testNotEditableNullHomeNavigate() {
+        JXDatePicker picker = new JXDatePicker();
+        picker.getActionMap().remove(JXDatePicker.HOME_NAVIGATE_KEY);
+        picker.setEditable(!picker.isEditable());
+    }
+
+    /**
+     * Issue #910-swingx: home commit must be disabled if picker not editable.
+     * 
+     */
+    @Test
+    public void testNotEditableDisabledHomeNavigate() {
+        JXDatePicker picker = new JXDatePicker();
+        Action delegate = picker.getActionMap().get(JXDatePicker.HOME_NAVIGATE_KEY);
+        assertEquals(picker.isEditable(), delegate.isEnabled());
+        picker.setEditable(!picker.isEditable());
+        assertEquals(picker.isEditable(), delegate.isEnabled());
+    }
+
+    /**
+     * Issue #910-swingx: home commit must be disabled if picker not editable.
+     * 
+     */
+    @Test
+    public void testNotEditableNullHomeCommit() {
+        JXDatePicker picker = new JXDatePicker();
+        picker.getActionMap().remove(JXDatePicker.HOME_COMMIT_KEY);
+        picker.setEditable(!picker.isEditable());
+    }
+
+    /**
+     * Issue #910-swingx: home commit must be disabled if picker not editable.
+     * 
+     */
+    @Test
+    public void testNotEditableDisabledHomeCommit() {
+        JXDatePicker picker = new JXDatePicker();
+        Action delegate = picker.getActionMap().get(JXDatePicker.HOME_COMMIT_KEY);
+        assertEquals(picker.isEditable(), delegate.isEnabled());
+        picker.setEditable(!picker.isEditable());
+        assertEquals(picker.isEditable(), delegate.isEnabled());
+    }
+    /**
+     * Sanity: report in forum that editor not disabled if picker disabled.
+     * Looks okay.
+     */
+    @Test
+    public void testEnabled() {
+        JXDatePicker picker = new JXDatePicker();
+        picker.setEnabled(false);
+        assertFalse("sanity: picker disabled", picker.isEnabled());
+        assertEquals("editor enabled must follow picker enabled", 
+                picker.isEnabled(), picker.getEditor().isEnabled());
     }
     
     /**
@@ -83,6 +153,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * editor must respect columns.
      */
+    @Test
     public void testDatePickerColumns50() {
         JXDatePicker picker = new JXDatePicker();
         picker.getEditor().setColumns(50);
@@ -97,6 +168,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * editor must respect columns.
      */
+    @Test
     public void testDatePickerColumns5() {
         JXDatePicker picker = new JXDatePicker();
         picker.getEditor().setColumns(5);
@@ -113,6 +185,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * editors border if it finds a null. 
      * 
      */
+    @Test
     public void testPickerBorder() {
         // force loading of addon
         new JXDatePicker();
@@ -139,6 +212,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Here: change the timezone on the monthView - can't guarantee the notification.
      * At least not without hacks...
      */
+    @Test
     public void testTimeZoneChangeNotificationChangeOnMonthView() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone timeZone = picker.getTimeZone();
@@ -153,6 +227,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Issue #724-swingx: picker must notify about timezone changes.
      * Here: change the timezon on the picker - can guarantee the notification.
      */
+    @Test
     public void testTimeZoneChangeNotification() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone timeZone = picker.getTimeZone();
@@ -168,6 +243,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Here: setMonthView must update the picker's timezone if different and
      *   fire a notification.
      */
+    @Test
     public void testTimeZoneSetMonthView() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone timeZone = picker.getTimeZone();
@@ -194,6 +270,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * model's calendar coordinates, a SingleDaySelectionModel keeps the date as-is.
      * For now, need to explicitly set. 
      */
+    @Test
     public void testSetDateKeepsTime() {
         JXDatePicker picker = new JXDatePicker();
         DateSelectionModel selectionModel = new SingleDaySelectionModel();
@@ -214,6 +291,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * The implication is that client code (such as JXDatePicker/UI) is 
      * responsible to do the scrolling.
      */
+    @Test
     public void testVisibleMonthContainsSelectionOpenSet() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run testLinkPanelNull - headless");
@@ -241,6 +319,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * The implication is that client code (such as JXDatePicker/UI) is 
      * responsible to do the scrolling.
      */
+    @Test
     public void testVisibleMonthContainsSelectionOpenInitial() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run testLinkPanelNull - headless");
@@ -266,6 +345,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * The implication is that client code (such as JXDatePicker/UI) is 
      * responsible to do the scrolling.
      */
+    @Test
     public void testVisibleMonthContainsSelectionIinitial() {
         calendar.set(2008, Calendar.JULY, 15);
         JXDatePicker picker = new JXDatePicker(calendar.getTime());
@@ -281,6 +361,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * The implication is that client code (such as JXDatePicker/UI) is 
      * responsible to do the scrolling.
      */
+    @Test
     public void testVisibleMonthContainsSelectionSet() {
         JXDatePicker picker = new JXDatePicker();
         calendar.set(2008, Calendar.JULY, 15);
@@ -295,6 +376,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Issue #693-swingx: format of custom locale.
      * Here: test constructor with locale parameter.
      */
+    @Test
     public void testCustomLocaleConstructor() {
         Locale german = Locale.GERMAN;
         JXDatePicker picker = new JXDatePicker(german);
@@ -307,6 +389,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Issue #693-swingx: format of custom locale.
      * Here: test setLocale.
      */
+    @Test
     public void testCustomLocaleSet() {
         Locale german = Locale.GERMAN;
         JXDatePicker picker = new JXDatePicker();
@@ -321,6 +404,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Here: default formats re-set.
      */
+    @Test
     public void testDefaultFormats() {
         JXDatePicker picker = new JXDatePicker();
         DateFormat[] formats = picker.getFormats();
@@ -334,6 +418,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Sanity test: custom format set as expected.
      */
+    @Test
     public void testCustomFormatsSet() {
         JXDatePicker picker = new JXDatePicker();
         DateFormat format = DateFormat.getDateInstance(DateFormat.MEDIUM,Locale.UK);
@@ -348,6 +433,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Here: test that custom format is unchanged after updateUI
      */
+    @Test
     public void testCustomFormatsKept() {
         JXDatePicker picker = new JXDatePicker();
         DateFormat format = DateFormat.getDateInstance(DateFormat.MEDIUM,Locale.UK);
@@ -368,6 +454,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * value (and no way to remove which is okay).
      * 
      */
+    @Test
     public void testLinkFormatStringNull() {
         // force loading
         new JXDatePicker();
@@ -388,6 +475,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Forum report: NPE under certain initial conditions.
      * 
      */
+    @Test
     public void testPickerFormatSetFormats() {
         JXDatePicker picker = new JXDatePicker();
         picker.setFormats((DateFormat[])null);
@@ -399,6 +487,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Forum report: NPE under certain initial conditions.
      * 
      */
+    @Test
     public void testPickerFormatSetFormatsNullElements() {
         JXDatePicker picker = new JXDatePicker();
         try {
@@ -415,6 +504,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Forum report: NPE under certain initial conditions.
      * 
      */
+    @Test
     public void testPickerFormatSetFormatStrings() {
         JXDatePicker picker = new JXDatePicker();
         picker.setFormats((String[])null);
@@ -426,6 +516,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Forum report: NPE under certain initial conditions.
      * 
      */
+    @Test
     public void testPickerFormatSetFormatStringsNullElements() {
         JXDatePicker picker = new JXDatePicker();
         try {
@@ -442,6 +533,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * This produced exactly the stacktrace as reported.
      * 
      */
+    @Test
     public void testPickerFormatsNotNull() {
         JXDatePicker picker = new JXDatePicker();
         // trick the picker - no formats
@@ -456,6 +548,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * 
      */
+    @Test
     public void testPickerFormatsNotNullUnknownFormatter() {
         JXDatePicker picker = new JXDatePicker();
         // trick the picker - no formats
@@ -475,6 +568,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * testing internals: need focus listener add/remove
      *
      */
+    @Test
     public void testFocusListenerOnPicker() {
         JXDatePicker picker = new JXDatePicker();
         assertEquals(1, picker.getFocusListeners().length);
@@ -489,6 +583,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * testing internals: need focus listener add/remove
      *
      */
+    @Test
     public void testFocusListenerOnEditor() {
         JFormattedTextField field = new JFormattedTextField(new DatePickerFormatter());
         int listenerCount = field.getFocusListeners().length;
@@ -502,6 +597,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * tests LinkPanel set to null after showing.
      * Was: NPE.
      */
+    @Test
     public void testLinkPanelSetNull() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run testLinkPanelNull - headless");
@@ -521,6 +617,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * tests initial null linkPanel.
      *
      */
+    @Test
     public void testLinkPanelInitalNull() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run testLinkPanelNull - headless");
@@ -541,6 +638,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * - removed/added from parent
      * - bindings initially installed/uninstalled/re-installed
      */
+    @Test
     public void testLinkPanelRemovedAdded() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run testLinkPanelNull - headless");
@@ -580,6 +678,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * are removed (no popup)
      *
      */
+    @Test
     public void testLinkPanelBindingUninstalled() {
         JXDatePicker picker = new JXDatePicker();
         JComponent linkPanel = picker.getLinkPanel();
@@ -593,6 +692,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * for homeCommit/-Cancel (initially, no popup)
      *
      */
+    @Test
     public void testLinkPanelAction() {
         JXDatePicker picker = new JXDatePicker();
         JComponent linkPanel = picker.getLinkPanel();
@@ -663,6 +763,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * picker's actionMap.
      *
      */
+    @Test
     public void testTogglePopupAction() {
        JXDatePicker picker = new JXDatePicker();
        Action togglePopup = picker.getActionMap().get("TOGGLE_POPUP");
@@ -680,6 +781,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Test that set date programmatically (directly or indirectly) 
      * does not fire an actionEvent.
      */
+    @Test
     public void testSetDateSilently() {
         JXDatePicker picker = new JXDatePicker();
         ActionReport report = new ActionReport();
@@ -707,6 +809,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * cancel in the picker.
      *
      */
+    @Test
     public void testCommitCancelFromMonthViewCancel() {
         JXDatePicker picker = new JXDatePicker();
         final ActionReport report = new ActionReport();
@@ -725,6 +828,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * commit in the picker.
      *
      */
+    @Test
     public void testCommitCancelFromMonthViewCommit() {
         JXDatePicker picker = new JXDatePicker();
         Action commitAction = picker.getMonthView().getActionMap().get(JXMonthView.COMMIT_KEY);
@@ -741,6 +845,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * test that the ui installed a listener.
      */
+    @Test
     public void testCommitCancelListeningToMonthView() {
         JXMonthView monthView = new JXMonthView();
         int standalone = monthView.getListeners(ActionListener.class).length;
@@ -754,6 +859,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * test wrapping and resetting the editors cancel action.
      * internals ... mostly to be sure about cleanup and re-wire.
      */
+    @Test
     public void testCancelEditorAction() {
         JFormattedTextField field = new JFormattedTextField(new DatePickerFormatter());
         // original action
@@ -786,6 +892,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * state unchanged and no events fired (except the actionEvent).
      *
      */
+    @Test
     public void testCancelEditRevertsSilently() {
         JXDatePicker picker = new JXDatePicker(new Date());
         String text = picker.getEditor().getText();
@@ -811,6 +918,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * PENDING: need to invoke ... safe test?
      *
      */
+    @Test
     public void testCommitCancelActionsFireCancel() {
         JXDatePicker picker = new JXDatePicker();
         final ActionReport report = new ActionReport();
@@ -827,6 +935,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * test that commit fires as expected.
      * PENDING: need to invoke ... safe test?
      */
+    @Test
     public void testCommitCancelActionsFireCommit() {
         JXDatePicker picker = new JXDatePicker();
         Action commitAction = picker.getActionMap().get(JXDatePicker.COMMIT_KEY);
@@ -843,6 +952,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * test that actions are registered.
      *
      */
+    @Test
     public void testCommitCancelActionExist() {
         JXDatePicker picker = new JXDatePicker();
         assertNotNull(picker.getActionMap().get(JXDatePicker.CANCEL_KEY));
@@ -855,6 +965,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * linkDate synced with monthView's today after setting.
      */
+    @Test
     public void testLinkDateSetToday() {
         JXDatePicker picker = new JXDatePicker();
         Calendar cal = picker.getMonthView().getCalendar();
@@ -871,6 +982,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Initial linkDate synced with monthView's today.
      */
+    @Test
     public void testLinkDateInitial() {
         JXDatePicker picker = new JXDatePicker();
         assertEquals(picker.getMonthView().getToday(), picker.getLinkDay());
@@ -881,6 +993,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Here: set timezone in picker.
      */
+    @Test
     public void testSynchTimeZoneLinkFormatOnModified() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone alternative = getSafeAlternativeTimeZone(picker.getTimeZone());
@@ -893,6 +1006,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
 
      * Here: set monthView with alternative timezone
      */
+    @Test
     public void testSynchTimeZoneLinkFormatOnSetMonthView() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone defaultZone = picker.getTimeZone();
@@ -926,6 +1040,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Issue #554-swingx: timezone of formats and picker must be synched.
      * Here: set the timezone in the monthView.
      */
+    @Test
     public void testSynchTimeZoneModifiedInMonthView() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone defaultZone = picker.getTimeZone();
@@ -940,6 +1055,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Here: set the timezone in the picker.
      */
+    @Test
     public void testSynchTimeZoneModifiedInPicker() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone defaultZone = picker.getTimeZone();
@@ -953,6 +1069,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
 
      * Here: set the timezone in the picker.
      */
+    @Test
     public void testSynchTimeZoneOnSetMonthView() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone defaultZone = picker.getTimeZone();
@@ -968,6 +1085,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Here: initialize the formats with the pickers timezone on setting.
      */
+    @Test
     public void testSynchTimeZoneOnSetFormats() {
         JXDatePicker picker = new JXDatePicker();
         TimeZone defaultZone = picker.getTimeZone();
@@ -995,6 +1113,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     /**
      * Issue #554-swingx: timezone of formats and picker must be synched.
      */
+    @Test
     public void testSynchTimeZoneInitial() {
         JXDatePicker picker = new JXDatePicker();
         assertNotNull(picker.getTimeZone());
@@ -1007,6 +1126,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * setFormats should fire a propertyChange.
      *
      */
+    @Test
     public void testFormatsProperty() {
         JXDatePicker picker = new JXDatePicker();
         PropertyChangeReport report = new PropertyChangeReport();
@@ -1021,6 +1141,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     /**
      * Test doc'ed behaviour: editor must not be null.
      */
+    @Test
     public void testEditorNull() {
         JXDatePicker picker = new JXDatePicker();
         assertNotNull(picker.getEditor());
@@ -1036,6 +1157,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     /**
      * Test doc'ed behaviour: editor must not be null.
      */
+    @Test
     public void testMonthViewNull() {
         JXDatePicker picker = new JXDatePicker();
         assertNotNull(picker.getMonthView());
@@ -1053,6 +1175,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * are up for the DatePickerUI to decide. 
      * 
      */
+    @Test
     public void testSetDateCleansDate() {
         JXDatePicker picker = new JXDatePicker();
         Date date = calendar.getTime();
@@ -1064,6 +1187,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Regression testing: make sure the passed-in date is not changed.
      * 
      */
+    @Test
     public void testSetDateDoesNotChangeOriginal() {
         JXDatePicker picker = new JXDatePicker();
         Date date = calendar.getTime();
@@ -1075,6 +1199,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     /**
      *  date is a bound property of DatePicker.
      */
+    @Test
     public void testDateProperty() {
         JXDatePicker picker = new JXDatePicker();
         Date date = XTestUtils.getStartOfToday(5);
@@ -1088,6 +1213,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      *  date is a bound property of DatePicker. 
      *  test indirect event firing: changed editor value
      */
+    @Test
     public void testDatePropertyThroughEditor() {
         JXDatePicker picker = new JXDatePicker();
         Date date = XTestUtils.getStartOfToday(5);
@@ -1101,6 +1227,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      *  date is a bound property of DatePicker.
      *  test indirect event firing: changed monthView selection 
      */
+    @Test
     public void testDatePropertyThroughSelection() {
         JXDatePicker picker = new JXDatePicker();
         Date date = XTestUtils.getStartOfToday(5);
@@ -1116,6 +1243,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * @throws ParseException 
      *
      */
+    @Test
     public void testDatePropertyThroughCommit() throws ParseException {
         JXDatePicker picker = new JXDatePicker(new Date());
         Date initialDate = picker.getDate();
@@ -1145,6 +1273,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * @throws ParseException 
      *
      */
+    @Test
     public void testSynchAllAfterCommit() throws ParseException {
         JXDatePicker picker = new JXDatePicker(new Date());
         String text = picker.getEditor().getText();
@@ -1171,6 +1300,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * here: initial. 
      * 
      */
+    @Test
     public void testSynchAllInitialDate() {
         Date date = XTestUtils.getStartOfToday(5);
         JXDatePicker picker = new JXDatePicker(date);
@@ -1183,6 +1313,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Note: test uses a cleaned date, do same with uncleaned.
      */
+    @Test
     public void testSynchAllOnDateModified() {
         JXDatePicker picker = new JXDatePicker();
         Date date = XTestUtils.getStartOfToday(5);
@@ -1195,6 +1326,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * here: set selected date in monthview
      * Note: test uses a cleaned date, do same with uncleaned.
      */
+    @Test
     public void testSynchAllOnSelectionChange()  {
         JXDatePicker picker = new JXDatePicker();
         Date date = XTestUtils.getStartOfToday(5);
@@ -1208,6 +1340,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Note: test uses a cleaned date, do same with uncleaned.
      */
+    @Test
     public void testSynchAllOnEditorSetValue() {
         JXDatePicker picker = new JXDatePicker();
         Date date = XTestUtils.getStartOfToday(5);
@@ -1221,6 +1354,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Note: this started to fail during listener cleanup.
      */
+    @Test
     public void testSynchAllOnEditorSetValueAfterSetEditor() {
         JXDatePicker picker = new JXDatePicker();
         picker.setEditor(new JFormattedTextField(DateFormat.getInstance()));
@@ -1235,6 +1369,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Note: this started to fail during listener cleanup.
      */
+    @Test
     public void testSynchAllOnSelectionChangeAfterSetMonthView() {
         JXDatePicker picker = new JXDatePicker();
         picker.setMonthView(new JXMonthView());
@@ -1252,6 +1387,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * Note: this started to fail during listener cleanup.
      */
+    @Test
     public void testSynchAllOnSelectionChangeAfterSetSelectionModel() {
         JXDatePicker picker = new JXDatePicker();
         picker.getMonthView().setSelectionModel(new DefaultDateSelectionModel());
@@ -1287,6 +1423,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
     /**
      * test that input of unselectable dates reverts editors value.
      */
+    @Test
     public void testRejectSetValueUnselectable() {
         JXDatePicker picker = new JXDatePicker();
         Date upperBound = XTestUtils.getStartOfToday(1);
@@ -1311,6 +1448,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * brittle because done during the notification. 
      * Changed to use dedicated listener.
      */
+    @Test
     public void testSpuriousEditableListening() {
         JXDatePicker picker = new JXDatePicker();
         picker.getEditor().setEditable(false);
@@ -1325,6 +1463,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * PickerUI listened to enabled of button (meant: datePicker) and resets
      * the buttons property. 
      */
+    @Test
     public void testSpuriousEnabledListening() {
         JXDatePicker picker = new JXDatePicker();
         Component button = null;
@@ -1350,6 +1489,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * ui listening to picker property changes.
      *
      */
+    @Test
     public void testDatePickerPropertyListening() {
         JXDatePicker picker = new JXDatePicker();
         picker.setEnabled(false);
@@ -1365,6 +1505,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * uninstallListeners but later in uninstallComponents - at that time
      * the handler is already nulled, removing will actually create a new one.
      */
+    @Test
     public void testEditorListeners() {
         JFormattedTextField field = new JFormattedTextField(DateFormat.getInstance());
         JXDatePicker picker = new JXDatePicker();
@@ -1387,6 +1528,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * quick&dirty fix: let the picker manually update.
      *
      */
+    @Test
     public void testEditorValueOnSetMonthView() {
         JXDatePicker picker = new JXDatePicker(new Date());
         // set unselected monthView
@@ -1410,6 +1552,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * 
      * 
      */
+    @Test
     public void testEditorValueOnSetEditor() {
         JXDatePicker picker = new JXDatePicker();
         Object value = picker.getEditor().getValue();
@@ -1425,6 +1568,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      *
      * @see #testEditorValueOnSetEditor
      */
+    @Test
     public void testEditorUpdateOnLF() {
         JXDatePicker picker = new JXDatePicker();
         Object date = picker.getEditor().getValue();
@@ -1442,6 +1586,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Here: model with selection.
      *
      */
+    @Test
     public void testSynchAllAfterSetSelectionModelNotEmpty() {
         JXDatePicker picker = new JXDatePicker();
         Date date = XTestUtils.getStartOfToday(5);
@@ -1462,6 +1607,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Here: model with empty selection.
      *
      */
+    @Test
     public void testSynchAllAfterSetSelectionModelEmpty() {
         JXDatePicker picker = new JXDatePicker(new Date());
         assertNotNull(picker.getDate());
@@ -1478,6 +1624,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Here: monthview with selection.
      *
      */
+    @Test
     public void testSynchAllSetMonthViewWithSelection() {
         JXDatePicker picker = new JXDatePicker();
         JXMonthView monthView = new JXMonthView();
@@ -1496,6 +1643,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * Here: monthview with empty selection.
      *
      */
+    @Test
     public void testSynchAllSetMonthViewWithEmptySelection() {
         JXDatePicker picker = new JXDatePicker(new Date());
         // sanity
@@ -1513,6 +1661,7 @@ public class JXDatePickerTest extends InteractiveTestCase {
      * If not, the initial size might appear kind of collapsed.
      *
      */
+    @Test
     public void testPrefSizeEmptyEditor() {
         JXDatePicker picker = new JXDatePicker(new Date());
         // sanity 
@@ -1523,11 +1672,13 @@ public class JXDatePickerTest extends InteractiveTestCase {
         assertEquals("pref width must be same for empty/filled", filled.width, empty.width);
     }
     
+    @Test
     public void testDefaultConstructor() {
         JXDatePicker datePicker = new JXDatePicker();
         assertNull(datePicker.getDate());
     }
 
+    @Test
     public void testConstructor() {
         calendar.setTimeInMillis(System.currentTimeMillis());
         calendar.add(Calendar.DAY_OF_MONTH, 5);
@@ -1536,11 +1687,13 @@ public class JXDatePickerTest extends InteractiveTestCase {
         assertTrue(expectedDate.equals(datePicker.getDate()));
     }
 
+    @Test
     public void testNullSelection() {
         JXDatePicker datePicker = new JXDatePicker();
         assertTrue(null == datePicker.getDate());
     }
 
+    @Test
     public void testSetDate() {
         calendar.setTimeInMillis(System.currentTimeMillis());
         calendar.add(Calendar.DAY_OF_MONTH, 5);
