@@ -33,6 +33,7 @@ import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.Locale;
+import java.util.TimeZone;
 import java.util.logging.Logger;
 
 import javax.swing.AbstractAction;
@@ -46,13 +47,21 @@ import javax.swing.JMenu;
 import javax.swing.JMenuBar;
 import javax.swing.JPanel;
 import javax.swing.JPopupMenu;
+import javax.swing.JSpinner;
+import javax.swing.JTabbedPane;
 import javax.swing.JTextField;
+import javax.swing.SpinnerDateModel;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.UnsupportedLookAndFeelException;
+import javax.swing.JSpinner.DefaultEditor;
 import javax.swing.UIManager.LookAndFeelInfo;
+import javax.swing.text.DateFormatter;
+import javax.swing.text.DefaultFormatterFactory;
 
 import org.jdesktop.swingx.action.AbstractActionExt;
+import org.jdesktop.swingx.calendar.DateSelectionModel;
+import org.jdesktop.swingx.calendar.DaySelectionModel;
 import org.jdesktop.swingx.calendar.SingleDaySelectionModel;
 import org.jdesktop.swingx.calendar.DateSelectionModel.SelectionMode;
 import org.jdesktop.test.VerticalLayoutPref;
@@ -79,6 +88,7 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
     }
 
     public static void main(String[] args) throws Exception {
+       UIManager.put("JXDatePicker.forceZoomable", Boolean.TRUE);
          setSystemLF(true);
         JXDatePickerVisualCheck test = new JXDatePickerVisualCheck();
         
@@ -86,12 +96,170 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
             test.runInteractiveTests();
 //            test.runInteractiveTests("interactive.*PrefSize.*");
 //            test.runInteractiveTests("interactive.*Keep.*");
+//          test.runInteractiveTests("interactive.*Multiple.*");
+//            test.runInteractiveTests("interactive.*Event.*");
         } catch (Exception e) {
             System.err.println("exception when executing interactive tests:");
             e.printStackTrace();
         }
     }
 
+    /**
+     * Issue #940-swingx: support multiple selection in picker.
+     * Nothing out-off-the-box, trying to implement custom 
+     * dateSelectionModel.
+     */
+    public void interactiveMultipleSelection() {
+        DateSelectionModel model = new AddingDaySelectionModel();
+        model.setSelectionMode(SelectionMode.MULTIPLE_INTERVAL_SELECTION);
+        JXMonthView monthView = new JXMonthView(new Date(), model) {
+
+            @Override
+            public Date getSelectionDate() {
+                if (getSelectionModel() instanceof AddingDaySelectionModel) {
+                    return ((AddingDaySelectionModel) getSelectionModel()).getLastAddedDate();
+                }
+                return super.getSelectionDate();
+            }
+            
+        };
+        JXDatePicker picker = new JXDatePicker();
+        picker.setMonthView(monthView);
+        JXFrame frame = showInFrame(picker, "multiple selection");
+        show(frame);
+    }
+    
+    /**
+     * Custom model which always adds selection dates.
+     */
+    public static class AddingDaySelectionModel extends DaySelectionModel {
+        
+        Date lastAdded;
+        
+        @Override
+        public void setSelectionInterval(Date startDate, Date endDate) {
+            addSelectionInterval(startDate, endDate);
+        }
+        
+        @Override
+        public void addSelectionInterval(Date startDate, Date endDate) {
+            if (endDate.before(startDate)) return;
+            super.addSelectionInterval(startDate, endDate);
+            // PENDING: need to do better to cope with unselectables
+            if (isSelected(endDate)) {
+              lastAdded = endDate;
+            } else if (isSelected(startDate)) {
+                lastAdded = startDate;
+            } else {
+                lastAdded = null;
+            }
+        }
+        
+        
+        @Override
+        public void clearSelection() {
+            lastAdded = null;
+            super.clearSelection();
+        }
+
+        public Date getLastAddedDate() {
+            return lastAdded;
+        }
+    }
+    /**
+     * Issue #910-swingx: commitToday must not be allowed if field not editable.
+     * 
+     */
+    public void interactiveNotEditableCommitToday() {
+        JXDatePicker picker = new JXDatePicker();
+        Calendar cal = picker.getMonthView().getCalendar();
+        cal.add(Calendar.MONTH, 5);
+        picker.setDate(cal.getTime());
+        picker.setEditable(false);
+        showInFrame(picker, "not editable ");
+    }
+    
+    /**
+     * Issue #910-swingx: commitToday must not be allowed if field not editable.
+     * 
+     */
+    public void interactiveNotEditableCompareTextField() {
+        final JXDatePicker picker = new JXDatePicker(new Date());
+        final JFormattedTextField field = new JFormattedTextField(picker.getDate());
+        field.setEditable(false);
+        PropertyChangeListener l = new PropertyChangeListener() {
+
+            public void propertyChange(PropertyChangeEvent evt) {
+                if ("date".equals(evt.getPropertyName())) {
+                    if (picker.getDate() != null)
+                     field.setValue(picker.getDate());
+                }
+            }
+            
+        };
+        picker.addPropertyChangeListener(l);
+        JXPanel panel = new JXPanel();
+        panel.add(picker);
+        panel.add(field);
+        showInFrame(panel, "not editable field ");
+    }
+    /**
+     * From forum: have spinner with the same timezone.
+     */
+    public void interactiveTimeZoneFormat() {
+        final JSpinner spinner = new JSpinner(new SpinnerDateModel());
+        final JXDatePicker picker = new JXDatePicker();
+        picker.setTimeZone(TimeZone.getTimeZone("GMT-10"));
+        picker.setDate(new Date());
+        spinner.setValue(picker.getDate());
+        SimpleDateFormat format = new SimpleDateFormat("HH:mm:ss", picker.getLocale());
+        format.setTimeZone(picker.getTimeZone());
+        JFormattedTextField textField = ((DefaultEditor) spinner.getEditor()).getTextField();
+        textField.setFormatterFactory(
+                new DefaultFormatterFactory(new DateFormatter(format)));
+        PropertyChangeListener l = new PropertyChangeListener() {
+
+            public void propertyChange(PropertyChangeEvent evt) {
+                if ("date".equals(evt.getPropertyName())) {
+                    if (picker.getDate() != null)
+                     spinner.setValue(picker.getDate());
+                }
+            }
+            
+        };
+        picker.addPropertyChangeListener(l);
+        JXPanel panel = new JXPanel();
+        panel.add(picker);
+        panel.add(spinner);
+        showInFrame(panel, "formats in picker and spinner");
+    }
+    /**
+     * Issue #565-swingx: popup not closed if open and 
+     * clicking into other focus-tricksing component (like
+     * picker, combo).
+     * 
+     * And: Compare picker and combo behaviour on toggle lf.
+     * 
+     * Not really comparable: the combo has complete control over the popup, re-creates
+     * both popup and content on install.
+     * 
+     */
+    public void interactiveUpdateUIPickerCompareCombo() {
+//      Trace14.keyboardFocusManager(true);
+       final JXDatePicker picker = new JXDatePicker();
+       picker.getEditor().setName("first DateField");
+        JComboBox box = new JComboBox(new Object[] {"one", "twooooooo", "threeeeeeeeeeee", "GOOO!"});
+        box.setEditable(true);
+        JComponent comp = new JPanel();
+        comp.add(picker);
+        comp.add(new JXDatePicker(new Date()));
+        comp.add(box);
+        JXFrame frame = wrapInFrame(comp, "compare combo <-> picker", true);
+        addMessage(frame, "open popup, click in other picker/combo - popup must close and other focused");
+        show(frame);
+    }
+    
+
     
     /**
      * Visually characterize focus behaviour.
@@ -117,7 +285,7 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
      * 
      * 
      */
-    public void interactiveFocusOnTogglePopup() {
+    public void interactiveFocusEventOnTogglePopup() {
         JXDatePicker picker = new JXDatePicker();
         final Action togglePopup = picker.getActionMap().get("TOGGLE_POPUP");
         JComboBox box = new JComboBox(new String[] {"one", "twos"});
@@ -487,6 +655,37 @@ public class JXDatePickerVisualCheck extends InteractiveTestCase {
         frame.pack();
     }
   
+    /**
+     * Checking PropertyChangeEvent: report in forum that no event for date fired.
+     * here not reproducible.. problem of WizardPage?
+     */
+    public void interactivePCEvent() {
+        JXDatePicker picker = new JXDatePicker(new Date());
+        JFormattedTextField textField = new JFormattedTextField(DateFormat.getDateInstance());
+        textField.setValue(new Date());
+        
+        PropertyChangeListener l = new PropertyChangeListener() {
+
+            public void propertyChange(PropertyChangeEvent e) {
+                LOG.info("got pce from: " + e.getSource().getClass().getSimpleName() + 
+                        "\n" + e.getPropertyName() + e.getNewValue());
+                
+            }
+            
+        };
+        textField.addPropertyChangeListener(l);
+        picker.addPropertyChangeListener(l);
+//        picker.getMonthView().addActionListener(l);
+        JPanel panel = new JPanel();
+        panel.add(textField);
+        panel.add(picker);
+        JTabbedPane tab = new JTabbedPane();
+        tab.add("fields", panel);
+        tab.add("dummy", new JTextField("dummy"));
+        JXFrame frame = showInFrame(tab, "Compare propertChange events: keyboard/mouse");
+        frame.pack();
+        
+    }
     
     /**
      * Issue #235-swingx: action events
