@@ -1,5 +1,5 @@
 /*
- * $Id: JXListTest.java,v 1.45 2008/05/09 08:37:30 kleopatra Exp $
+ * $Id: JXListTest.java,v 1.50 2008/12/23 18:12:36 kschaefe Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -12,7 +12,6 @@ import java.net.MalformedURLException;
 import java.net.URL;
 import java.text.Collator;
 import java.util.Vector;
-import java.util.regex.Pattern;
 
 import javax.swing.DefaultComboBoxModel;
 import javax.swing.DefaultListCellRenderer;
@@ -36,27 +35,49 @@ import org.jdesktop.swingx.decorator.SearchPredicate;
 import org.jdesktop.swingx.decorator.SelectionMapper;
 import org.jdesktop.swingx.decorator.SortKey;
 import org.jdesktop.swingx.decorator.SortOrder;
+import org.jdesktop.swingx.hyperlink.LinkModel;
 import org.jdesktop.swingx.renderer.DefaultListRenderer;
 import org.jdesktop.swingx.renderer.StringValue;
+import org.jdesktop.swingx.renderer.StringValues;
+import org.jdesktop.swingx.rollover.ListRolloverController;
+import org.jdesktop.swingx.rollover.RolloverProducer;
 import org.jdesktop.test.AncientSwingTeam;
 import org.jdesktop.test.ListDataReport;
 import org.jdesktop.test.PropertyChangeReport;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+import org.junit.Test;
+import org.junit.Before;
+import org.junit.After;
+
 
 /**
  * Testing JXList.
  * 
  * @author Jeanette Winzenburg
  */
+@RunWith(JUnit4.class)
 public class JXListTest extends InteractiveTestCase {
 
     protected ListModel listModel;
     protected DefaultListModel ascendingListModel;
 
     
+    @Before
+    public void setUpJ4() throws Exception {
+        setUp();
+    }
+    
+    @After
+    public void tearDownJ4() throws Exception {
+        tearDown();
+    }
+    
     /**
      * Issue #855-swingx: throws AIOOB on repeated remove/add.
      * Reason is that the lead/anchor is not removed in removeIndexInterval
      */
+    @Test
     public void testAddRemoveSelect() {
         DefaultListModel model = new DefaultListModel();
         model.addElement("something");
@@ -79,6 +100,7 @@ public class JXListTest extends InteractiveTestCase {
      * cleanup is different.
      * 
      */
+    @Test
     public void testAddRemoveSelectTable() {
         DefaultTableModel model = new DefaultTableModel(0, 1);
         model.addRow(new Object[] {"something"});
@@ -96,6 +118,7 @@ public class JXListTest extends InteractiveTestCase {
      * Issue #816-swingx: Delegating renderer must create list's default.
      * Consistent api: expose wrappedRenderer the same way as wrappedModel
      */
+    @Test
     public void testWrappedRendererDefault() {
         JXList list = new JXList();
         DelegatingRenderer renderer = (DelegatingRenderer) list.getCellRenderer();
@@ -107,6 +130,7 @@ public class JXListTest extends InteractiveTestCase {
      * Issue #816-swingx: Delegating renderer must create list's default.
      * Consistent api: expose wrappedRenderer the same way as wrappedModel
      */
+    @Test
     public void testWrappedRendererCustom() {
         JXList list = new JXList();
         DelegatingRenderer renderer = (DelegatingRenderer) list.getCellRenderer();
@@ -120,6 +144,7 @@ public class JXListTest extends InteractiveTestCase {
      * Issue #816-swingx: Delegating renderer must create list's default.
      * Delegating uses default on null, here: default default.
      */
+    @Test
     public void testDelegatingRendererUseDefaultSetNull() {
         JXList list = new JXList();
         ListCellRenderer defaultRenderer = list.createDefaultCellRenderer();
@@ -133,6 +158,7 @@ public class JXListTest extends InteractiveTestCase {
      * Issue #816-swingx: Delegating renderer must create list's default.
      * Delegating has default from list initially, here: default default.
      */
+    @Test
     public void testDelegatingRendererUseDefault() {
         JXList list = new JXList();
         ListCellRenderer defaultRenderer = list.createDefaultCellRenderer();
@@ -146,6 +172,7 @@ public class JXListTest extends InteractiveTestCase {
      * Issue #816-swingx: Delegating renderer must create list's default.
      * Delegating has default from list initially, here: custom default.
      */
+    @Test
     public void testDelegatingRendererUseCustomDefaultSetNull() {
         JXList list = new JXList() {
 
@@ -166,6 +193,7 @@ public class JXListTest extends InteractiveTestCase {
      * Issue #816-swingx: Delegating renderer must create list's default.
      * Delegating has default from list initially, here: custom default.
      */
+    @Test
     public void testDelegatingRendererUseCustomDefault() {
         JXList list = new JXList() {
 
@@ -192,6 +220,7 @@ public class JXListTest extends InteractiveTestCase {
      * 
      * Here: test api on JXTable.
      */
+    @Test
     public void testGetString() {
         JXList list = new JXList(AncientSwingTeam.createNamedColorListModel());
         StringValue sv = new StringValue() {
@@ -201,7 +230,7 @@ public class JXListTest extends InteractiveTestCase {
                     Color color = (Color) value;
                     return "R/G/B: " + color.getRGB();
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -216,6 +245,7 @@ public class JXListTest extends InteractiveTestCase {
      * 
      * Here: test single item remove fires interval removed
      */
+    @Test
     public void testListDataEventRemove() {
         JXList list = new JXList(ascendingListModel, true);
         ListDataReport report = new ListDataReport();
@@ -234,6 +264,7 @@ public class JXListTest extends InteractiveTestCase {
      * 
      * Here: test that a single item removal of a filtered element doesn't fire.
      */
+    @Test
     public void testListDataEventRemoveSingleFiltered() {
         JXList list = new JXList(ascendingListModel, true);
         assertEquals(20, list.getElementCount());
@@ -254,6 +285,7 @@ public class JXListTest extends InteractiveTestCase {
      *   correctly to the visible interval.
      *   
      */
+    @Test
     public void testListDataEventRemoveCutIntervalFiltered() {
         JXList list = new JXList(ascendingListModel, true);
         assertEquals(20, list.getElementCount());
@@ -280,6 +312,7 @@ public class JXListTest extends InteractiveTestCase {
      * Here: a removing a interval including all unfiltered value
      *   
      */
+    @Test
     public void testListDataEventRemoveIntervalFilteredAll() {
         JXList list = new JXList(ascendingListModel, true);
         assertEquals(20, list.getElementCount());
@@ -305,6 +338,7 @@ public class JXListTest extends InteractiveTestCase {
      * 
      * set single item fires contentsChanged with single index.
      */
+    @Test
     public void testListDataEventSingleSet() {
         JXList list = new JXList(ascendingListModel, true);
         ListDataReport report = new ListDataReport();
@@ -325,6 +359,7 @@ public class JXListTest extends InteractiveTestCase {
      * 
      * insert fires intervalAdded.
      */
+    @Test
     public void testListDataEventAdd() {
         JXList list = new JXList(ascendingListModel, true);
         ListDataReport report = new ListDataReport();
@@ -343,6 +378,7 @@ public class JXListTest extends InteractiveTestCase {
      * 
      * event source is the wrapping list model.
      */
+    @Test
     public void testListDataEventSource() {
         JXList list = new JXList(ascendingListModel, true);
         ListDataReport report = new ListDataReport();
@@ -365,6 +401,7 @@ public class JXListTest extends InteractiveTestCase {
      * How to test?
      *
      */
+    @Test
     public void testSetModelFlushFilter() {
         final JXList list = new JXList();
         list.setFilterEnabled(true);
@@ -385,6 +422,7 @@ public class JXListTest extends InteractiveTestCase {
      * super's contract.
      *
      */
+    @Test
     public void testSetModelEmptySelection() {
         final JXList list = new JXList();
         list.setFilterEnabled(true);
@@ -407,6 +445,7 @@ public class JXListTest extends InteractiveTestCase {
      * test that swingx renderer is used by default.
      *
      */
+    @Test
     public void testDefaultListRenderer() {
         JXList list = new JXList();
         ListCellRenderer renderer = ((DelegatingRenderer) list.getCellRenderer()).getDelegateRenderer();
@@ -424,11 +463,12 @@ public class JXListTest extends InteractiveTestCase {
      * invalid ComponentAdapter state. Negative invalid index.
      *
      */
+    @Test
     public void testIllegalNegativeListRowIndex() {
         JXList list = new JXList(new Object[] {1, 2, 3});
         ListCellRenderer renderer = list.getCellRenderer();
         renderer.getListCellRendererComponent(list, "dummy", -1, false, false);
-        SearchPredicate predicate = new SearchPredicate(Pattern.compile("\\QNode\\E"));
+        SearchPredicate predicate = new SearchPredicate("\\QNode\\E");
         Highlighter searchHighlighter = new ColorHighlighter(predicate, null, Color.RED);
         list.addHighlighter(searchHighlighter);
         renderer.getListCellRendererComponent(list, "dummy", -1, false, false);
@@ -443,11 +483,12 @@ public class JXListTest extends InteractiveTestCase {
      * invalid ComponentAdapter state. Invalid index > valid range.
      *
      */
+    @Test
     public void testIllegalExceedingListRowIndex() {
         JXList list = new JXList(new Object[] {1, 2, 3});
         ListCellRenderer renderer = list.getCellRenderer();
         renderer.getListCellRendererComponent(list, "dummy", list.getElementCount(), false, false);
-        SearchPredicate predicate = new SearchPredicate(Pattern.compile("\\QNode\\E"));
+        SearchPredicate predicate = new SearchPredicate("\\QNode\\E");
         Highlighter searchHighlighter = new ColorHighlighter(predicate, null, Color.RED);
         list.addHighlighter(searchHighlighter);
         renderer.getListCellRendererComponent(list, "dummy", list.getElementCount(), false, false);
@@ -457,6 +498,7 @@ public class JXListTest extends InteractiveTestCase {
      * test convenience method accessing the configured adapter.
      *
      */
+    @Test
     public void testConfiguredComponentAdapter() {
         JXList list = new JXList(new Object[] {1, 2, 3});
         ComponentAdapter adapter = list.getComponentAdapter();
@@ -477,6 +519,7 @@ public class JXListTest extends InteractiveTestCase {
      * PENDING: the default's getValue() implementation is incorrect!
      *
      */
+    @Test
     public void testComponentAdapterCoordinates() {
         JXList list = new JXList(ascendingListModel, true);
         Object originalFirstRowValue = list.getElementAt(0);
@@ -510,6 +553,7 @@ public class JXListTest extends InteractiveTestCase {
      * test exceptions on null data(model, vector, array).
      *
      */
+    @Test
     public void testNullData() {
         try {
             new JXList((ListModel) null);
@@ -544,6 +588,7 @@ public class JXListTest extends InteractiveTestCase {
      * test filterEnabled property on initialization.
      *
      */
+    @Test
     public void testConstructorFilterEnabled() {
         // 
         assertFilterEnabled(new JXList(), false);
@@ -570,6 +615,7 @@ public class JXListTest extends InteractiveTestCase {
      * added xtable.setSortOrder(int, SortOrder)
      * 
      */
+    @Test
     public void testSetSortOrder() {
         JXList list = new JXList(ascendingListModel, true);
         list.setSortOrder(SortOrder.ASCENDING);
@@ -580,6 +626,7 @@ public class JXListTest extends InteractiveTestCase {
      * JXList has responsibility to guarantee usage of 
      * its comparator: setComparator if already sorted.
      */
+    @Test
     public void testDynamicComparatorToSortController() {
         JXList list = new JXList(listModel, true);
         list.toggleSortOrder();
@@ -593,6 +640,7 @@ public class JXListTest extends InteractiveTestCase {
      * JXList has responsibility to guarantee usage of 
      * its comparator: toggle.
      */
+    @Test
     public void testToggleComparatorToSortController() {
         JXList list = new JXList(listModel, true);
         list.setComparator(Collator.getInstance());
@@ -606,6 +654,7 @@ public class JXListTest extends InteractiveTestCase {
      * JXList has responsibility to guarantee usage of 
      * its comparator: set.
      */
+    @Test
     public void testSetComparatorToSortController() {
         JXList list = new JXList(listModel, true);
         list.setComparator(Collator.getInstance());
@@ -619,6 +668,7 @@ public class JXListTest extends InteractiveTestCase {
      * add and test comparator property.
      * 
      */
+    @Test
     public void testComparator() {
         JXList list = new JXList();
         assertNull(list.getComparator());
@@ -636,6 +686,7 @@ public class JXListTest extends InteractiveTestCase {
      * getSortOrder(), toggleSortOrder(), resetSortOrder().
      *
      */
+    @Test
     public void testToggleSortOrder() {
         JXList list = new JXList(ascendingListModel, true);
         assertSame(SortOrder.UNSORTED, list.getSortOrder());
@@ -650,6 +701,7 @@ public class JXListTest extends InteractiveTestCase {
     /**
      * prepare sort testing: internal probs with SortController?
      */
+    @Test
     public void testSortController() {
         JXList list = new JXList(ascendingListModel, true);
         assertNotNull("sortController must be initialized", list.getSortController());
@@ -659,6 +711,7 @@ public class JXListTest extends InteractiveTestCase {
      * Issue #232-swingx: selection not kept if selectionModel had been changed.
      *
      */
+    @Test
     public void testSelectionMapperUpdatedOnSelectionModelChange() {
         JXList table = new JXList(true);
         // created lazily, to see the failure,
@@ -674,6 +727,7 @@ public class JXListTest extends InteractiveTestCase {
      *
      *  PENDING: selectionMapper shouldn't be available if list not filterable? 
      */
+    @Test
     public void testSelectionMapperFilterDisabled() {
         JXList table = new JXList();
         // created lazily, need to get hold before replacing list's selection
@@ -688,6 +742,7 @@ public class JXListTest extends InteractiveTestCase {
      * setRolloverEnabled.
      *
      */
+    @Test
     public void testLinkControllerListening() {
         JXList table = new JXList();
         table.setRolloverEnabled(true);
@@ -703,13 +758,14 @@ public class JXListTest extends InteractiveTestCase {
     private PropertyChangeListener getLinkControllerAsPropertyChangeListener(JXList table, String propertyName) {
         PropertyChangeListener[] listeners = table.getPropertyChangeListeners(propertyName);
         for (int i = 0; i < listeners.length; i++) {
-            if (listeners[i] instanceof JXList.ListRolloverController) {
-                return (JXList.ListRolloverController) listeners[i];
+            if (listeners[i] instanceof ListRolloverController) {
+                return (ListRolloverController) listeners[i];
             }
         }
         return null;
     }
 
+    @Test
     public void testConvertToModelPreconditions() {
         final JXList list = new JXList(ascendingListModel, true);
         assertEquals(20, list.getElementCount());
@@ -727,6 +783,7 @@ public class JXListTest extends InteractiveTestCase {
     }
  
 
+    @Test
     public void testElementAtPreconditions() {
         final JXList list = new JXList(ascendingListModel, true);
         assertEquals(20, list.getElementCount());
@@ -754,6 +811,7 @@ public class JXListTest extends InteractiveTestCase {
      * http://www.javadesktop.org/forums/thread.jspa?messageID=117814
      *
      */
+    @Test
     public void testSelectionListenerNotification() {
         final JXList list = new JXList(ascendingListModel, true);
         assertEquals(20, list.getElementCount());
@@ -783,6 +841,7 @@ public class JXListTest extends InteractiveTestCase {
      * 
      *
      */
+    @Test
     public void testSetFilterEnabledWithSelection() {
         final JXList list = new JXList(ascendingListModel);
         assertEquals(20, list.getElementCount());
@@ -793,12 +852,14 @@ public class JXListTest extends InteractiveTestCase {
         
     }
 
+    @Test
     public void testEmptyFilter() {
         JXList list = new JXList(ascendingListModel);
         assertEquals(ascendingListModel.getSize(), list.getElementCount());
         assertEquals(ascendingListModel.getElementAt(0), list.getElementAt(0));
     }
     
+    @Test
     public void testFilterEnabled() {
         JXList list = new JXList(ascendingListModel, true);
         assertNotSame(ascendingListModel, list.getModel());
@@ -812,6 +873,7 @@ public class JXListTest extends InteractiveTestCase {
      * it's not allowed to reset filterEnabled property to false again.
      *
      */
+    @Test
     public void testFilterEnabledAndDisabled() {
         JXList list = new JXList(ascendingListModel, true);
         try {
@@ -828,6 +890,7 @@ public class JXListTest extends InteractiveTestCase {
         
     }
     
+    @Test
     public void testSortingFilterEnabled() {
         JXList list = new JXList(ascendingListModel, true);
         FilterPipeline pipeline = list.getFilters();
@@ -838,6 +901,7 @@ public class JXListTest extends InteractiveTestCase {
         
     }
     
+    @Test
     public void testSortingKeepsModelSelection() {
         JXList list = new JXList(ascendingListModel, true);
         list.setSelectedIndex(0);
@@ -855,6 +919,7 @@ public class JXListTest extends InteractiveTestCase {
      *  
      *
      */
+    @Test
     public void testFilterDisabled() {
         JXList list = new JXList();
         list.setModel(ascendingListModel);
@@ -877,6 +942,7 @@ public class JXListTest extends InteractiveTestCase {
      * This fails after quick fix for #370-swingx. 
      *
      */
+    @Test
     public void testSelectionAfterAddAtFirst() {
         JXList list = new JXList(ascendingListModel, true);
         // selecte second row
@@ -896,6 +962,7 @@ public class JXListTest extends InteractiveTestCase {
      * sanity test: compare table with list behaviour (#377-swingx)
      * 
      */
+    @Test
     public void testSelectionAfterAddAtFirstCompareTable() {
         DefaultTableModel ascendingModel = new DefaultTableModel(20, 2);
         JXTable table = new JXTable(ascendingModel);
@@ -915,6 +982,7 @@ public class JXListTest extends InteractiveTestCase {
      * This fails after quick fix for #370-swingx. 
      *
      */
+    @Test
     public void testSelectionAfterAddAbove() {
         JXList list = new JXList(ascendingListModel, true);
         // selecte second row
@@ -935,6 +1003,7 @@ public class JXListTest extends InteractiveTestCase {
      * test if selection is updated on add row above selection.
      *
      */
+    @Test
     public void testAddRowAboveSelectionInvertedOrder() {
         JXList list = new JXList(ascendingListModel, true);
         // select the last row in view coordinates
@@ -961,6 +1030,7 @@ public class JXListTest extends InteractiveTestCase {
      * This fails after quick fix for #370-swingx. 
      *
      */
+    @Test
     public void testSelectionAfterDeleteAbove() {
         JXList list = new JXList(ascendingListModel, true);
         // selecte second row
@@ -975,6 +1045,7 @@ public class JXListTest extends InteractiveTestCase {
      * sanity test: compare table with list behaviour (#370-swingx)
      * 
      */
+    @Test
     public void testSelectionAfterDeleteAboveCompareTable() {
         DefaultTableModel ascendingModel = new DefaultTableModel(20, 2);
         JXTable table = new JXTable(ascendingModel);
