@@ -1,5 +1,5 @@
 /*
- * $Id: JXMonthViewVisualCheck.java,v 1.32 2008/03/03 13:15:33 kleopatra Exp $
+ * $Id: JXMonthViewVisualCheck.java,v 1.38 2008/10/30 16:38:39 kleopatra Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -21,6 +21,7 @@
  */
 package org.jdesktop.swingx;
 
+import java.awt.Color;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.MouseAdapter;
@@ -32,6 +33,7 @@ import java.util.Locale;
 import java.util.TimeZone;
 import java.util.logging.Logger;
 
+import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.Box;
 import javax.swing.JButton;
@@ -60,18 +62,99 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
     private Calendar calendar;
 
     public static void main(String[] args) {
+//        UIManager.put("JXDatePicker.forceZoomable", Boolean.TRUE);
       setSystemLF(true);
       JXMonthViewVisualCheck  test = new JXMonthViewVisualCheck();
       try {
-//          test.runInteractiveTests();
-        test.runInteractiveTests(".*TimeZone.*");
-//        test.runInteractiveTests("interactive.*Toggle.*");
+          test.runInteractiveTests();
+//        test.runInteractiveTests(".*TimeZone.*");
+//        test.runInteractiveTests("interactive.*Zoomable.*");
       } catch (Exception e) {
           System.err.println("exception when executing interactive tests:");
           e.printStackTrace();
       }
   }
 
+    public void interactiveRevalidateOnZoomable() {
+        final JXMonthView monthView = new JXMonthView();
+        JXFrame frame = wrapInFrame(monthView, "Revalidate on zoomable");
+        Action toggleBackground = new AbstractAction("toggleZoomable") {
+            
+            public void actionPerformed(ActionEvent e) {
+                monthView.setZoomable(!monthView.isZoomable());
+                        
+            }
+            
+        };
+        addAction(frame, toggleBackground);
+        Action toggleTraversable = new AbstractAction("toggleTraversable") {
+            
+            private boolean traversable;
+
+            public void actionPerformed(ActionEvent e) {
+                traversable = !traversable;
+                monthView.setTraversable(traversable);
+                        
+            }
+            
+        };
+        addAction(frame, toggleTraversable);
+        show(frame);
+
+    }
+    /**
+     * Issue #931-swingx: JXMonthView not repainted on property change.
+     * 
+     * look for
+     * - selectionBackground
+     * - selectionForeground (not taken?)
+     * 
+     * 
+     */
+    public void interactiveRepaintOnPropertyChange() {
+        final JXMonthView monthView = new JXMonthView();
+        monthView.setSelectionDate(CalendarUtils.startOfWeek(calendar, new Date()));
+        monthView.setFlaggedDates(CalendarUtils.endOfWeek(calendar, new Date()));
+        final Color selectionBackground = monthView.getSelectionBackground();
+        final Color selectionForeground = monthView.getSelectionForeground();
+        final Color flaggedDayForeground = monthView.getFlaggedDayForeground();
+        JXFrame frame = wrapInFrame(monthView, "repaint on propertyChange");
+        Action toggleBackground = new AbstractAction("toggleSelectionBack") {
+            
+            public void actionPerformed(ActionEvent e) {
+                monthView.setSelectionBackground(
+                        Color.PINK.equals(monthView.getSelectionBackground()) ? 
+                                selectionBackground : Color.PINK);
+            }
+            
+        };
+        addAction(frame, toggleBackground);
+        Action toggleForeground = new AbstractAction("toggleSelectionFore") {
+            
+            public void actionPerformed(ActionEvent e) {
+                
+                monthView.setSelectionForeground(
+                        Color.RED.equals(monthView.getSelectionForeground()) ? 
+                                selectionForeground : Color.RED);
+            }
+            
+        };
+        addAction(frame, toggleForeground);
+        Action toggleFlaggedForeground = new AbstractAction("toggleFlaggedFore") {
+            
+            public void actionPerformed(ActionEvent e) {
+                
+                monthView.setFlaggedDayForeground(
+                        Color.GREEN.equals(monthView.getFlaggedDayForeground()) ? 
+                                flaggedDayForeground : Color.GREEN);
+            }
+            
+        };
+        addAction(frame, toggleFlaggedForeground);
+        show(frame);
+        
+    }
+
     /**
      * Issue #786-swingx: IllegalStateException when paintDays of April 2008.
      * 
@@ -158,13 +241,6 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
             
         };
         addAction(frame, today);
-        Action antialiased = new AbstractActionExt("antialiased") {
-            public void actionPerformed(ActionEvent e) {
-                monthView.setAntialiased(!monthView.isAntialiased());
-            }
-            
-        };
-        addAction(frame, antialiased);
         Action daysOfWeek = new AbstractActionExt("daysOfWeek") {
             String[] days = {"S", "M", "D", "M", "D", "F", "S"};
             public void actionPerformed(ActionEvent e) {
@@ -282,7 +358,7 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
      */
     public void interactiveUpdateUIMonthView() {
 //        calendar.set(1955, 10, 9);
-        final JXMonthView monthView = new JXMonthView(); //calendar.getTimeInMillis());
+        final JXMonthView monthView = new JXMonthView(); 
         monthView.setTraversable(true);
         final JXFrame frame = showInFrame(monthView, "MonthView update ui - visible month kept");
         Action action = new AbstractActionExt("toggleUI") {
@@ -453,10 +529,10 @@ public class JXMonthViewVisualCheck extends InteractiveTestCase {
     public void interactiveUpdateLocale() {
         JComponent panel = Box.createVerticalBox();
 
-        final JComboBox zoneSelector = new JComboBox(Locale.getAvailableLocales());
         final JXMonthView monthView = new JXMonthView();
         monthView.setTraversable(true);
         monthView.setShowingWeekNumber(true);
+        final JComboBox zoneSelector = new JComboBox(Locale.getAvailableLocales());
         // Synchronize the monthView's and selector's zones.
         zoneSelector.setSelectedItem(monthView.getLocale());
 
