@@ -1,5 +1,5 @@
 /*
- * $Id: JXTableIssues.java,v 1.83 2008/05/15 11:42:49 kleopatra Exp $
+ * $Id: JXTableIssues.java,v 1.90 2008/12/05 14:34:58 kschaefe Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -66,6 +66,7 @@ import org.jdesktop.swingx.action.BoundAction;
 import org.jdesktop.swingx.decorator.AbstractHighlighter;
 import org.jdesktop.swingx.decorator.ColorHighlighter;
 import org.jdesktop.swingx.decorator.ComponentAdapter;
+import org.jdesktop.swingx.decorator.Filter;
 import org.jdesktop.swingx.decorator.FilterPipeline;
 import org.jdesktop.swingx.decorator.HighlightPredicate;
 import org.jdesktop.swingx.decorator.PatternFilter;
@@ -95,17 +96,53 @@ public class JXTableIssues extends InteractiveTestCase {
         JXTableIssues test = new JXTableIssues();
         setSystemLF(true);
         try {
-//          test.runInteractiveTests();
+          test.runInteractiveTests();
 //            test.runInteractiveTests("interactive.*Scroll.*");
          //   test.runInteractiveTests("interactive.*Render.*");
 //            test.runInteractiveTests("interactive.*Sort.*");
-            test.runInteractiveTests("interactive.*Highlight.*");
+//            test.runInteractiveTests("interactive.*Repaint.*");
         } catch (Exception e) {
             System.err.println("exception when executing interactive tests:");
             e.printStackTrace();
         } 
     }
     
+    /**
+     * Quick check for a forum report:
+     * getValueAt called on init for each cell (even the invisible).
+     * 
+     * Looks okay: getValueAt called for visible cells only.
+     * @throws Exception 
+     * 
+     */
+    public void testGetValueOnInit() throws Exception {
+        // This test will not work in a headless configuration.
+        if (GraphicsEnvironment.isHeadless()) {
+            LOG.info("cannot run test - headless environment");
+            return;
+        }
+        final List<Integer> set = new ArrayList<Integer>();
+        final JXTable table = new JXTable() {
+
+            @Override
+            public Object getValueAt(int row, int column) {
+                set.add(row);
+                return super.getValueAt(row, column);
+            }
+            
+        };
+        showWithScrollingInFrame(table, "");
+        table.setModel(new DefaultTableModel(100, 5));
+        SwingUtilities.invokeAndWait(new Runnable() {
+            public void run() {
+                // failing - one row off?
+                assertEquals(table.getColumnCount() * table.getVisibleRowCount(), set.size());
+                
+            }
+        });
+
+    }
+
     /**
      * Issue #856-swingx: no notification on filters changed
      */
@@ -137,87 +174,6 @@ public class JXTableIssues extends InteractiveTestCase {
         assertEquals("sanity: new pipeline set", other, table.getFilters());
         TestUtils.assertPropertyChangeEvent(report, "filters", pipeline, other, false);
     }
-    /**
-     * Issue #610-swingx: Cancel editing via Escape doesn't fire editingCanceled.
-     * 
-     * Reported against ComboBoxCellEditor in the autoComplete package, but actually
-     * a JTable _never_ fires a editingCanceled for any editor. Reason is that the
-     * cancel Action registered in BasisTableUI incorrectly calls table.removeEditor
-     * instead of getCelleditor.cancelEditing.
-     * 
-     * Quick hack around that: JXTable registers its own cancel action.
-     * 
-     * Still open: esc when popup is open will only close the popup, not cancel the
-     * edit (which requires a second esc). 
-     *  
-     */
-    public void interactiveEditingCanceledOnEscape() {
-        final JTextField field = new JTextField();
-        JXTable xTable = new JXTable(10, 3);
-        CellEditor editor = xTable.getDefaultEditor(Object.class);
-        CellEditorListener l =  new CellEditorListener() {
-
-            public void editingCanceled(ChangeEvent e) {
-                field.setText("canceled");
-                
-            }
-
-            public void editingStopped(ChangeEvent e) {
-                field.setText("stopped");
-                
-            }};
-        editor.addCellEditorListener(l);
-        JTable table = new JTable(xTable.getModel());
-        CellEditor coreEditor = table.getDefaultEditor(Object.class);
-        coreEditor.addCellEditorListener(l);
-        JXFrame frame = wrapWithScrollingInFrame(xTable, table, "#610-swingx: escape doesn't fire editing canceled");
-        frame.add(field, BorderLayout.SOUTH);
-        frame.setVisible(true);
-    }
-    /**
-     * row index conversion goes nuts if not re-sorted on update.
-     * Looks like a repaint problem.
-     */
-    public void interactiveSortOnUpdate() {
-        JXTable xtable = new JXTable(new AncientSwingTeam()) {
-
-            @Override
-            protected boolean shouldSortOnChange(TableModelEvent e) {
-                if (isUpdate(e)) {
-                    return false;
-                }
-                return super.shouldSortOnChange(e);
-            }
-            
-        };
-        JXTable table = new JXTable(xtable.getModel()) {
-
-            @Override
-            protected boolean shouldSortOnChange(TableModelEvent e) {
-                if (isUpdate(e)) {
-                    repaint(e);
-                    return false;
-                }
-                return super.shouldSortOnChange(e);
-            }
-
-            /**
-             * Hack to repaint at the correct row in terms of 
-             * view coordinates.
-             * @param e
-             */
-            private void repaint(TableModelEvent e) {
-                int firstRow = convertRowIndexToView(e.getFirstRow());
-                Rectangle rowRect = getCellRect(firstRow, 0, true);
-                rowRect.width = getWidth();
-                repaint(rowRect);
-            }
-            
-        };
-        JXFrame frame = wrapWithScrollingInFrame(xtable, table, "edit and shouldSortOnChange false");
-        frame.setVisible(true);
-    }
-    
 
     /**
      * Issue #847-swingx: JXTable respect custom corner if columnControl not visible
@@ -526,7 +482,161 @@ public class JXTableIssues extends InteractiveTestCase {
     }
 
 //----------------- interactive
+
+    /**
+     * Unconditional repaint on cell update (through the default
+     * identify filter). 
+     */
+    public void interactiveRepaintOnUpdateSingleCell() {
+        JXTable table =  new JXTable(10, 5);
+        // highlight complete row if first cell starts with a
+        HighlightPredicate predicate = new HighlightPredicate() {
+
+            public boolean isHighlighted(Component renderer,
+                    ComponentAdapter adapter) {
+                return adapter.getString(0).startsWith("a");
+            }
+            
+        };
+        ColorHighlighter highlighter = new ColorHighlighter(predicate, Color.MAGENTA, null, Color.MAGENTA, null);
+        table.addHighlighter(highlighter);
+        JXTable other = new JXTable(table.getModel());
+        other.setFilters(new FilterPipeline(new IdentityFilter()));
+        other.addHighlighter(highlighter);
+        JXFrame frame = wrapWithScrollingInFrame(table, other, "repaint on update in first");
+        addMessage(frame, "edit first cell in left table (start with/out a)");
+        show(frame);
+    }
     
+    public class IdentityFilter extends Filter {
+        
+        
+        /**
+         * PENDING JW: fires always, even without sorter ..
+         * Could do better - but will break behaviour of apps which relied on
+         * the (buggy) side-effect of repainting on each change.
+         * 
+         */
+        @Override
+        public void refresh() {
+            if ((pipeline == null) ||
+              (pipeline.getSortController().getSortKeys().size() == 0)) return;
+            super.refresh();
+        }
+
+        @Override
+        protected void init() {
+
+        }
+
+        @Override
+        protected void reset() {
+
+        }
+
+        @Override
+        protected void filter() {
+
+        }
+
+        @Override
+        public int getSize() {
+            return this.getInputSize();
+        }
+
+        @Override
+        protected int mapTowardModel(int row) {
+            return row;
+        }
+
+        @Override
+        protected int mapTowardView(int row) {
+            return row;
+        }
+    }
+
+    /**
+     * Issue #610-swingx: Cancel editing via Escape doesn't fire editingCanceled.
+     * 
+     * Reported against ComboBoxCellEditor in the autoComplete package, but actually
+     * a JTable _never_ fires a editingCanceled for any editor. Reason is that the
+     * cancel Action registered in BasisTableUI incorrectly calls table.removeEditor
+     * instead of getCelleditor.cancelEditing.
+     * 
+     * Quick hack around that: JXTable registers its own cancel action.
+     * 
+     * Still open: esc when popup is open will only close the popup, not cancel the
+     * edit (which requires a second esc). 
+     *  
+     */
+    public void interactiveEditingCanceledOnEscape() {
+        final JTextField field = new JTextField();
+        JXTable xTable = new JXTable(10, 3);
+        CellEditor editor = xTable.getDefaultEditor(Object.class);
+        CellEditorListener l =  new CellEditorListener() {
+
+            public void editingCanceled(ChangeEvent e) {
+                field.setText("canceled");
+                
+            }
+
+            public void editingStopped(ChangeEvent e) {
+                field.setText("stopped");
+                
+            }};
+        editor.addCellEditorListener(l);
+        JTable table = new JTable(xTable.getModel());
+        CellEditor coreEditor = table.getDefaultEditor(Object.class);
+        coreEditor.addCellEditorListener(l);
+        JXFrame frame = wrapWithScrollingInFrame(xTable, table, "#610-swingx: escape doesn't fire editing canceled");
+        frame.add(field, BorderLayout.SOUTH);
+        frame.setVisible(true);
+    }
+    /**
+     * row index conversion goes nuts if not re-sorted on update.
+     * Looks like a repaint problem.
+     */
+    public void interactiveSortOnUpdate() {
+        JXTable xtable = new JXTable(new AncientSwingTeam()) {
+
+            @Override
+            protected boolean shouldSortOnChange(TableModelEvent e) {
+                if (isUpdate(e)) {
+                    return false;
+                }
+                return super.shouldSortOnChange(e);
+            }
+            
+        };
+        JXTable table = new JXTable(xtable.getModel()) {
+
+            @Override
+            protected boolean shouldSortOnChange(TableModelEvent e) {
+                if (isUpdate(e)) {
+                    repaint(e);
+                    return false;
+                }
+                return super.shouldSortOnChange(e);
+            }
+
+            /**
+             * Hack to repaint at the correct row in terms of 
+             * view coordinates.
+             * @param e
+             */
+            private void repaint(TableModelEvent e) {
+                int firstRow = convertRowIndexToView(e.getFirstRow());
+                Rectangle rowRect = getCellRect(firstRow, 0, true);
+                rowRect.width = getWidth();
+                repaint(rowRect);
+            }
+            
+        };
+        JXFrame frame = wrapWithScrollingInFrame(xtable, table, "edit and shouldSortOnChange false");
+        frame.setVisible(true);
+    }
+    
+
     public void interactiveIndividualRowHeightAndFilter() {
         final JXTable table = new JXTable(createAscendingModel(0, 50));
         table.setRowHeightEnabled(true);
@@ -757,9 +867,9 @@ public class JXTableIssues extends InteractiveTestCase {
      * A one column table model where all the data is in an Object[] array.
      */
     static class ReallySimpleTableModel extends AbstractTableModel {
-        private List contents = new ArrayList();
-        @SuppressWarnings("unchecked")
-        public void setContents(List contents) {
+        private List<Object> contents = new ArrayList<Object>();
+        
+        public void setContents(List<Object> contents) {
             this.contents.clear();
             this.contents.addAll(contents);
             fireTableDataChanged();
