@@ -1,5 +1,5 @@
 /*
- * $Id: JXTableVisualCheck.java,v 1.81 2008/04/16 13:13:25 kleopatra Exp $
+ * $Id: JXTableVisualCheck.java,v 1.86 2008/08/05 10:17:48 kleopatra Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -50,6 +50,7 @@ import javax.swing.event.ListSelectionListener;
 import javax.swing.event.TableColumnModelEvent;
 import javax.swing.table.DefaultTableCellRenderer;
 import javax.swing.table.DefaultTableModel;
+import javax.swing.table.TableCellEditor;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumn;
 import javax.swing.table.TableModel;
@@ -57,7 +58,6 @@ import javax.swing.table.TableModel;
 import org.jdesktop.swingx.JXTable.NumberEditor;
 import org.jdesktop.swingx.JXTableHeader.SortGestureRecognizer;
 import org.jdesktop.swingx.action.AbstractActionExt;
-import org.jdesktop.swingx.action.LinkModelAction;
 import org.jdesktop.swingx.decorator.AbstractHighlighter;
 import org.jdesktop.swingx.decorator.ColorHighlighter;
 import org.jdesktop.swingx.decorator.ComponentAdapter;
@@ -70,10 +70,15 @@ import org.jdesktop.swingx.decorator.PatternFilter;
 import org.jdesktop.swingx.decorator.ShuttleSorter;
 import org.jdesktop.swingx.decorator.SortController;
 import org.jdesktop.swingx.decorator.Sorter;
+import org.jdesktop.swingx.hyperlink.LinkModel;
+import org.jdesktop.swingx.hyperlink.LinkModelAction;
+import org.jdesktop.swingx.renderer.CheckBoxProvider;
 import org.jdesktop.swingx.renderer.DefaultTableRenderer;
 import org.jdesktop.swingx.renderer.HyperlinkProvider;
+import org.jdesktop.swingx.search.SearchFactory;
 import org.jdesktop.swingx.table.ColumnFactory;
 import org.jdesktop.swingx.table.ColumnHeaderRenderer;
+import org.jdesktop.swingx.table.DatePickerCellEditor;
 import org.jdesktop.swingx.table.NumberEditorExt;
 import org.jdesktop.swingx.table.TableColumnExt;
 import org.jdesktop.test.AncientSwingTeam;
@@ -93,7 +98,7 @@ public class JXTableVisualCheck extends JXTableUnitTest {
       JXTableVisualCheck test = new JXTableVisualCheck();
       try {
 //        test.runInteractiveTests();
-//          test.runInteractiveTests("interactive.*ColumnControl.*");
+          test.runInteractiveTests("interactive.*ColumnControl.*");
 //          test.runInteractiveTests("interactive.*Header.*");
 //          test.runInteractiveTests("interactive.*ColumnProp.*");
 //          test.runInteractiveTests("interactive.*Multiple.*");
@@ -103,7 +108,7 @@ public class JXTableVisualCheck extends JXTableUnitTest {
           
 //          test.runInteractiveTests("interactive.*Policy.*");
 //        test.runInteractiveTests("interactive.*Rollover.*");
-        test.runInteractiveTests("interactive.*Vertical.*");
+        test.runInteractiveTests("interactive.*UpdateUI.*");
 //        test.runInteractiveTests("interactiveColumnHighlighting");
       } catch (Exception e) {
           System.err.println("exception when executing interactive tests:");
@@ -119,6 +124,66 @@ public class JXTableVisualCheck extends JXTableUnitTest {
         setSystemLF(true);
     }
 
+    /**
+     * Issue #908-swingx: move updateUI responsibility into column.
+     * 
+     */
+    public void interactiveUpdateUIRenderers() {
+        JXTable table = new JXTable(new AncientSwingTeam());
+        table.getColumn(4).setCellRenderer(new DefaultTableRenderer(new CheckBoxProvider()));
+        showWithScrollingInFrame(table, "toggle ui - must update renderers");
+    }
+    
+    /**
+     * Issue #908-swingx: move updateUI responsibility into column.
+     * 
+     */
+    public void interactiveUpdateUIEditors() {
+        DefaultTableModel model = new DefaultTableModel(5, 5) {
+
+            @Override
+            public Class<?> getColumnClass(int columnIndex) {
+                if (getValueAt(0, columnIndex) == null)
+                    return super.getColumnClass(columnIndex);
+                return getValueAt(0, columnIndex).getClass();
+            }
+            
+        };
+        for (int i = 0; i < model.getRowCount(); i++) {
+            model.setValueAt(new Date(), i, 0);
+        }
+        JXTable table = new JXTable(model);
+        TableCellEditor editor = new DatePickerCellEditor();
+        table.getColumn(0).setCellEditor(editor);
+        showWithScrollingInFrame(table, "toggle ui - must update editors");
+    }
+    /**
+     * Issue #550-swingx: xtable must not reset columns' pref/size on 
+     * structureChanged if autocreate is false.
+     * 
+     *  
+     */
+    public void interactiveColumnWidthOnStructureChanged() {
+        final JXTable table = new JXTable(new AncientSwingTeam());
+        table.setAutoCreateColumnsFromModel(false);
+        table.setAutoResizeMode(JXTable.AUTO_RESIZE_OFF);
+        table.setColumnControlVisible(true);
+        // min/max is respected
+//        mini.setMaxWidth(5);
+//        mini.setMinWidth(5);
+        Action structureChanged = new AbstractAction("fire structure changed") {
+
+            public void actionPerformed(ActionEvent e) {
+                table.tableChanged(null);
+            }
+            
+        };
+        JXFrame frame = showWithScrollingInFrame(table, "structure change must not re-size columns");
+        addAction(frame, structureChanged);
+        show(frame);
+    }
+    
+
     /**
      * Issue #675-swingx: esc doesn't reach rootpane.
      * 
