@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeTableIssues.java,v 1.66 2008/03/19 09:07:25 kleopatra Exp $
+ * $Id: JXTreeTableIssues.java,v 1.79 2008/12/23 18:12:36 kschaefe Exp $
  * 
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
  * California 95054, U.S.A. All rights reserved.
@@ -20,7 +20,6 @@
  */
 package org.jdesktop.swingx;
 
-import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.event.ActionEvent;
@@ -32,19 +31,13 @@ import java.util.logging.Logger;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.BorderFactory;
-import javax.swing.CellEditor;
 import javax.swing.JFrame;
-import javax.swing.JTextField;
 import javax.swing.JTree;
 import javax.swing.SwingUtilities;
 import javax.swing.Timer;
-import javax.swing.TransferHandler;
 import javax.swing.UIManager;
 import javax.swing.border.Border;
-import javax.swing.event.CellEditorListener;
-import javax.swing.event.ChangeEvent;
 import javax.swing.event.TableModelEvent;
-import javax.swing.table.TableCellRenderer;
 import javax.swing.tree.DefaultMutableTreeNode;
 import javax.swing.tree.DefaultTreeCellRenderer;
 import javax.swing.tree.DefaultTreeModel;
@@ -52,17 +45,18 @@ import javax.swing.tree.TreeCellRenderer;
 import javax.swing.tree.TreePath;
 
 import org.jdesktop.swingx.action.AbstractActionExt;
-import org.jdesktop.swingx.action.LinkAction;
 import org.jdesktop.swingx.decorator.Highlighter;
 import org.jdesktop.swingx.decorator.HighlighterFactory;
-import org.jdesktop.swingx.renderer.CheckBoxProvider;
+import org.jdesktop.swingx.hyperlink.LinkAction;
 import org.jdesktop.swingx.renderer.CellContext;
+import org.jdesktop.swingx.renderer.CheckBoxProvider;
 import org.jdesktop.swingx.renderer.ComponentProvider;
 import org.jdesktop.swingx.renderer.DefaultTableRenderer;
 import org.jdesktop.swingx.renderer.DefaultTreeRenderer;
 import org.jdesktop.swingx.renderer.HyperlinkProvider;
 import org.jdesktop.swingx.renderer.LabelProvider;
 import org.jdesktop.swingx.renderer.StringValue;
+import org.jdesktop.swingx.renderer.StringValues;
 import org.jdesktop.swingx.renderer.WrappingIconPanel;
 import org.jdesktop.swingx.renderer.WrappingProvider;
 import org.jdesktop.swingx.renderer.RendererVisualCheck.TextAreaProvider;
@@ -76,6 +70,7 @@ import org.jdesktop.swingx.treetable.FileSystemModel;
 import org.jdesktop.swingx.treetable.MutableTreeTableNode;
 import org.jdesktop.swingx.treetable.TreeTableModel;
 import org.jdesktop.swingx.treetable.TreeTableNode;
+import org.jdesktop.test.AncientSwingTeam;
 import org.jdesktop.test.TableModelReport;
 
 /**
@@ -98,11 +93,11 @@ public class JXTreeTableIssues extends InteractiveTestCase {
         JXTreeTableIssues test = new JXTreeTableIssues();
         try {
 //            test.runInteractiveTests();
-//            test.runInteractiveTests(".*AdapterDeleteUpdate.*");
+//            test.runInteractiveTests(".*ColumnSelection.*");
 //            test.runInteractiveTests(".*Text.*");
 //            test.runInteractiveTests(".*TreeExpand.*");
-//            test.runInteractiveTests("interactive.*ClipIssueD.*");
-          test.runInteractiveTests("interactive.*CustomColor.*");
+            test.runInteractiveTests("interactive.*Cancel.*");
+//          test.runInteractiveTests("interactive.*CustomColor.*");
               
         } catch (Exception e) {
             System.err.println("exception when executing interactive tests:");
@@ -110,6 +105,18 @@ public class JXTreeTableIssues extends InteractiveTestCase {
         }
     }
 
+    /**
+     * Issue #875-swingx: cell selection incorrect in hierarchical column.
+     * 
+     */
+    public void interactiveColumnSelection() {
+        JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
+        treeTable.setColumnSelectionAllowed(true);
+        JXTable table = new JXTable(new AncientSwingTeam());
+        table.setColumnSelectionAllowed(true);
+        JXFrame frame = wrapWithScrollingInFrame(treeTable, table, "columnSelection in treetable");
+        show(frame);
+    }
     /**
      * Custom renderer colors of Swingx DefaultTreeRenderer not respected.
      * (same in J/X/Tree). 
@@ -190,76 +197,6 @@ public class JXTreeTableIssues extends InteractiveTestCase {
     }
 
 
-    /**
-     * Issue #766-swingx: drop image is blinking over hierarchical column.
-     * 
-     * Not sure how to enable in 1.5 (TransferSupport is 1.6 api). But looks 
-     * terrible in 1.6. Probably related to our mouse tricksery? Any ideas anybody?
-     * 
-     */
-    public void interactiveDropOnHierachicalColumnBlinks() {
-        JXTreeTable xTable = new JXTreeTable(new ComponentTreeTableModel(new JXFrame()));
-        
-        TransferHandler tableTransfer = new TransferHandler() {
-
-//            @Override
-//            public boolean canImport (TransferSupport support) {
-//                    return true;
-//            }
-//
-//            @Override
-//            public boolean importData (TransferSupport support) {
-//                    return super.importData(support);
-//            }
-
-    };
-
-       xTable.setTransferHandler(tableTransfer);
-        xTable.expandAll();
-        xTable.setVisibleColumnCount(10);
-        JXFrame frame = wrapWithScrollingInFrame(xTable, "TreeTable: null icons?");
-        JTextField textField = new JTextField("drag");
-        textField.setDragEnabled(true);
-        addStatusComponent(frame, textField);
-        frame.setVisible(true);
-    }
-
-    
-    /**
-     * Issue #730-swingx: editor's stop not always called.
-     * 
-     *  - start edit a cell in the hierarchical column, 
-     *  - click into another cell of the hierarchical column
-     *  - edit sometimes canceled instead of stopped 
-     *  
-     *  seems to happen if click into text of cell, okay if outside
-     *  
-     */
-    public void interactiveEditingCanceledStopped() {
-        final JTextField field = new JTextField();
-        JXTreeTable xTable = new JXTreeTable(new ComponentTreeTableModel(new JXFrame()));
-        xTable.expandAll();
-        xTable.setVisibleColumnCount(10);
-        xTable.packColumn(0, -1);
-        CellEditor editor = xTable.getCellEditor(0, 0);
-        CellEditorListener l =  new CellEditorListener() {
-
-            public void editingCanceled(ChangeEvent e) {
-                field.setText("canceled");
-                LOG.info("canceled");
-            }
-
-            public void editingStopped(ChangeEvent e) {
-                field.setText("stopped");
-                LOG.info("stopped");
-                
-            }};
-        editor.addCellEditorListener(l);
-        JXFrame frame = wrapWithScrollingInFrame(xTable, "#730-swingx: click sometimes cancels");
-        frame.add(field, BorderLayout.SOUTH);
-        frame.setVisible(true);
-    }
-
     
     /**
      * Issue #493-swingx: incorrect table events fired.
@@ -790,7 +727,7 @@ public class JXTreeTableIssues extends InteractiveTestCase {
         StringValue sv = new StringValue( ){
 
             public String getString(Object value) {
-                return "..." + TO_STRING.getString(value);
+                return "..." + StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -877,76 +814,100 @@ public class JXTreeTableIssues extends InteractiveTestCase {
 
 
     /**
-     * example how to use a custom component as
-     * renderer in tree column of TreeTable.
-     *
+     * Experiments to try and understand clipping issues: occasionally, the text
+     * in the tree column is clipped even if there is enough space available.
+     * 
+     * To visualize the rendering component's size we use a WrappingIconProvider
+     * which sets a red border.
+     * 
+     * Calling packxx might pose a problem: for non-large models the node size
+     * is cached. In this case, packing before replacing the renderer will lead
+     * to incorrect sizes which are hard to invalidate (no way except faking a
+     * structural tree event? temporaryly set large model and back, plus repaint
+     * works).
+     * 
      */
     public void interactiveTreeTableClipIssueWrappingProvider() {
         final JXTreeTable treeTable = new JXTreeTable(createActionTreeModel());
         treeTable.setHorizontalScrollEnabled(true);
+        treeTable.setColumnControlVisible(true);
+        // BEWARE: do not pack before setting the renderer
         treeTable.packColumn(0, -1);
-        treeTable.setLargeModel(true);
-               
+
         StringValue format = new StringValue() {
 
             public String getString(Object value) {
                 if (value instanceof Action) {
                     return ((Action) value).getValue(Action.NAME) + "xx";
                 }
-                return StringValue.TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
-            
+
         };
         ComponentProvider tableProvider = new LabelProvider(format);
-        TableCellRenderer tableRenderer = new DefaultTableRenderer(tableProvider);
         WrappingProvider wrappingProvider = new WrappingProvider(tableProvider) {
             Border redBorder = BorderFactory.createLineBorder(Color.RED);
+
             @Override
             public WrappingIconPanel getRendererComponent(CellContext context) {
-//                Dimension old = rendererComponent.getPreferredSize();
-//                rendererComponent.setPreferredSize(null);
                 super.getRendererComponent(context);
-//                Dimension dim = rendererComponent.getPreferredSize();
-//                dim.width = Math.max(dim.width, treeTable.getColumn(0).getWidth());
-//                rendererComponent.setPreferredSize(dim);
                 rendererComponent.setBorder(redBorder);
                 return rendererComponent;
             }
-            
+
         };
-        DefaultTreeRenderer treeCellRenderer = new DefaultTreeRenderer(wrappingProvider);
+        DefaultTreeRenderer treeCellRenderer = new DefaultTreeRenderer(
+                wrappingProvider);
         treeTable.setTreeCellRenderer(treeCellRenderer);
         treeTable.setHighlighters(HighlighterFactory.createSimpleStriping());
+        // at this point a pack is okay, caching will get the correct values
+        // treeTable.packColumn(0, -1);
+
         final JXTree tree = new JXTree(treeTable.getTreeTableModel());
         tree.setCellRenderer(treeCellRenderer);
-       tree.setScrollsOnExpand(false);
-        JXFrame frame = wrapWithScrollingInFrame(treeTable, tree, "treetable and default wrapping provider");
+        tree.setScrollsOnExpand(false);
+        JXFrame frame = wrapWithScrollingInFrame(treeTable, tree,
+                "treetable and tree with wrapping provider");
+        // revalidate doesn't help
         Action revalidate = new AbstractActionExt("revalidate") {
 
             public void actionPerformed(ActionEvent e) {
                 treeTable.revalidate();
                 tree.revalidate();
-                
-            } };
+                treeTable.repaint();
+            }
+        };
+
+        // hack around incorrect cached node sizes
+        Action large = new AbstractActionExt("large-circle") {
+
+            public void actionPerformed(ActionEvent e) {
+                treeTable.setLargeModel(true);
+                treeTable.setLargeModel(false);
+                treeTable.repaint();
+            }
+        };
         addAction(frame, revalidate);
-        frame.setVisible(true);
+        addAction(frame, large);
+        show(frame);
     }
 
     /**
-     * quick check for text clipping probs.
+     * Experiments to try and understand clipping issues: occasionally, the text
+     * in the tree column is clipped even if there is enough space available.
+     * 
+     * Here we don't change any renderers.
      */
     public void interactiveTreeTableClipIssueDefaultRenderer() {
         final JXTreeTable treeTable = new JXTreeTable(createActionTreeModel());
-//        treeTable.setHorizontalScrollEnabled(true);
+        treeTable.setHorizontalScrollEnabled(true);
         treeTable.setRootVisible(true);
         treeTable.collapseAll();
         treeTable.packColumn(0, -1);
         
         final JTree tree = new JTree(treeTable.getTreeTableModel());
         tree.collapseRow(0);
-        tree.setLargeModel(true);
-//        tree.collapseAll();
-        JXFrame frame = wrapWithScrollingInFrame(//treeTable, 
+        JXFrame frame = wrapWithScrollingInFrame(treeTable, 
                 tree, "JXTreeTable vs. JTree: default renderer");
         Action revalidate = new AbstractActionExt("revalidate") {
 
@@ -960,52 +921,56 @@ public class JXTreeTableIssues extends InteractiveTestCase {
     }
 
     /**
-     * quick check for text clipping probs. Reset treeTable.treeCellRenderer 
+     * Experiments to try and understand clipping issues: occasionally, the text
+     * in the tree column is clipped even if there is enough space available.
+     * Here we set a custom (unchanged default) treeCellRenderer which 
      * removes ellipses altogether.
      * 
      */
     public void interactiveTreeTableClipIssueCustomDefaultRenderer() {
-        TreeCellRenderer renderer =  new DefaultTreeCellRenderer() {
+        TreeCellRenderer renderer = new DefaultTreeCellRenderer() {
 
             @Override
             public Component getTreeCellRendererComponent(JTree tree,
                     Object value, boolean sel, boolean expanded, boolean leaf,
                     int row, boolean hasFocus) {
-                return super.getTreeCellRendererComponent(tree, value, sel, expanded, leaf,
-                        row, hasFocus);
+                return super.getTreeCellRendererComponent(tree, value, sel,
+                        expanded, leaf, row, hasFocus);
             }
-            
+
         };
         final JXTreeTable treeTable = new JXTreeTable(createActionTreeModel());
         treeTable.setTreeCellRenderer(renderer);
-//        treeTable.setHorizontalScrollEnabled(true);
+        treeTable.setHorizontalScrollEnabled(true);
         treeTable.setRootVisible(true);
         treeTable.collapseAll();
         treeTable.packColumn(0, -1);
-        
+
         final JTree tree = new JTree(treeTable.getTreeTableModel());
         tree.setCellRenderer(renderer);
         tree.collapseRow(0);
-        JXFrame frame = wrapWithScrollingInFrame(treeTable, tree, "JXTreeTable vs. JTree: custom default renderer");
+        JXFrame frame = wrapWithScrollingInFrame(treeTable, tree,
+                "JXTreeTable vs. JTree: custom default renderer");
         Action revalidate = new AbstractActionExt("revalidate") {
 
             public void actionPerformed(ActionEvent e) {
                 treeTable.revalidate();
                 tree.revalidate();
-                
-            } };
+
+            }
+        };
         addAction(frame, revalidate);
         frame.setVisible(true);
     }
 
     /**
-     * Dirty example how to configure a custom renderer
-     * to use treeTableModel.getValueAt(...) for showing.
-     *
+     * Dirty example how to configure a custom renderer to use
+     * treeTableModel.getValueAt(...) for showing.
+     * 
      */
     public void interactiveTreeTableGetValueRenderer() {
         JXTreeTable tree = new JXTreeTable(new ComponentTreeTableModel(new JXFrame()));
-        ComponentProvider provider = new CheckBoxProvider(StringValue.TO_STRING) {
+        ComponentProvider provider = new CheckBoxProvider(StringValues.TO_STRING) {
             
             @Override
             protected String getValueAsString(CellContext context) {
@@ -1101,6 +1066,7 @@ public class JXTreeTableIssues extends InteractiveTestCase {
         treeTable.setRowSelectionInterval(0, 0);
         assertEquals(treeTable.getSelectionModel().getLeadSelectionIndex(), 
                 treeTable.getTreeSelectionModel().getLeadSelectionRow());
+        fail("lead selection synch passes locally, fails on server");
     }
     
     /**
@@ -1117,7 +1083,7 @@ public class JXTreeTableIssues extends InteractiveTestCase {
         assertEquals(treeTable.getSelectionModel().getLeadSelectionIndex(), 
                 treeTable.getTreeSelectionModel().getLeadSelectionRow());
         assertEquals(0, treeTable.getTreeSelectionModel().getLeadSelectionRow());
-
+        fail("lead selection synch passes locally, fails on server");
     }
 
 
