@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeTableUnitTest.java,v 1.58 2008/05/15 12:15:25 kleopatra Exp $
+ * $Id: JXTreeTableUnitTest.java,v 1.64 2008/12/23 18:12:37 kschaefe Exp $
  * 
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
  * California 95054, U.S.A. All rights reserved.
@@ -45,6 +45,7 @@ import javax.swing.tree.TreePath;
 import org.jdesktop.swingx.decorator.ComponentAdapterTest.JXTreeTableT;
 import org.jdesktop.swingx.renderer.DefaultTreeRenderer;
 import org.jdesktop.swingx.renderer.StringValue;
+import org.jdesktop.swingx.renderer.StringValues;
 import org.jdesktop.swingx.table.TableColumnExt;
 import org.jdesktop.swingx.test.ComponentTreeTableModel;
 import org.jdesktop.swingx.test.TreeTableUtils;
@@ -58,8 +59,18 @@ import org.jdesktop.test.AncientSwingTeam;
 import org.jdesktop.test.PropertyChangeReport;
 import org.jdesktop.test.TableModelReport;
 import org.jdesktop.test.TreeSelectionReport;
+import org.junit.Before;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+import org.junit.Test;
+import org.junit.Before;
+import org.junit.After;
 
+
+@RunWith(JUnit4.class)
 public class JXTreeTableUnitTest extends InteractiveTestCase {
+    @SuppressWarnings ("unused")
     private static final Logger LOG = Logger
             .getLogger(JXTreeTableUnitTest.class.getName());
     
@@ -70,10 +81,53 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
         super("JXTreeTable Unit Test");
     }
 
+    
+    /**
+     * Issue #766-swingx: drop image is blinking over hierarchical column.
+     * 
+     * Test the hack - enabled by default, can be disabled by setting the
+     * client property to Boolean.FALSE.
+     * 
+     */
+    @Test
+    public void testDropHack() {
+        JXTree tree = new JXTree();
+        assertEquals("sanity - default visible", true, tree.isVisible());
+        JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
+        JXTree renderer = (JXTree) treeTable.getCellRenderer(0, 0);
+        assertEquals("renderer must be invisible by default", false, renderer.isVisible());
+        treeTable.putClientProperty(JXTreeTable.DROP_HACK_FLAG_KEY, Boolean.FALSE);
+        assertEquals("renderer must be visible if hack disabled", true, renderer.isVisible());
+    }
+
+    /**
+     * Issue #862-swingx: JXTree - add api for selection colors.
+     * Here: test that the tree in JXTreeTable is kept in synch.
+     */
+    @Test
+    public void testSelectionBackground() {
+        JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
+        treeTable.setSelectionBackground(Color.RED);
+        assertEquals(treeTable.getSelectionBackground(), 
+                ((JXTree) treeTable.getCellRenderer(0, 0)).getSelectionBackground());
+    }
+    
+    /**
+     * Issue #862-swingx: JXTree - add api for selection colors.
+     * Here: test that the tree in JXTreeTable is kept in synch.
+     */
+    @Test
+    public void testSelectionForeground() {
+        JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
+        treeTable.setSelectionForeground(Color.RED);
+        assertEquals(treeTable.getSelectionForeground(), 
+                ((JXTree) treeTable.getCellRenderer(0, 0)).getSelectionForeground());
+    }
     /**
      * Issue #853-swingx: tree is not disabled.
      * 
      */
+    @Test
     public void testDisabledTreeColumn() {
         JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
         treeTable.setEnabled(false);
@@ -84,6 +138,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #853-swingx: tree is not disabled.
      * 
      */
+    @Test
     public void testDisabledTreeColumnPrepared() {
         JXTreeTable treeTable = new JXTreeTable(new FileSystemModel());
         treeTable.setEnabled(false);
@@ -94,6 +149,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #821-swingx: JXTreeTable broken string rep of hierarchical column
      * Here we test the getStringAt for the hierarchical column.
      */
+    @Test
     public void testGetStringAtHierarchicalColumn() {
         JXTreeTable table = new JXTreeTableT(AncientSwingTeam.createNamedColorTreeTableModel());
         StringValue sv = new StringValue() {
@@ -103,7 +159,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
                     Color color = (Color) value;
                     return "R/G/B: " + color.getRGB();
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -119,6 +175,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: icon on renderer must be respected if overwrite is false.
      */
+    @Test
     public void testIconSetOnRendererFalseOverwrite() {
         JXTreeTable treeTable = new JXTreeTable();
         DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
@@ -133,6 +190,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: icon on renderer must be overwritten if overwrite is true.
      */
+    @Test
     public void testIconSetOnRendererTrueOverwrite() {
         JXTreeTable treeTable = new JXTreeTable();
         treeTable.setLeafIcon(null);
@@ -152,6 +210,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: set icon on treeTable is passed on to renderer always.
      */
+    @Test
     public void testIconSetOnTreeTableFalseOverwrite() {
         JXTreeTable treeTable = new JXTreeTable();
         DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
@@ -167,6 +226,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: set icon on treeTable is passed on to renderer always.
      */
+    @Test
     public void testIconSetOnTreeTableTrueOverwrite() {
         JXTreeTable treeTable = new JXTreeTable();
         treeTable.setOverwriteRendererIcons(true);
@@ -183,6 +243,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: default overwriteOnRenderer is false.
      */
+    @Test
     public void testIconOverwriteInitial() {
         JXTreeTable treeTable = new JXTreeTable();
         assertFalse("initial overwriteRendererIcons must be false", 
@@ -195,6 +256,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: test that different treetables have different instances of mapper.
      */
+    @Test
     public void testSelectionMapperViewSelectionModel() {
         JXTreeTable one = new JXTreeTable();
         assertSame("mapper's viewselectionModel must be same as the treetable's", 
@@ -211,6 +273,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: test that different treetables have different instances of mapper.
      */
+    @Test
     public void testSelectionMapper() {
         JXTreeTable one = new JXTreeTable();
         JXTreeTable two = new JXTreeTable();
@@ -222,6 +285,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: test method without event (delegates to event == null)
      */
+    @Test
     public void testEditCellAt() {
         JXTreeTable treeTable = prepareTreeTable(true);
         treeTable.expandAll();
@@ -235,6 +299,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: test method taking the event
      */
+    @Test
     public void testEditCellAtByKeyEvent() {
         JXTreeTable treeTable = prepareTreeTable(true);
         treeTable.expandAll();
@@ -250,6 +315,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * Here: compare with plain table (in fact plain DefaultCellEditor)
      */
+    @Test
     public void testTableEditCellAtByKeyEvent() {
         JXTable table = new JXTable(10, 20);
         // sanity
@@ -271,6 +337,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InvocationTargetException 
      * @throws InterruptedException 
      */
+    @Test
     public void testTableEventOnSetNullRoot() throws InterruptedException, InvocationTargetException {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         final JXTreeTable table = new JXTreeTable(model);
@@ -301,6 +368,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InvocationTargetException 
      * @throws InterruptedException 
      */
+    @Test
     public void testTableEventOnSetRoot() throws InterruptedException, InvocationTargetException {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         final JXTreeTable table = new JXTreeTable(model);
@@ -331,6 +399,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InvocationTargetException 
      * @throws InterruptedException 
      */
+    @Test
     public void testTableEventOnReloadNonRoot() throws InterruptedException, InvocationTargetException {
         DefaultTreeTableModel model = new DefaultTreeTableModel(
                 (TreeTableNode) createCustomTreeTableModelFromDefault().getRoot()) {
@@ -375,6 +444,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InvocationTargetException 
      * @throws InterruptedException 
      */
+    @Test
     public void testTableEventOnSetModel() throws InterruptedException, InvocationTargetException {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         final JXTreeTable table = new JXTreeTable(model);
@@ -398,6 +468,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #531-swingx: IllegalArgumentException on setModel.
      *
      */
+    @Test
     public void testSetModel() {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         JXTreeTable treeTable = new JXTreeTable(model);
@@ -409,6 +480,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #531-swingx: IllegalArgumentException on setModel.
      *
      */
+    @Test
     public void testSetModelOnTree() {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         JXTree treeTable = new JXTree(model);
@@ -419,6 +491,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #531-swingx: IllegalArgumentException on setModel.
      *
      */
+    @Test
     public void testSetModelEmptyContructor() {
         JXTreeTable treeTable = new JXTreeTable();
         treeTable.setRootVisible(true);
@@ -435,6 +508,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InvocationTargetException 
      * @throws InterruptedException 
      */
+    @Test
     public void testTableEventUpdateOnTreeTableModelSetValue() throws InterruptedException, InvocationTargetException {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         final JXTreeTable table = new JXTreeTable(model);
@@ -467,6 +541,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InvocationTargetException 
      * @throws InterruptedException 
      */
+    @Test
     public void testTableEventDeleteOnTreeTableModel() throws InterruptedException, InvocationTargetException {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         MutableTreeTableNode root = (MutableTreeTableNode) model.getRoot();
@@ -509,6 +584,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InvocationTargetException 
      * @throws InterruptedException 
      */
+    @Test
     public void testTableEventUpdateOnTreeTableSetValue() throws InterruptedException, InvocationTargetException {
         TreeTableModel model = createCustomTreeTableModelFromDefault();
         final JXTreeTable table = new JXTreeTable(model);
@@ -537,6 +613,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
     /**
      * Issue #465-swingx: NPE if editing node with null icon.
      */
+    @Test
     public void testNPEEditingNullIcon() {
         JXTreeTable treeTable = new JXTreeTable(new ComponentTreeTableModel(new JXErrorPane()));
         treeTable.setEditable(true);
@@ -552,6 +629,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #??-swingx: ComponentAdapter not fully implemented - leaf always true.
      *
      */
+    @Test
     public void testComponentAdapterIsLeaf() {
         // build the test treeTableModel
         JPanel root = new JPanel();
@@ -587,6 +665,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #??-swingx: ComponentAdapter not fully implemented - expanded always true.
      *
      */
+    @Test
     public void testComponentAdapterIsExpanded() {
         // build the test treeTableModel
         JPanel root = new JPanel();
@@ -622,6 +701,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 0/1 if hiding/showing grid lines. 
      *
      */
+    @Test
     public void testShowGrid() {
         JXTreeTable table = new JXTreeTable(simpleTreeTableModel);
         // sanity: initial margins are (0, 0), grid off
@@ -645,6 +725,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Don't know how to test mouse-triggered collapse/expand, "looked"
      * at it in the visualCheck. 
      */
+    @Test
     public void testEditOnCollapse() {
         DefaultMutableTreeTableNode root = new DefaultMutableTreeTableNode("ROOT");
         DefaultMutableTreeTableNode a = new DefaultMutableTreeTableNode("A");
@@ -698,6 +779,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #399-swingx: editing terminated by selecting editing row.<p>
      * Assert workaround: setExpandsSelectedPaths(false)
      */
+    @Test
     public void testSelectionKeepsEditingWithExpandsFalse() {
         JXTreeTable treeTable = new JXTreeTable(new FileSystemModel()) {
 
@@ -724,6 +806,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * starting from unselected, the event count is 1 as expected 
      */
+    @Test
     public void testSelectionEvents() {
         JXTreeTable treeTable = prepareTreeTable(false);
         TreeSelectionReport report = new TreeSelectionReport();
@@ -740,6 +823,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * catching isAdjusting listSelectionEvents. The reason is 
      * an intermediate clearSelection which fires the additional.
      */
+    @Test
     public void testSelectionChangedEvents() {
         JXTreeTable treeTable = prepareTreeTable(true);
         TreeSelectionReport report = new TreeSelectionReport();
@@ -753,6 +837,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      * The old in the event must be the last selected. 
      */
+    @Test
     public void testSelectionChangedHasFirstOldPath() {
         JXTreeTable treeTable = prepareTreeTable(true);
         TreeSelectionReport report = new TreeSelectionReport();
@@ -789,6 +874,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * set directly via the treeSelectionModel. Characterize normal
      * treeSelection to mimic.
      */
+    @Test
     public void testSelectionChangedOnTreeSelection() {
         JXTreeTable treeTable = prepareTreeTable(true);
         TreePath oldSelected = treeTable.getPathForRow(0);
@@ -808,6 +894,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * TreeTableModelAdapter.
      *
      */
+    @Test
     public void testConservativeRowForNodeInAdapter() {
         // for testing we need a model which relies on 
         // node != null
@@ -855,6 +942,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * test if table and tree rowHeights are the same.
      *
      */
+    @Test
     public void testAdjustedRowHeights() {
         JXTreeTable treeTable = new JXTreeTable(simpleTreeTableModel);
         JXTree tree = (JXTree) treeTable.getCellRenderer(0, 0);
@@ -875,6 +963,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * #321-swingx: missing tree property toggleClickCount, largeModel.
      *
      */
+    @Test
     public void testToggleClickCount() {
         JXTreeTable treeTable = new JXTreeTable(simpleTreeTableModel);
         int clickCount = treeTable.getToggleClickCount();
@@ -895,6 +984,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * testing auto-detection of dragHackEnabled.
      * 
      */
+    @Test
     public void testDragHackFlagOn() {
         JXTreeTable treeTable = new JXTreeTable(simpleTreeTableModel);
         assertNull(treeTable.getClientProperty(JXTreeTable.DRAG_HACK_FLAG_KEY));
@@ -910,6 +1000,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * testing auto-detection of dragHackEnabled.
      * 
      */
+    @Test
     public void testDragHackFlagOff() {
         System.setProperty("sun.swing.enableImprovedDragGesture", "true");
         JXTreeTable treeTable = new JXTreeTable(simpleTreeTableModel);
@@ -930,6 +1021,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * is a missing visual update of the table.
      *
      */
+    @Test
     public void testEmptyModelInitiallyInvisibleRoot() {
         final DefaultMutableTreeTableNode root = new DefaultMutableTreeTableNode();
         final InsertTreeTableModel model = new InsertTreeTableModel(root);
@@ -961,6 +1053,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * @throws InterruptedException 
      * 
      */
+    @Test
     public void testInsertUnderCollapsedNode() throws InterruptedException, InvocationTargetException {
         final DefaultMutableTreeTableNode root = new DefaultMutableTreeTableNode();
         final InsertTreeTableModel model = new InsertTreeTableModel(root);
@@ -1031,6 +1124,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * 
      *
      */
+    @Test
     public void testTreeTableModelIsBoundProperty() {
         JXTreeTable treeTable = new JXTreeTable();
         PropertyChangeReport report = new PropertyChangeReport();
@@ -1052,6 +1146,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * sanity test (make sure nothing evil introduced in treeTable as 
      * compared to table)
      */
+    @Test
     public void testRemoveAllColumsAfterModelChanged() {
         JXTreeTable table = new JXTreeTable(new FileSystemModel());
         TableColumnExt columnX = table.getColumnExt(1);
@@ -1068,6 +1163,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #241: treeModelListeners not removed.
      *
      */
+    @Test
     public void testRemoveListeners() {
         JXTreeTable treeTable = new JXTreeTable(treeTableModel);
         treeTable.setTreeTableModel(new FileSystemModel());
@@ -1077,6 +1173,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
     /**
      * Clarify contract of isHierarchical.
      */
+    @Test
     public void testIsHierarchical() {
         TreeTableModel model = new DefaultTreeTableModel();
         //sanity
@@ -1093,6 +1190,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
         }
     }
     
+    @Test
     public void testRowForPath() {
         JXTreeTable treeTable = new JXTreeTable(simpleTreeTableModel);
         // @todo - make sure we find an expandible row instead of hardcoding
@@ -1109,12 +1207,14 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
         
     }
     
+    @Test
     public void testPathForRowContract() {
         JXTreeTable treeTable = new JXTreeTable(treeTableModel);
         assertNull("row < 0 must return null path", treeTable.getPathForRow(-1));
         assertNull("row >= getRowCount must return null path", treeTable.getPathForRow(treeTable.getRowCount()));
     }
     
+    @Test
     public void testTableRowAtNegativePoint() {
         JXTable treeTable = new JXTable(1, 4);
         int negativeYRowHeight = - treeTable.getRowHeight();
@@ -1130,6 +1230,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
     }
 
 
+    @Test
     public void testPathForLocationContract() {
         JXTreeTable treeTable = new JXTreeTable(treeTableModel);
         // this is actually a JTable rowAtPoint bug: falsely calculates
@@ -1150,6 +1251,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #151: renderer properties ignored after setting treeTableModel.
      * 
      */
+    @Test
     public void testRendererProperties() {
         JXTreeTable treeTable = new JXTreeTable(treeTableModel);
         // storing negates of properties
@@ -1187,6 +1289,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * Issue #148: line style client property not respected by renderer.
      * 
      */
+    @Test
     public void testLineStyle() {
         JXTreeTable treeTable = new JXTreeTable(treeTableModel);
         String propertyName = "JTree.lineStyle";
@@ -1200,6 +1303,7 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
      * sanity test: arbitrary client properties not passed to renderer.
      * 
      */
+    @Test
     public void testArbitraryClientProperty() {
         JXTreeTable treeTable = new JXTreeTable(treeTableModel);
         String propertyName = "someproperty";
@@ -1256,7 +1360,8 @@ public class JXTreeTableUnitTest extends InteractiveTestCase {
 
     // ------------------ init
     @Override
-    protected void setUp() throws Exception {
+    @Before
+    public void setUp() throws Exception {
         super.setUp();
         simpleTreeTableModel = getDefaultTreeTableModel();
         this.treeTableModel = new FileSystemModel();
