@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeTableVisualCheck.java,v 1.70 2008/05/08 14:48:31 kleopatra Exp $
+ * $Id: JXTreeTableVisualCheck.java,v 1.73 2008/10/14 12:52:02 kleopatra Exp $
  * 
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
  * California 95054, U.S.A. All rights reserved.
@@ -21,6 +21,7 @@
 package org.jdesktop.swingx;
 
 
+import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.Dimension;
@@ -33,6 +34,7 @@ import java.util.regex.Pattern;
 
 import javax.swing.AbstractAction;
 import javax.swing.Action;
+import javax.swing.CellEditor;
 import javax.swing.Icon;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
@@ -41,9 +43,12 @@ import javax.swing.JScrollPane;
 import javax.swing.JTable;
 import javax.swing.JTextField;
 import javax.swing.JTree;
+import javax.swing.KeyStroke;
 import javax.swing.SwingUtilities;
 import javax.swing.ToolTipManager;
 import javax.swing.UIManager;
+import javax.swing.event.CellEditorListener;
+import javax.swing.event.ChangeEvent;
 import javax.swing.event.TreeExpansionEvent;
 import javax.swing.event.TreeExpansionListener;
 import javax.swing.table.DefaultTableCellRenderer;
@@ -68,9 +73,11 @@ import org.jdesktop.swingx.decorator.ShuttleSorter;
 import org.jdesktop.swingx.decorator.HighlightPredicate.AndHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.ColumnHighlightPredicate;
 import org.jdesktop.swingx.decorator.HighlightPredicate.DepthHighlightPredicate;
+import org.jdesktop.swingx.renderer.DefaultTreeRenderer;
 import org.jdesktop.swingx.test.ComponentTreeTableModel;
 import org.jdesktop.swingx.test.XTestUtils;
 import org.jdesktop.swingx.treetable.DefaultMutableTreeTableNode;
+import org.jdesktop.swingx.treetable.DefaultTreeTableModel;
 import org.jdesktop.swingx.treetable.FileSystemModel;
 import org.jdesktop.swingx.treetable.TreeTableModel;
 import org.jdesktop.test.AncientSwingTeam;
@@ -97,12 +104,121 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
 //             test.runInteractiveTests("interactive.*RowHeightCompare.*");
 //             test.runInteractiveTests("interactive.*RToL.*");
 //             test.runInteractiveTests("interactive.*Insert.*");
-             test.runInteractiveTests("interactive.*LAF.*");
+             test.runInteractiveTests("interactive.*Selection.*");
         } catch (Exception ex) {
 
         }
     }
 
+
+    
+    /**
+     * Issue #730-swingx: editor's stop not always called.
+     * 
+     *  - start edit a cell in the hierarchical column, 
+     *  - click into another cell of the hierarchical column
+     *  - edit sometimes canceled instead of stopped 
+     *  
+     *  seems to happen if click into text of cell, okay if outside.
+     *  Trying to fix in TreeTableHacker: first try to stop editing
+     *  cancel if unsuccessful. 
+     *  
+     *  PENDING JW: why didn't we do that in the first place? Any
+     *  possibility that the edit will end up in the wrong node
+     *  in expand/collapse?
+     *  
+     *  Okay, checked again: the cancel is needed because otherwise
+     *  the edited value might end up in the wrong row, that is the
+     *  one after the currently edited if the parent of the edited
+     *  is collapsed while editing (old issue #120-jdnc).
+     *  
+     *  To fight the regression, the hacker's completeEditing now is
+     *  called before updating renderer's (tree) expansion state. Seems
+     *  to fix both issues now. 
+     */
+    public void interactiveEditingCanceledStopped() {
+        final JTextField field = new JTextField();
+        DefaultMutableTreeTableNode root = new DefaultMutableTreeTableNode("ROOT");
+        DefaultMutableTreeTableNode a = new DefaultMutableTreeTableNode("A");
+        DefaultMutableTreeTableNode a1 = new DefaultMutableTreeTableNode("A1");
+        DefaultMutableTreeTableNode b = new DefaultMutableTreeTableNode("B");
+        a.add(a1);
+        root.add(a);
+        root.add(b);
+        // default table: hack around #120-jdnc introduces #730
+        final JXTreeTable xTable = new JXTreeTable();
+        xTable.setTreeTableModel(new DefaultTreeTableModel(root));
+        xTable.expandAll();
+        xTable.setVisibleColumnCount(10);
+        xTable.packColumn(0, -1);
+        CellEditor editor = xTable.getCellEditor(0, 0);
+        CellEditorListener l =  new CellEditorListener() {
+
+            public void editingCanceled(ChangeEvent e) {
+                field.setText("canceled");
+                LOG.info("canceled");
+            }
+
+            public void editingStopped(ChangeEvent e) {
+                field.setText("stopped");
+                LOG.info("stopped");
+                
+            }};
+        editor.addCellEditorListener(l);
+        JXFrame frame = wrapWithScrollingInFrame(xTable, "#730-swingx: click sometimes cancels");
+        Action toggleExpansion = new AbstractAction("toggle") {
+
+            public void actionPerformed(ActionEvent arg0) {
+                boolean isExpanded = xTable.isExpanded(0);
+                if (isExpanded) {
+                     xTable.collapseRow(0);
+                } else {
+                    xTable.expandRow(0);
+                }
+                
+            }
+            
+        };
+        KeyStroke stroke = KeyStroke.getKeyStroke("F1");
+        xTable.getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT).put(stroke, "toggleExpansion");
+        xTable.getActionMap().put("toggleExpansion", toggleExpansion);
+        frame.add(field, BorderLayout.SOUTH);
+        addStatusMessage(frame, "F1 to toggle expansion of first row");
+        show(frame);
+    }
+
+
+    
+    /**
+     * Issue #862-swingx: JXTree - add api for selection colors.
+     * Here: check colors when used in JXTreeTable
+     */
+    public void interactiveSelectionColors() {
+        final JXTreeTable tree = new JXTreeTable(new FileSystemModel());
+        // use SwingX renderer which is aware of per-tree selection colors
+        tree.setTreeCellRenderer(new DefaultTreeRenderer());
+        final Color uiBackground = tree.getSelectionBackground();
+        final Color uiForeground = tree.getSelectionForeground();
+        Action toggleSelectionColors = new AbstractAction("toggle selection colors") {
+            
+            public void actionPerformed(ActionEvent e) {
+                if (tree.getSelectionBackground() == uiBackground) {
+                    tree.setSelectionBackground(Color.BLUE);
+                    tree.setSelectionForeground(Color.RED);
+                } else {
+                    tree.setSelectionBackground(uiBackground);
+                    tree.setSelectionForeground(uiForeground);
+                }
+                
+            }
+            
+        };
+        JXFrame frame = wrapWithScrollingInFrame(tree, "selection colors");
+        addAction(frame, toggleSelectionColors);
+        show(frame);
+    }
+    
+
     
     /**
      * Issue #853-swingx: tree is not disabled.
@@ -974,12 +1090,6 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
         treeTable.addHighlighter(hl);
         treeTable.addHighlighter(new ColorHighlighter(new PatternPredicate(Pattern.compile("^s", Pattern.CASE_INSENSITIVE), 0), null, 
                 Color.red));
-        // alternative: set a pipeline containing the bunch of highlighters
-//        treeTable.setHighlighters(new CompoundHighlighter(new LegacyHighlighter[] {
-//                AlternateRowHighlighter.quickSilver,
-//                new HierarchicalColumnHighlighter(),
-//                new PatternHighlighter(null, Color.red, "^s",
-//                        Pattern.CASE_INSENSITIVE, 0, -1), }));
         JFrame frame = wrapWithScrollingInFrame(treeTable,
                 "QuickSilver-, Column-, PatternHighligher and LineStyle");
         frame.setVisible(true);
@@ -1160,7 +1270,7 @@ public class JXTreeTableVisualCheck extends JXTreeTableUnitTest {
         treeTable.setHighlighters(
                         new ColorHighlighter(Color.orange, null),
                         hl,
-                        new ColorHighlighter(new PatternPredicate(Pattern.compile("D"), 0), null,
+                        new ColorHighlighter(new PatternPredicate("D", 0), null,
                                 Color.red));
 
         HighlightPredicate predicate = new HighlightPredicate() {
