@@ -1,5 +1,5 @@
 /*
- * $Id: JXTreeUnitTest.java,v 1.31 2008/03/19 14:48:33 kleopatra Exp $
+ * $Id: JXTreeUnitTest.java,v 1.35 2008/12/23 18:12:36 kschaefe Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -9,9 +9,9 @@ package org.jdesktop.swingx;
 import java.awt.Color;
 import java.util.Hashtable;
 import java.util.Vector;
-import java.util.regex.Pattern;
 
 import javax.swing.JTree;
+import javax.swing.UIManager;
 import javax.swing.tree.DefaultMutableTreeNode;
 import javax.swing.tree.DefaultTreeCellEditor;
 import javax.swing.tree.DefaultTreeCellRenderer;
@@ -27,11 +27,20 @@ import org.jdesktop.swingx.decorator.Highlighter;
 import org.jdesktop.swingx.decorator.SearchPredicate;
 import org.jdesktop.swingx.renderer.DefaultTreeRenderer;
 import org.jdesktop.swingx.renderer.StringValue;
+import org.jdesktop.swingx.renderer.StringValues;
 import org.jdesktop.swingx.tree.DefaultXTreeCellEditor;
 import org.jdesktop.swingx.treetable.DefaultMutableTreeTableNode;
 import org.jdesktop.swingx.treetable.FileSystemModel;
 import org.jdesktop.swingx.treetable.TreeTableModel;
 import org.jdesktop.test.AncientSwingTeam;
+import org.jdesktop.test.PropertyChangeReport;
+import org.jdesktop.test.TestUtils;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+import org.junit.Test;
+import org.junit.Before;
+import org.junit.After;
+
 
 
 /**
@@ -39,6 +48,7 @@ import org.jdesktop.test.AncientSwingTeam;
  * 
  * @author Jeanette Winzenburg
  */
+@RunWith(JUnit4.class)
 public class JXTreeUnitTest extends InteractiveTestCase {
 
     protected TreeTableModel treeTableModel;
@@ -47,10 +57,68 @@ public class JXTreeUnitTest extends InteractiveTestCase {
         super("JXTree Test");
     }
 
+    /**
+     * Issue #862-swingx: JXTree - add api for selection colors.
+     */
+    @Test
+    public void testSelectionBackground() {
+        JXTree tree = new JXTree();
+        Color uiColor = UIManager.getColor("Tree.selectionBackground");
+        assertEquals(uiColor, tree.getSelectionBackground());
+        Color customColor = Color.RED;
+        tree.setSelectionBackground(customColor);
+        tree.updateUI();
+        assertEquals("custom color must not be reset by ui", customColor, tree.getSelectionBackground());
+    }
+    
+    /**
+     * Issue #862-swingx: JXTree - add api for selection colors.
+     */
+    @Test
+    public void testSelectionForeground() {
+        JXTree tree = new JXTree();
+        Color uiColor = UIManager.getColor("Tree.selectionForeground");
+        assertEquals(uiColor, tree.getSelectionForeground());
+        Color customColor = Color.RED;
+        tree.setSelectionForeground(customColor);
+        tree.updateUI();
+        assertEquals("custom color must not be reset by ui", customColor, tree.getSelectionForeground());
+    }
+    
+    
+    /**
+     * Issue #862-swingx: JXTree - add api for selection colors.
+     */
+    @Test
+    public void testSelectionBackgroundChange() {
+        JXTree tree = new JXTree();
+        Color uiColor = tree.getSelectionBackground();
+        Color customColor = Color.RED;
+        PropertyChangeReport report = new PropertyChangeReport();
+        tree.addPropertyChangeListener(report);
+        tree.setSelectionBackground(customColor);
+        TestUtils.assertPropertyChangeEvent(report, "selectionBackground", uiColor, customColor);
+    }
+    
+    /**
+     * Issue #862-swingx: JXTree - add api for selection colors.
+     */
+    @Test
+    public void testSelectionForegroundChange() {
+        JXTree tree = new JXTree();
+        Color uiColor = tree.getSelectionForeground();
+        Color customColor = Color.RED;
+        PropertyChangeReport report = new PropertyChangeReport();
+        tree.addPropertyChangeListener(report);
+        tree.setSelectionForeground(customColor);
+        TestUtils.assertPropertyChangeEvent(report, "selectionForeground", uiColor, customColor);
+    }
+    
     /**
      * Issue #817-swingx: Delegating renderer must create list's default.
      * Consistent api: expose wrappedRenderer the same way as wrappedModel
      */
+    @Test
     public void testWrappedRendererDefault() {
         JXTree list = new JXTree();
         DelegatingRenderer renderer = (DelegatingRenderer) list.getCellRenderer();
@@ -62,6 +130,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * Issue #817-swingx: Delegating renderer must create list's default.
      * Consistent api: expose wrappedRenderer the same way as wrappedModel
      */
+    @Test
     public void testWrappedRendererCustom() {
         JXTree list = new JXTree();
         DelegatingRenderer renderer = (DelegatingRenderer) list.getCellRenderer();
@@ -75,6 +144,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * Issue #817-swingx: Delegating renderer must create list's default.
      * Delegating uses default on null, here: default default.
      */
+    @Test
     public void testDelegatingRendererUseDefaultSetNull() {
         JXTree list = new JXTree();
         TreeCellRenderer defaultRenderer = list.createDefaultCellRenderer();
@@ -90,6 +160,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Note: this test has to be changed once we switch to default to DefaultTreeRenderer.
      */
+    @Test
     public void testDelegatingRendererUseDefault() {
         JXTree list = new JXTree();
         TreeCellRenderer defaultRenderer = list.createDefaultCellRenderer();
@@ -103,6 +174,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * Issue #817-swingx: Delegating renderer must create list's default.
      * Delegating has default from list initially, here: custom default.
      */
+    @Test
     public void testDelegatingRendererUseCustomDefaultSetNull() {
         JXTree list = new JXTree() {
 
@@ -123,6 +195,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * Issue #817-swingx: Delegating renderer must create list's default.
      * Delegating has default from list initially, here: custom default.
      */
+    @Test
     public void testDelegatingRendererUseCustomDefault() {
         JXTree list = new JXTree() {
 
@@ -150,6 +223,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Here: test api on JXTable.
      */
+    @Test
     public void testGetStringForRow() {
         JXTree tree = new JXTree(AncientSwingTeam.createNamedColorTreeModel());
         tree.expandAll();
@@ -160,7 +234,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
                     Color color = (Color) value;
                     return "R/G/B: " + color.getRGB();
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -175,6 +249,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Here: test api on JXTable.
      */
+    @Test
     public void testGetStringForPath() {
         JXTree tree = new JXTree(AncientSwingTeam.createNamedColorTreeModel());
         tree.expandAll();
@@ -185,7 +260,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
                     Color color = (Color) value;
                     return "R/G/B: " + color.getRGB();
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -200,6 +275,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Here: icon on renderer must be respected if overwrite is false.
      */
+    @Test
     public void testIconSetOnRendererFalseOverwrite() {
         JXTree tree = new JXTree();
         DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
@@ -214,6 +290,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Here: icon on renderer must be overwritten if overwrite is true.
      */
+    @Test
     public void testIconSetOnRendererTrueOverwrite() {
         JXTree tree = new JXTree();
         tree.setLeafIcon(null);
@@ -233,6 +310,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Here: set icon on tree is passed on to renderer always.
      */
+    @Test
     public void testIconSetOnTreeFalseOverwrite() {
         JXTree tree = new JXTree();
         DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
@@ -248,6 +326,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Here: set icon on tree is passed on to renderer always.
      */
+    @Test
     public void testIconSetOnTreeTrueOverwrite() {
         JXTree tree = new JXTree();
         tree.setOverwriteRendererIcons(true);
@@ -264,6 +343,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * 
      * Here: default overwriteOnRenderer is false.
      */
+    @Test
     public void testIconOverwriteInitial() {
         JXTree tree = new JXTree();
         assertFalse("initial overwriteRendererIcons must be false", tree.isOverwriteRendererIcons());
@@ -275,6 +355,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * custom cellEditorListener.
      *
      */
+    @Test
     public void testEditorListenerRemovedOnEditorStopped() {
         JXTree tree = createEditingTree();
         DefaultTreeCellEditor cellEditor = (DefaultTreeCellEditor) tree.getCellEditor();
@@ -290,6 +371,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * custom cellEditorListener.
      *
      */
+    @Test
     public void testEditorListenerRemovedOnEditorCancel() {
         JXTree tree = createEditingTree();
         DefaultTreeCellEditor cellEditor = (DefaultTreeCellEditor) tree.getCellEditor();
@@ -304,6 +386,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * custom cellEditorListener.
      *
      */
+    @Test
     public void testEditorListenerRemovedOnTreeCancel() {
         JXTree tree = createEditingTree();
         DefaultTreeCellEditor cellEditor = (DefaultTreeCellEditor) tree.getCellEditor();
@@ -318,6 +401,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * custom cellEditorListener.
      *
      */
+    @Test
     public void testEditorListenerRemovedOnTreeStop() {
         JXTree tree = createEditingTree();
         DefaultTreeCellEditor cellEditor = (DefaultTreeCellEditor) tree.getCellEditor();
@@ -332,6 +416,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * custom cellEditorListener.
      *
      */
+    @Test
     public void testEditorListenerOnXTree() {
         JTree core = new JTree();
         int coreCount = getListenerCountAfterStartEditing(core);
@@ -358,6 +443,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * characterization: listeners in core tree.
      *
      */
+    @Test
     public void testEditorListenerOnCoreTree() {
         JTree tree = new JTree();
         int listenerCount = getListenerCountAfterStartEditing(tree);
@@ -397,13 +483,14 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * invalid ComponentAdapter state. Negative invalid index.
      *
      */
+    @Test
     public void testIllegalNegativeTreeRowIndex() {
         JXTree tree = new JXTree();
         tree.expandAll();
         assertTrue(tree.getRowCount() > 0);
         TreeCellRenderer renderer = tree.getCellRenderer();
         renderer.getTreeCellRendererComponent(tree, "dummy", false, false, false, -1, false);
-        SearchPredicate predicate = new SearchPredicate(Pattern.compile("\\QNode\\E"));
+        SearchPredicate predicate = new SearchPredicate("\\QNode\\E");
         Highlighter searchHighlighter = new ColorHighlighter(predicate, null, Color.RED);
         tree.addHighlighter(searchHighlighter);
         renderer.getTreeCellRendererComponent(tree, "dummy", false, false, false, -1, false);
@@ -418,13 +505,14 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * invalid ComponentAdapter state. Invalid index > valid range.
      *
      */
+    @Test
     public void testIllegalExceedingTreeRowIndex() {
         JXTree tree = new JXTree();
         tree.expandAll();
         assertTrue(tree.getRowCount() > 0);
         TreeCellRenderer renderer = tree.getCellRenderer();
         renderer.getTreeCellRendererComponent(tree, "dummy", false, false, false, tree.getRowCount(), false);
-        SearchPredicate predicate = new SearchPredicate(Pattern.compile("\\QNode\\E"));
+        SearchPredicate predicate = new SearchPredicate("\\QNode\\E");
         Highlighter searchHighlighter = new ColorHighlighter(predicate, null, Color.RED);
         tree.addHighlighter(searchHighlighter);
         renderer.getTreeCellRendererComponent(tree, "dummy", false, false, false, tree.getRowCount(), false);
@@ -434,6 +522,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * test convenience method accessing the configured adapter.
      *
      */
+    @Test
     public void testConfiguredComponentAdapter() {
         JXTree list = new JXTree();
         list.expandAll();
@@ -454,6 +543,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * Issue #254-swingx: expandAll doesn't expand if root not shown?
      *
      */
+    @Test
     public void testExpandAllWithInvisible() {
         final DefaultMutableTreeTableNode root = new DefaultMutableTreeTableNode();
         final InsertTreeTableModel model = new InsertTreeTableModel(root);
@@ -479,6 +569,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * array != null
      *
      */
+    @Test
     public void testNotNullGetSelectedRows() {
         JXTree tree = new JXTree(treeTableModel);
         // sanity: no selection
@@ -491,6 +582,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * array != null
      *
      */
+    @Test
     public void testNotNullGetSelectedPaths() {
         JXTree tree = new JXTree(treeTableModel);
         // sanity: no selection
@@ -504,6 +596,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * PENDING: test all constructors!
      *
      */
+    @Test
     public void testInitInConstructors() {
         assertXTreeInit(new JXTree());
         assertXTreeInit(new JXTree(new Object[] {}));
@@ -532,6 +625,7 @@ public class JXTreeUnitTest extends InteractiveTestCase {
      * learning something new every day :-)
      *
      */
+    @Test
     public void testNullModel() {
         JXTree tree = new JXTree();
         assertNotNull(tree.getModel());
