@@ -1,5 +1,5 @@
 /*
- * $Id: XLocalizeTest.java,v 1.8 2008/03/18 13:16:30 kleopatra Exp $
+ * $Id: XLocalizeTest.java,v 1.10 2008/10/11 20:42:30 rah003 Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -35,8 +35,15 @@ import javax.swing.JComponent;
 import org.jdesktop.swingx.action.AbstractActionExt;
 import org.jdesktop.swingx.plaf.LookAndFeelAddons;
 import org.jdesktop.swingx.plaf.UIManagerExt;
+import org.jdesktop.swingx.search.PatternModel;
 import org.jdesktop.test.PropertyChangeReport;
 import org.jdesktop.test.TestUtils;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+import org.junit.Test;
+import org.junit.Before;
+import org.junit.After;
+
 
 /**
  * Test to expose known issues around <code>Locale</code> setting.
@@ -47,6 +54,7 @@ import org.jdesktop.test.TestUtils;
  * 
  * @author Jeanette Winzenburg
  */
+@RunWith(JUnit4.class)
 public class XLocalizeTest extends InteractiveTestCase {
     @SuppressWarnings("all")
     private static final Logger LOG = Logger.getLogger(XLocalizeTest.class
@@ -100,6 +108,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * 
      * Here: test FindPanel
      */
+    @Test
     public void testLocaleDialogPropertyNotificationInListener() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -150,6 +159,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * 
      * Here: test FindBar.
      */
+    @Test
     public void testLocaleFindBarPropertyNotificationInListener() {
         final String prefix = PatternModel.SEARCH_PREFIX;
         final JXFindBar findPanel = new JXFindBar();
@@ -193,6 +203,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * 
      * Here: test FindPanel
      */
+    @Test
     public void testLocaleFindPanelPropertyNotificationInListener() {
         final String prefix = PatternModel.SEARCH_PREFIX;
         final JXFindPanel findPanel = new JXFindPanel();
@@ -235,6 +246,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * test correct PropertyChangeNotification: must fire after
      * all internal state is set ... dooohhh.
      */
+    @Test
     public void testLocaleTablePropertyNotification() {
         String prefix = "JXTable.";
         JXTable table = new JXTable(10, 2);
@@ -261,6 +273,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * 
      * Here: test JXTable.
      */
+    @Test
     public void testLocaleTablePropertyNotificationInListener() {
         final String prefix = "JXTable.";
         final JXTable table = new JXTable(10, 2);
@@ -304,6 +317,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * Issue #635-swingx: find widgets must support dynamic localization
      * Here: test findPanel's actions (incomplete ..)
      */
+    @Test
     public void testLocaleFindPanel() {
         JXFindPanel panel = new JXFindPanel();
         // JW: arrrgghh ... dirty! Consequence of dirty initialization 
@@ -327,6 +341,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * <li> passes with jdk6 and LookAndFeelAddon addResourceBundle.
      * </ul>
      */
+    @Test
     public void testLocaleColumnControl() {
        String prefix = "JXTable.";
        JXTable table = new JXTable(10, 2);
@@ -375,6 +390,7 @@ public class XLocalizeTest extends InteractiveTestCase {
      * 
      * 
      */
+    @Test
     public void testGetLocaleUIDefaults() {
         String key = "JXTable.column.packAll";
         Object alternativeValue = UIManagerExt.getString(key, OTHER_LOCALE);
