@@ -1,5 +1,5 @@
 /*
- * $Id: HighlighterTest.java,v 1.31 2008/04/25 10:44:21 kleopatra Exp $
+ * $Id: HighlighterTest.java,v 1.42 2008/10/11 20:42:31 rah003 Exp $
  *
  * Copyright 2004 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -19,6 +19,9 @@ import javax.swing.JTextField;
 import javax.swing.UIManager;
 import javax.swing.border.Border;
 import javax.swing.border.CompoundBorder;
+import javax.swing.plaf.ColorUIResource;
+
+import junit.framework.TestCase;
 
 import org.jdesktop.swingx.InteractiveTestCase;
 import org.jdesktop.swingx.decorator.HighlighterFactory.UIColorHighlighter;
@@ -29,6 +32,14 @@ import org.jdesktop.swingx.renderer.JRendererLabel;
 import org.jdesktop.swingx.test.XTestUtils;
 import org.jdesktop.test.ChangeReport;
 import org.jdesktop.test.PropertyChangeReport;
+import org.junit.Before;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+import org.junit.Test;
+import org.junit.Before;
+import org.junit.After;
+
 
 /**
  * 
@@ -36,6 +47,7 @@ import org.jdesktop.test.PropertyChangeReport;
  * 
  * @author Jeanette Winzenburg
  */
+@RunWith(JUnit4.class)
 public class HighlighterTest extends InteractiveTestCase {
     private static final Logger LOG = Logger.getLogger(HighlighterTest.class
             .getName());
@@ -59,7 +71,8 @@ public class HighlighterTest extends InteractiveTestCase {
     protected boolean defaultToSystemLF;
 
     @Override
-    protected void setUp() {
+    @Before
+       public void setUp() {
         backgroundNull = new JLabel("test");
         backgroundNull.setForeground(foreground);
         backgroundNull.setBackground(null);
@@ -82,11 +95,12 @@ public class HighlighterTest extends InteractiveTestCase {
         emptyHighlighter = new ColorHighlighter();
         // make sure we have the same default for each test
         defaultToSystemLF = false;
-        setSystemLF(defaultToSystemLF);
+        InteractiveTestCase.setSystemLF(defaultToSystemLF);
     }
 
 //-------------------PainterHighlighter
     
+    @Test
      public void testPainterHighlighterConstructors() {
         PainterHighlighter hl = new PainterHighlighter();
         assertEquals(HighlightPredicate.ALWAYS, hl.getHighlightPredicate());
@@ -95,15 +109,16 @@ public class HighlighterTest extends InteractiveTestCase {
         PainterHighlighter withPainter = new PainterHighlighter(mattePainter);
         assertEquals(HighlightPredicate.ALWAYS, withPainter.getHighlightPredicate());
         assertEquals(mattePainter, withPainter.getPainter());
+        PainterHighlighter withPredicate = new PainterHighlighter(HighlightPredicate.NEVER);
+        assertEquals(HighlightPredicate.NEVER, withPredicate.getHighlightPredicate());
+        assertEquals(null, withPredicate.getPainter());
         PainterHighlighter all = new PainterHighlighter(HighlightPredicate.NEVER, mattePainter);
         assertEquals(HighlightPredicate.NEVER, all.getHighlightPredicate());
         assertEquals(mattePainter, all.getPainter());
-        PainterHighlighter allOld = new PainterHighlighter(HighlightPredicate.NEVER, mattePainter);
-        assertEquals(HighlightPredicate.NEVER, allOld.getHighlightPredicate());
-        assertEquals(mattePainter, allOld.getPainter());
     }
     
-    public void testPainterHighlighterSetPainterAndNotificatioon() {
+    @Test
+    public void testPainterHighlighterSetPainterChangeNotificatioon() {
         PainterHighlighter hl = new PainterHighlighter();
         ChangeReport report = new ChangeReport();
         hl.addChangeListener(report);
@@ -113,9 +128,19 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(1, report.getEventCount());
      }
     
+    @Test
+    public void testPainterHighlighterSetPainterNoChangeNotificatioon() {
+        MattePainter mattePainter = new MattePainter();
+        PainterHighlighter hl = new PainterHighlighter(mattePainter);
+        ChangeReport report = new ChangeReport();
+        hl.addChangeListener(report);
+        hl.setPainter(mattePainter);
+        assertEquals(0, report.getEventCount());
+     }
     /**
      * Issue #851-swingx: Highlighter must notify on painter property change
      */
+    @Test
     public void testPainterHighlighterPainterPropertyChangeNotificatioon() {
         PainterHighlighter hl = new PainterHighlighter();
         Color red = Color.RED;
@@ -138,6 +163,7 @@ public class HighlighterTest extends InteractiveTestCase {
      * the decoration. Supported in base to ease subclassing and keep
      * backward compatibility
      */
+    @Test
     public void testPainterHighlighterPainterPropertyNotNotifyInternalChange() {
         Color red = Color.RED;
         MattePainter mattePainter = new MattePainter(red);
@@ -160,6 +186,7 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(0, report.getEventCount());
      }
 
+    @Test
     public void testPainterHighlighterUsePainter() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         MattePainter mattePainter = new MattePainter();
@@ -169,6 +196,7 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(mattePainter, allColored.getPainter());
     }
     
+    @Test
     public void testPainterHighlighterNotUseNullPainter() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         PainterHighlighter hl = new PainterHighlighter();
@@ -179,6 +207,7 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(mattePainter, allColored.getPainter());
     }
     
+    @Test
     public void testPainterHighlighterIgnoreNotPainterAware() {
         ComponentAdapter adapter = createComponentAdapter(foregroundNull, false);
         MattePainter mattePainter = new MattePainter();
@@ -191,6 +220,7 @@ public class HighlighterTest extends InteractiveTestCase {
     /**
      * highlight every second 
      */
+    @Test
     public void testSimpleStriping() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         Highlighter h = HighlighterFactory.createSimpleStriping(unselectedBackground);
@@ -206,6 +236,7 @@ public class HighlighterTest extends InteractiveTestCase {
     /**
      * highlight every second 
      */
+    @Test
     public void testAlternateStriping() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         Highlighter h = HighlighterFactory.createAlternateStriping(unselectedBackground, selectedBackground);
@@ -220,6 +251,7 @@ public class HighlighterTest extends InteractiveTestCase {
 
 //-------------- IconHighlighter
 
+    @Test
     public void testIconHighlighterNotHighlightUnable() {
         Icon icon = XTestUtils.loadDefaultIcon();
         JTextField allColored = new JTextField();
@@ -229,6 +261,7 @@ public class HighlighterTest extends InteractiveTestCase {
     }
 
 
+    @Test
     public void testIconHighlighterNotHighlight() {
         Icon icon = XTestUtils.loadDefaultIcon();
         allColored.setIcon(icon);
@@ -237,6 +270,7 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(icon, allColored.getIcon());
     }
 
+    @Test
     public void testIconHighlighterHighlight() {
         Icon icon = XTestUtils.loadDefaultIcon();
         IconHighlighter hl = new IconHighlighter(icon);
@@ -244,7 +278,8 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(icon, allColored.getIcon());
     }
     
-    public void testIconHighlightChangeIcon() {
+    @Test
+    public void testIconHighlightIconChangeNotification() {
         IconHighlighter hl = new IconHighlighter();
         Icon icon = XTestUtils.loadDefaultIcon();
         ChangeReport report = new ChangeReport();
@@ -253,6 +288,18 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(icon, hl.getIcon());
         assertEquals(1, report.getEventCount());
     }
+    
+    @Test
+    public void testIconHighlightIconNoChangeNotification() {
+        Icon icon = XTestUtils.loadDefaultIcon();
+        IconHighlighter hl = new IconHighlighter(icon);
+        ChangeReport report = new ChangeReport();
+        hl.addChangeListener(report);
+        hl.setIcon(icon);
+        assertEquals(0, report.getEventCount());
+    }
+    
+    @Test
     public void testIconHighlighterConstructors() {
         IconHighlighter empty = new IconHighlighter();
         assertIconHighlighter(empty, HighlightPredicate.ALWAYS, null);
@@ -271,6 +318,46 @@ public class HighlighterTest extends InteractiveTestCase {
     }
 //-------------- BorderHighlighter
     
+    /**
+     * Test that all properties have setters and fire a changeEvent. 
+     */
+    @Test
+    public void testBorderHighlightSetters() {
+        BorderHighlighter hl = new BorderHighlighter();
+        ChangeReport report = new ChangeReport();
+        hl.addChangeListener(report);
+        hl.setInner(!hl.isInner());
+        assertEquals(1, report.getEventCount());
+        report.clear();
+        hl.setCompound(!hl.isCompound());
+        assertEquals(1, report.getEventCount());
+    }
+    
+    /**
+     * Test setBorder and fire a changeEvent.
+     * (setter was missing) 
+     */
+    @Test
+    public void testBorderHighlightSetBorder() {
+        BorderHighlighter hl = new BorderHighlighter();
+        ChangeReport report = new ChangeReport();
+        hl.addChangeListener(report);
+        Border padding = BorderFactory.createLineBorder(Color.RED, 3);
+        hl.setBorder(padding);
+        assertEquals("sanity: border set", padding, hl.getBorder());
+        assertEquals("must fire on setting border", 1, report.getEventCount());
+        report.clear();
+        hl.setBorder(padding);
+        assertEquals("must not fire on setting the same border", 0, report.getEventCount());
+        hl.setBorder(null);
+        assertEquals("must fire on setting border null", 1, report.getEventCount());
+        report.clear();
+        hl.setBorder(null);
+        assertEquals("must not fire setting same null border", 0, report.getEventCount());
+    }
+    
+    
+    @Test
     public void testBorderPaddingNull() {
         BorderHighlighter empty = new BorderHighlighter();
         Border border = allColored.getBorder();
@@ -279,6 +366,7 @@ public class HighlighterTest extends InteractiveTestCase {
                 border, allColored.getBorder());
     }
 
+    @Test
     public void testBorderPaddingCompoundNotInner() {
         Border padding = BorderFactory.createLineBorder(Color.RED, 3);
         BorderHighlighter empty = new BorderHighlighter(padding);
@@ -293,6 +381,7 @@ public class HighlighterTest extends InteractiveTestCase {
                 padding, ((CompoundBorder) compound).getInsideBorder());
     }
 
+    @Test
     public void testBorderPaddingCompoundInner() {
         Border padding = BorderFactory.createLineBorder(Color.RED, 3);
         BorderHighlighter empty = new BorderHighlighter(padding);
@@ -306,6 +395,7 @@ public class HighlighterTest extends InteractiveTestCase {
                 border, ((CompoundBorder) compound).getInsideBorder());
     }
     
+    @Test
     public void testBorderPaddingReplace() {
         Border padding = BorderFactory.createLineBorder(Color.RED, 3);
         BorderHighlighter empty = new BorderHighlighter(null, padding, false);
@@ -314,6 +404,7 @@ public class HighlighterTest extends InteractiveTestCase {
                 padding, allColored.getBorder());
     }
     
+    @Test
     public void testBorderPaddingSetBorderIfComponentBorderNull() {
         Border padding = BorderFactory.createLineBorder(Color.RED, 3);
         BorderHighlighter empty = new BorderHighlighter(padding);
@@ -322,6 +413,7 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals("borderHighlighter padding and null component border must set", 
                 padding, allColored.getBorder());
     }
+    @Test
     public void testBorderConstructors() {
         BorderHighlighter empty = new BorderHighlighter();
         assertBorderHLState(empty, HighlightPredicate.ALWAYS, null, true, false);
@@ -348,6 +440,7 @@ public class HighlighterTest extends InteractiveTestCase {
 
 //------------------ ShadingColorHighlighter
     
+    @Test
     public void testShadingConstructors() {
         ShadingColorHighlighter shading = new ShadingColorHighlighter();
         assertColorsAndPredicate(shading, HighlightPredicate.ALWAYS, null, null, null, null);
@@ -355,6 +448,7 @@ public class HighlighterTest extends InteractiveTestCase {
         assertColorsAndPredicate(never, HighlightPredicate.NEVER, null, null, null, null);
     }
     
+    @Test
     public void testShadingEffect() {
         
     }
@@ -363,6 +457,7 @@ public class HighlighterTest extends InteractiveTestCase {
     /**
      * Test constructor of ColorHighlighter.
      */
+    @Test
     public void testConstructors() {
         ColorHighlighter empty = new ColorHighlighter();
         assertColorsAndPredicate(empty, HighlightPredicate.ALWAYS, null, null, null, null);
@@ -391,31 +486,98 @@ public class HighlighterTest extends InteractiveTestCase {
     }
 //----------------- testing change notification ColorHighlighter
 
-    
-    public void testHighlighterChange() {
-        ColorHighlighter highlighter = new ColorHighlighter();
-        ChangeReport changeReport = new ChangeReport();
-        highlighter.addChangeListener(changeReport);
-        assertBaseHighlighterChange(highlighter, changeReport);
+    /**
+     * Test ui dependent color is updated.
+     */
+    @Test
+    public void testCustomUIColorHighlighter() {
+        UIColorHighlighter h = new UIColorHighlighter();
+        Color uiBackground = h.getBackground();
+        Color uiColor = UIManager.getColor("UIColorHighlighter.stripingBackground");
+        // very unusual ui striping
+        Color color = new ColorUIResource(Color.BLACK);
+        if (color.equals(uiBackground)) {
+            LOG.info("cannot run testUIColorHighlight - ui striping same as test color");
+            return;
+        }
+        UIManager.put("UIColorHighlighter.stripingBackground", color);
+        try {
+            h.updateUI();
+            assertEquals(color, h.getBackground());
+        } finally {
+            // remove custom setting. DO NOT set the old uiColor manually!
+            UIManager.put("UIColorHighlighter.stripingBackground", null);
+        }
+        // sanity - reset
+        h.updateUI();
+        assertNotNull(h.getBackground());
+        assertNotSame(color.getRGB(), h.getBackground().getRGB());
+        // can be generic grey as well (as per HighLighterFactory treatment of cases with no LAF defined)
+        boolean found = h.getBackground().equals( uiColor) || h.getBackground().equals(HighlighterFactory.GENERIC_GRAY);
+        assertTrue("Found " + h.getBackground() + " while expected " + uiColor, found);
     }
 
-    private void assertBaseHighlighterChange(ColorHighlighter highlighter, ChangeReport changeReport) {
-        int count = changeReport.getEventCount();
-        highlighter.setBackground(Color.red);
-        assertEquals("event count must be increased", ++count,  changeReport.getEventCount() );
-        highlighter.setForeground(Color.red);
-        assertEquals("event count must be increased", ++count,  changeReport.getEventCount() );
-        highlighter.setSelectedBackground(Color.red);
-        assertEquals("event count must be increased", ++count,  changeReport.getEventCount() );
-        highlighter.setSelectedForeground(Color.red);
-        assertEquals("event count must be increased", ++count,  changeReport.getEventCount() );
-        highlighter.setHighlightPredicate(HighlightPredicate.NEVER);
-        assertEquals("event count must be increased", ++count, changeReport.getEventCount());
+    
+    
+    @Test
+    public void testColorHighlighterChangeNotification() {
+        ColorHighlighter highlighter = new ColorHighlighter();
+        assertBaseHighlighterChange(highlighter, 1);
+    }
+
+    @Test
+    public void testColorHighlighterNoChangeNotification() {
+        ColorHighlighter highlighter = new ColorHighlighter(HighlightPredicate.NEVER, 
+                Color.RED, Color.RED, Color.RED, Color.RED);
+        assertBaseHighlighterChange(highlighter, 0);
     }
     
- 
+    private void assertBaseHighlighterChange(ColorHighlighter highlighter,  int count ) {
+        ChangeReport changeReport = new ChangeReport();
+        highlighter.addChangeListener(changeReport);
+        highlighter.setBackground(Color.red);
+        assertEquals("event count ", count,  changeReport.getEventCount() );
+        changeReport.clear();
+        highlighter.setForeground(Color.red);
+        assertEquals("event count ", count,  changeReport.getEventCount() );
+        changeReport.clear();
+        highlighter.setSelectedBackground(Color.red);
+        assertEquals("event count ", count,  changeReport.getEventCount() );
+        changeReport.clear();
+        highlighter.setSelectedForeground(Color.red);
+        assertEquals("event count ", count,  changeReport.getEventCount() );
+        changeReport.clear();
+        highlighter.setHighlightPredicate(HighlightPredicate.NEVER);
+        assertEquals("event count ", count, changeReport.getEventCount());
+    }
+    
+    /**
+     * test that the base implementation is polite and fires only if 
+     * the predicate is really changed.
+     */
+    @Test
+    public void testHighlightPredicateNoChangeNotification() {
+        AbstractHighlighter hl = new AbstractHighlighter() {
+
+            @Override
+            protected Component doHighlight(Component component,
+                    ComponentAdapter adapter) {
+                return component;
+            }
+            
+        };
+        ChangeReport report = new ChangeReport();
+        hl.addChangeListener(report);
+        hl.setHighlightPredicate(HighlightPredicate.ALWAYS);
+        assertEquals("must not fire on setting same predicate", 0, report.getEventCount());
+        report.clear();
+        hl.setHighlightPredicate(null);
+        assertEquals("must not fire on setting same predicate", 0, report.getEventCount());
+        
+    }
 //---------------------- exposing highlighter probs with null component color
     
+    @Test
     public void testLabelSanity() {
         assertNull("foreground must be null", foregroundNull.getForeground());
         assertNotNull("background must not be null", foregroundNull.getBackground());
@@ -432,6 +594,7 @@ public class HighlighterTest extends InteractiveTestCase {
     /**
      * test predicate defaults to always
      */
+    @Test
     public void testDefaultPredicate() {
         ColorHighlighter highlighter = new ColorHighlighter();
         assertSame(HighlightPredicate.ALWAYS, highlighter.getHighlightPredicate());
@@ -441,6 +604,7 @@ public class HighlighterTest extends InteractiveTestCase {
      * test highlight respects predicate never.
      *
      */
+    @Test
     public void testHighlightPredicate() {
         ColorHighlighter highlighter = new ColorHighlighter(unselectedBackground, 
                 unselectedForeground);
@@ -457,6 +621,7 @@ public class HighlighterTest extends InteractiveTestCase {
      * Test ColorHighlighter decorate unselected cell.
      *
      */
+    @Test
     public void testApplyColorHighlighterUnselected() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         ColorHighlighter highlighter = new ColorHighlighter(unselectedBackground, 
@@ -468,6 +633,7 @@ public class HighlighterTest extends InteractiveTestCase {
      * Test ColorHighlighter decorate selected cell.
      *
      */
+    @Test
     public void testApplyColorHighlighterSelected() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         ColorHighlighter highlighter = new ColorHighlighter(unselectedBackground, 
@@ -479,6 +645,7 @@ public class HighlighterTest extends InteractiveTestCase {
      * test that same renderer is returned.
      *
      */
+    @Test
     public void testReturnHighlightedComponent() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         ColorHighlighter highlighter = new ColorHighlighter(unselectedBackground, 
@@ -490,6 +657,7 @@ public class HighlighterTest extends InteractiveTestCase {
      * Issue #178-swingx: Highlighters always change the selection color.
      * sanity test to see if non-selected colors are unchanged.
      */
+    @Test
     public void testUnSelectedDoNothingHighlighter() {
         ComponentAdapter adapter = createComponentAdapter(allColored, false);
         assertApplied(emptyHighlighter, allColored, adapter);
@@ -497,6 +665,7 @@ public class HighlighterTest extends InteractiveTestCase {
     /**
      * Issue #178-swingx: Highlighters always change the selection color.
      */
+    @Test
     public void testSelectedDoNothingHighlighter() {
         ComponentAdapter adapter = createComponentAdapter(allColored, true);
         assertApplied(emptyHighlighter, allColored, adapter);
@@ -547,6 +716,7 @@ public class HighlighterTest extends InteractiveTestCase {
      * test that the ui color highlighter comes up with 
      * the ui-setting.
      */
+    @Test
     public void testInitialUIColorHighlighter() {
         ColorHighlighter h = new UIColorHighlighter();
         Color uiBackground = h.getBackground();
@@ -557,130 +727,6 @@ public class HighlighterTest extends InteractiveTestCase {
         assertEquals(uiColor, uiBackground);
     }
     
-//-----------------------  CompoundHighlighter
-    
-    /**
-     * there had been exceptions when adding/removing highlighters to/from
-     * an initially empty pipeline. 
-     */
-    public void testAddToEmptyCompoundHiglighter() {
-        CompoundHighlighter pipeline = new CompoundHighlighter();
-        pipeline.addHighlighter(new ColorHighlighter());
-    }
-    public void testRemoveFromEmptyCompoundHighlighter() {
-        CompoundHighlighter pipeline = new CompoundHighlighter();
-        pipeline.removeHighlighter(new ColorHighlighter());
-    }
-    public void testApplyEmptyCompoundHighlighter() {
-        CompoundHighlighter pipeline = new CompoundHighlighter();
-        pipeline.highlight(new JLabel(), createComponentAdapter(new JLabel(), false));
-    }
-
-    /*
-     */
-    public void testAddRemoveHighlighter() {
-        CompoundHighlighter pipeline = new CompoundHighlighter(
-                new ColorHighlighter(Color.white, new Color(0xF0, 0xF0, 0xE0)),
-                new ColorHighlighter(null, foreground)
-                );
-
-        ColorHighlighter hl = new ColorHighlighter(Color.blue, Color.red);
-        ColorHighlighter hl2 = new ColorHighlighter(Color.white, Color.black);
-
-        // added highlighter should be appended
-        pipeline.addHighlighter(hl);
-
-        Highlighter[] hls = pipeline.getHighlighters();
-
-        assertTrue(hls.length == 3);
-        assertTrue(hls[2] == hl);
-
-        // added highlighter should be prepended
-        pipeline.addHighlighter(hl2, true);
-
-        hls = pipeline.getHighlighters();
-
-        assertTrue(hls.length == 4);
-        assertTrue(hls[0] == hl2);
-
-        // remove highlighter
-        pipeline.removeHighlighter(hl);
-
-        hls = pipeline.getHighlighters();
-        assertTrue(hls.length == 3);
-        for (int i = 0; i < hls.length; i++) {
-            assertTrue(hls[i] != hl);
-        }
-
-        // remove another highligher
-        pipeline.removeHighlighter(hl2);
-
-        hls = pipeline.getHighlighters();
-        assertTrue(hls.length == 2);
-        for (int i = 0; i < hls.length; i++) {
-            assertTrue(hls[i] != hl2);
-        }
-    }
-
-
-    //----------------- testing change notification of pipeline
-    
-    /**
-     * @todo - how to handle same highlighter inserted more than once?
-     */
-    public void testCompoundHighlighterWithDuplicates() {
-        
-    }
-    
-    /**
-     * test doc'ed NPE when adding null Highlighter.
-     *
-     */
-    public void testCompoundHighlighterAddNull() {
-        CompoundHighlighter pipeline = new CompoundHighlighter();
-        try {
-            pipeline.addHighlighter(null);
-            fail("compoundHighlighter must not accept null highlighter");
-        } catch(NullPointerException ex) {
-            
-        }
-        ComponentAdapter adapter = createComponentAdapter(allColored, false);
-        // was added even with NPE.
-        pipeline.highlight(allColored, adapter);
-    }
-    
-    public void testCompoundHighlighterChange() {
-        ColorHighlighter highlighter = new ColorHighlighter();
-        CompoundHighlighter pipeline = new CompoundHighlighter();
-        ChangeReport changeReport = new ChangeReport();
-        pipeline.addChangeListener(changeReport);
-        int count = changeReport.getEventCount();
-        pipeline.addHighlighter(highlighter);
-        assertEquals("event count must be increased", ++count,  changeReport.getEventCount() );
-        assertCompoundHighlighterChange(highlighter, pipeline, changeReport);
-    }
-    
-    public void testCompoundHighlighterChangeConstructor() {
-        ColorHighlighter highlighter = new ColorHighlighter();
-        CompoundHighlighter pipeline = new CompoundHighlighter(highlighter);
-        ChangeReport changeReport = new ChangeReport();
-        pipeline.addChangeListener(changeReport);
-        assertCompoundHighlighterChange(highlighter, pipeline, changeReport);
- 
-    }
-    private void assertCompoundHighlighterChange(ColorHighlighter highlighter, CompoundHighlighter pipeline, ChangeReport changeReport) {
-        int count = changeReport.getEventCount();
-        highlighter.setBackground(Color.red);
-        assertEquals("event count must be increased", ++count,  changeReport.getEventCount() );
-        assertEquals("event source must be pipeline", pipeline, changeReport.getLastEvent().getSource());
-        pipeline.removeHighlighter(highlighter);
-        assertEquals("event count must be increased", ++count,  changeReport.getEventCount() );
-        pipeline.removeHighlighter(highlighter);
-        assertEquals("event count must not be increased", count,  changeReport.getEventCount() );
-        highlighter.setBackground(Color.BLUE);
-        assertEquals("event count must not be increased", count,  changeReport.getEventCount() );
-    }
- 
     // --------------------- factory methods
     
     /**
@@ -754,10 +800,6 @@ public class HighlighterTest extends InteractiveTestCase {
                 return null;
             }
 
-            @Override
-            public String getColumnIdentifier(int columnIndex) {
-                return null;
-            }
             
         };
         return adapter;
