@@ -1,5 +1,5 @@
 /*
- * $Id: BasicMonthViewUITest.java,v 1.24 2008/04/01 12:21:28 kleopatra Exp $
+ * $Id: BasicMonthViewUITest.java,v 1.29 2008/12/16 13:42:34 kleopatra Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -21,6 +21,8 @@
  */
 package org.jdesktop.swingx.plaf.basic;
 
+import java.awt.BorderLayout;
+import java.awt.Color;
 import java.awt.ComponentOrientation;
 import java.awt.Dimension;
 import java.awt.GraphicsEnvironment;
@@ -36,8 +38,12 @@ import java.util.Date;
 import java.util.Locale;
 import java.util.logging.Logger;
 
+import javax.swing.AbstractAction;
 import javax.swing.Action;
+import javax.swing.Box;
 import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JLabel;
 import javax.swing.UIManager;
 
 import org.jdesktop.swingx.InteractiveTestCase;
@@ -47,12 +53,19 @@ import org.jdesktop.swingx.JXMonthView;
 import org.jdesktop.swingx.action.AbstractActionExt;
 import org.jdesktop.swingx.calendar.CalendarUtils;
 import org.jdesktop.swingx.calendar.DateSelectionModel.SelectionMode;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+import org.junit.Test;
+import org.junit.Before;
+import org.junit.After;
+
 
 /**
  * Tests to expose known issues of BasicMonthViewUI.
  * 
  * @author Jeanette Winzenburg
  */
+@RunWith(JUnit4.class)
 public class BasicMonthViewUITest extends InteractiveTestCase {
     @SuppressWarnings("all")
     private static final Logger LOG = Logger
@@ -75,50 +88,108 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
   }
  
     /**
-     * Issue #781-swingx: reverse coordinate mapping form date to bounds.
+     * Issue #750-swingx: use rendering to side-step antialiase probs.
      * 
      * Debugging ...
      */
-    public void interactiveBoundsFromDate() {
+    public void interactiveRenderingOn() {
+        // force default loading
+        new JXMonthView();
+        // this is global state - uncomment for debug painting completely
+//        UIManager.put("JXMonthView.trailingDayForeground", Color.YELLOW);
+//        UIManager.put("JXMonthView.leadingDayForeground", Color.ORANGE);
+//        UIManager.put("JXMonthView.weekOfTheYearForeground", Color.GREEN);
+//        UIManager.put("JXMonthView.unselectableDayForeground", Color.MAGENTA);
+        String frameTitle = "Debug painting: rendering on";
+        showDebugMonthView(frameTitle, null);
+    }
+
+    /**
+     * Issue #750-swingx: use rendering to side-step antialiase probs.
+     * 
+     * Debugging ...
+     */
+    public void interactiveRenderingOff() {
+        String frameTitle = "Debug painting: rendering off";
+        Boolean disableRendering = Boolean.TRUE;
+        showDebugMonthView(frameTitle, disableRendering);
+    }
+    /**
+     * @param frameTitle
+     * @param disableRendering
+     */
+    private void showDebugMonthView(String frameTitle, Boolean disableRendering) {
         final JXMonthView monthView = new JXMonthView();
+        monthView.putClientProperty("disableRendering", disableRendering);
+        monthView.setDayForeground(Calendar.SUNDAY, Color.BLUE);
+        monthView.setDaysOfTheWeekForeground(Color.RED);
+        monthView.setFlaggedDayForeground(Color.CYAN);
+        monthView.setSelectionBackground(Color.GRAY);
+        monthView.setSelectionForeground(Color.GREEN);
+        monthView.setTodayBackground(Color.PINK);
         monthView.setTraversable(true);
         monthView.setShowingWeekNumber(true);
         monthView.setShowingLeadingDays(true);
         monthView.setShowingTrailingDays(true);
         monthView.setSelectionMode(SelectionMode.SINGLE_INTERVAL_SELECTION);
-        monthView.setPreferredCols(2);
-        monthView.setPreferredRows(2);
-        final BasicMonthViewUI ui = ((BasicMonthViewUI) monthView.getUI());
-        Action action = new AbstractActionExt("toggle minimal") {
+        monthView.setPreferredColumnCount(2);
+        monthView.setPreferredRowCount(2);
+        final JXFrame frame = wrapInFrame(monthView, frameTitle);
+        addComponentOrientationToggle(frame);
+        Action toggleTraversable = new AbstractAction("toggle traversable") {
 
             public void actionPerformed(ActionEvent e) {
-                int minimal = monthView.getSelectionModel().getMinimalDaysInFirstWeek();
-                monthView.getSelectionModel().setMinimalDaysInFirstWeek(minimal > 1 ? 1 : 4);
+                monthView.setTraversable(!monthView.isTraversable());
+                
             }
             
         };
-        final JXFrame frame = wrapInFrame(monthView, "test mapping: printed on mouse release");
-        addAction(frame, action);
-        addComponentOrientationToggle(frame);
+        addAction(frame, toggleTraversable);
         final JXDatePicker picker = new JXDatePicker();
+        picker.getMonthView().putClientProperty("disableRendering", disableRendering);
         picker.addActionListener(new ActionListener() {
 
             public void actionPerformed(ActionEvent e) {
                 if (e.getActionCommand().equals(JXDatePicker.CANCEL_KEY)) return;
                 if (picker.getDate() == null) return;
-//                LOG.info("logical monthPosition " + 
-//                        ui.getMonthGridPosition(picker.getDate()) 
-//                        + "\n  bounds " + ui.getMonthBounds(picker.getDate()));
-                LOG.info("logical dayPosition " + 
-                        ui.getDayGridPosition(picker.getDate()) 
-                        + "\n  bounds " + ui.getDayBounds(picker.getDate()));
-
+                monthView.setFlaggedDates(picker.getDate());
             }
             
         });
-        addStatusComponent(frame, picker);
-        frame.pack();
-        frame.setVisible(true);
+        final JXDatePicker unselectable = new JXDatePicker();
+        unselectable.getMonthView().putClientProperty("disableRendering", disableRendering);
+        unselectable.addActionListener(new ActionListener() {
+
+            public void actionPerformed(ActionEvent e) {
+                if (e.getActionCommand().equals(JXDatePicker.CANCEL_KEY)) return;
+                if (unselectable.getDate() == null) return;
+                monthView.setUnselectableDates(unselectable.getDate());
+            }
+            
+        });
+        final JComboBox zoneSelector = new JComboBox(Locale.getAvailableLocales());
+        // Synchronize the monthView's and selector's zones.
+        zoneSelector.setSelectedItem(monthView.getLocale());
+
+        // Set the monthView's time zone based on the selected time zone.
+        zoneSelector.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent event) {
+                Locale zone = (Locale) zoneSelector.getSelectedItem();
+                monthView.setLocale(zone);
+//                monthView.revalidate();
+            }
+        });
+
+
+        JComponent pickers = Box.createHorizontalBox();
+        pickers.add(new JLabel("Flagged: "));
+        pickers.add(picker);
+        pickers.add(new JLabel("Unselectable: "));
+        pickers.add(unselectable);
+        pickers.add(new JLabel("Locale: "));
+        pickers.add(zoneSelector);
+        frame.add(pickers, BorderLayout.SOUTH);
+        show(frame);
     }
 
 
@@ -134,8 +205,8 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
         monthView.setShowingLeadingDays(true);
         monthView.setShowingTrailingDays(true);
         monthView.setSelectionMode(SelectionMode.SINGLE_INTERVAL_SELECTION);
-        monthView.setPreferredCols(2);
-        monthView.setPreferredRows(2);
+        monthView.setPreferredColumnCount(2);
+        monthView.setPreferredRowCount(2);
         final BasicMonthViewUI ui = ((BasicMonthViewUI) monthView.getUI());
         monthView.addMouseListener(new MouseAdapter() {
 
@@ -226,6 +297,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test that day position in details day-of-week header returns null date
      */
+    @Test
     public void testDayInMonthForDayOfWeekHeader() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -241,6 +313,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test that day position in details weekNumber header returns null date
      */
+    @Test
     public void testDayInMonthForWeekNumberHeader() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -257,6 +330,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Test contract of getDayInMonth: grid position of leading dates must be null.
      * Here: first month in grid.
      */
+    @Test
     public void testDayInMonthLeadingFirstMonth() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -273,6 +347,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Test contract of getDayInMonth: grid position of leading dates must be null.
      * Here: second month in grid.
      */
+    @Test
     public void testDayInMonthLeadingSecondMonth() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -290,6 +365,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Issue #787-swingx: hit detection of leading/trailing days.
      * Sanity: get day bounds for leading dates (here: second month) must succeed.
      */
+    @Test
     public void testDayBoundsAtLocationLeadingSecondMonth() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -312,6 +388,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Issue #787-swingx: hit detection of leading/trailing days.
      * Sanity: get day bounds for leading dates (here: first month) must succeed.
      */
+    @Test
     public void testDayBoundsAtLocationLeadingFirstMonth() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -331,6 +408,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Issue #787-swingx: hit detection of leading/trailing days.
      * Must be null (second month).
      */
+    @Test
     public void testDayAtLocationLeadingSecondMonth() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -349,6 +427,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Issue #787-swingx: hit detection of leading/trailing days.
      * Must be null (first month).
      */
+    @Test
     public void testDayAtLocationLeadingFirstMonth() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -366,6 +445,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test full circle: getDayBounds(Date)
      */
+    @Test
     public void testDayBoundsFromDate() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -389,6 +469,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Test getDayGridPosition(Date) - 
      * here: had been incorrect calculation of first row.
      */
+    @Test
     public void testDateToGridPosition6Apr2008() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -397,8 +478,9 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
         }
         BasicMonthViewUI ui = getRealizedMonthViewUI(ComponentOrientation.LEFT_TO_RIGHT);
         Calendar cal = ui.getCalendar();
-        cal.set(2008, Calendar.APRIL, 6);
-        // it's the last day of the first week
+        // 6th April was sunday ... it is a last day of the first week, but only at places where first day is Monday.
+        // so using this obsure notation we get last day of first week depending on when the week really starts.
+        cal.set(2008, Calendar.APRIL, 4 + cal.getFirstDayOfWeek()); 
         assertEquals(6, ui.getDayGridPosition(cal.getTime()).x);
         assertEquals(0, ui.getDayGridPosition(cal.getTime()).y);
         
@@ -407,6 +489,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
     * Test getDayGridPosition(Date) - first complete row
     */
+    @Test
     public void testDateToGridPositionNonLeading() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -423,6 +506,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
     * Test getDayGridPosition(Date) - somewhere in the middle (being paranoid ;-)
      */
+    @Test
     public void testDateToGridPositionMiddle() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -460,6 +544,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test full circle: getMonthGridPosition(Date) - had problems with first row?
      */
+    @Test
     public void testMonthGridPositionFirstRowFromDate() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -489,6 +574,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test full circle: getMonthGridPosition(Date) - had problems with first row?
      */
+    @Test
     public void testDateToMonthGridPositionFirst() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -501,6 +587,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test full circle: getMonthGridPosition(Date) - had problems with first row?
      */
+    @Test
     public void testDateToMonthGridPositionSecond() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -514,6 +601,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test full circle: getMonthGridPosition(Date)
      */
+    @Test
     public void testDateToMonthGridPositionLast() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -527,6 +615,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test full circle: getMonthBounds(Date)
      */
+    @Test
     public void testDateToMonthBounds() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -544,6 +633,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test  getMonthBounds(Date) for not visible dates are null.
      */
+    @Test
     public void testDateToMonthBoundsNotVisible() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -563,6 +653,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test  getDayBounds(Date)  for null date must throw NPE.
      */
+    @Test
     public void testMonthBoundsNullDate() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -581,6 +672,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test  getDayBounds(Date) for leading dates are null.
      */
+    @Test
     public void testDateToDayBoundsLeadingDate() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -600,6 +692,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test  getDayBounds(Date)  for null date must fire NPE.
      */
+    @Test
     public void testDayBoundsNullDate() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -618,6 +711,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Issue #781-swingx: reverse coordinate transformation.
      * Here: expose sizes
      */
+    @Test
     public void testMonthSize() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run test - headless environment");
@@ -633,6 +727,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Issue #781-swingx: reverse coordinate transformation.
      * Here: expose sizes
      */
+    @Test
     public void testDaySize() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run test - headless environment");
@@ -647,6 +742,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
         assertEquals(dayBounds.height, ui.getDaySize().height);
     }
     
+    @Test
     public void testMonthBoundsFromLogicalRToL() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run test - headless environment");
@@ -662,6 +758,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
         assertEquals(monthBounds11, ui.getMonthBounds(1, 1));
     }
 
+    @Test
     public void testMonthBoundsFromLogicalLToR() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run test - headless environment");
@@ -680,6 +777,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Sanity test: inexpected pass if the realized frame isn't visible.
      */
+    @Test
     public void testFirstMonthLocation() {
         if (GraphicsEnvironment.isHeadless()) {
             LOG.info("cannot run test - headless environment");
@@ -695,6 +793,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test day at location
      */
+    @Test
     public void testDayAtLocationLToR() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -720,6 +819,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test day at location
      */
+    @Test
     public void testDayAtLocationRToL() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -746,6 +846,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Test day at location: hitting days of week must return null.
      */
+    @Test
     public void testDayAtLocationDayHeaderNull() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -761,6 +862,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
         assertNull("hitting days-of-week must return null calendar", date);
      }
     
+    @Test
     public void testDayBounds() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -787,6 +889,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * days of week is mapped to row index -1.
      */
+    @Test
     public void testDayGridPositionColumnHeader() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -804,6 +907,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * day grid rows >= 0
      */
+    @Test
     public void testDayGridPositionRow() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -826,6 +930,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * Screen location mapped to logical day columns.
      */
+    @Test
     public void testDayGridPositionColumn() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -847,6 +952,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
         assertEquals("first logical column in LToR", 0, dayGridLToR.x);
      }
 
+    @Test
     public void testDayGridPositionWeekHeader() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -872,6 +978,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * day grid returns null for hitting month header.
      */
+    @Test
     public void testDayGridPositionMonthHeaderHitLToR() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -887,6 +994,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * day grid returns null for hitting month header.
      */
+    @Test
     public void testDayGridPositionMonthHeaderHitRToL() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -903,6 +1011,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * coordinate mapping: get calendar from logical grid 
      *   coordinates.
      */
+    @Test
     public void testMonthFromGrid() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -925,6 +1034,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * coordinate mapping: logical grid coordinates.
      */
+    @Test
     public void testMonthGridPositionAtLocation() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -945,6 +1055,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * coordinate mapping: monthBounds in pixel.
      * 
      */
+    @Test
     public void testMonthBoundsAtLocation() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -971,6 +1082,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * coordinate mapping: monthBounds in pixel.
      * 
      */
+    @Test
     public void testMonthHeaderBoundsAtLocation() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -1019,8 +1131,8 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     private BasicMonthViewUI getRealizedMonthViewUI(ComponentOrientation co,
             boolean isShowingWeekNumbers) {
         JXMonthView monthView = new JXMonthView();
-        monthView.setPreferredCols(2);
-        monthView.setPreferredRows(2);
+        monthView.setPreferredColumnCount(2);
+        monthView.setPreferredRowCount(2);
         monthView.setComponentOrientation(co);
         monthView.setShowingWeekNumber(isShowingWeekNumbers);
         Calendar calendar = monthView.getCalendar();
@@ -1040,6 +1152,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * replace getDayAt which is deprecated as a first step.
      */
     @SuppressWarnings("deprecation")
+    @Test
     public void testGetDayAtLocation() {
         // This test will not work in a headless configuration.
         if (GraphicsEnvironment.isHeadless()) {
@@ -1063,6 +1176,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * Issue 711-swingx: today notify-only property.
      * Changed to read-only in monthView
      */
+    @Test
     public void testTodayUpdate() {
         JXMonthView monthView = new JXMonthView();
         Date first = ((BasicMonthViewUI) monthView.getUI()).getToday();
@@ -1073,6 +1187,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * test localized month names.
      */
+    @Test
     public void testLocaleMonths() {
         Locale french = Locale.FRENCH;
         JXMonthView monthView = new JXMonthView(french);
@@ -1092,6 +1207,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
         }
     }
 
+    @Test
     public void testCustomWeekdays() {
         String[] days = new String[] {"1", "2", "3", "4", "5", "6", "7"};
         UIManager.put("JXMonthView.daysOfTheWeek", days);
@@ -1113,6 +1229,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
     /**
      * test localized weekday names.
      */
+    @Test
     public void testLocaleWeekdays() {
         Locale french = Locale.FRENCH;
         JXMonthView monthView = new JXMonthView(french);
@@ -1137,6 +1254,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * 
      * bad marker in ui-delegate ... but looks okay? 
      */
+    @Test
     public void testZeroFirstDisplayedDate() {
         JXMonthView monthView = new JXMonthView();
         Date first = monthView.getUI().getLastDisplayedDay();
@@ -1150,6 +1268,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * 
      * Here: test that lastDisplayedDate is unchanged.
      */
+    @Test
     public void testUpdateUILast() {
         final JXMonthView monthView = new JXMonthView();
         Date first = monthView.getUI().getLastDisplayedDay();
@@ -1162,6 +1281,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * 
      * Here: test that firstDisplayedDate is unchanged.
      */
+    @Test
     public void testUpdateUIFirstDate() {
         final JXMonthView monthView = new JXMonthView();
         Date first = ((BasicMonthViewUI) monthView.getUI()).getFirstDisplayedDay();
@@ -1174,6 +1294,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * 
      * Here: test that firstDisplayedYear is unchanged.
      */
+    @Test
     public void testUpdateUIFirstYear() {
         final JXMonthView monthView = new JXMonthView();
         long first = ((BasicMonthViewUI) monthView.getUI()).getFirstDisplayedYear();
@@ -1186,6 +1307,7 @@ public class BasicMonthViewUITest extends InteractiveTestCase {
      * 
      * Here: test that firstDisplayedMonth is unchanged.
      */
+    @Test
     public void testUpdateUIFirstMonth() {
         Calendar cal = Calendar.getInstance();
         cal.set(Calendar.MONTH, 5);
