@@ -1,5 +1,5 @@
 /*
- * $Id: HighlighterClientVisualCheck.java,v 1.23 2008/03/12 12:05:11 kleopatra Exp $
+ * $Id: HighlighterClientVisualCheck.java,v 1.29 2008/12/23 18:12:38 kschaefe Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -53,7 +53,6 @@ import org.jdesktop.swingx.JXList;
 import org.jdesktop.swingx.JXSearchPanel;
 import org.jdesktop.swingx.JXTable;
 import org.jdesktop.swingx.JXTreeTable;
-import org.jdesktop.swingx.RolloverProducer;
 import org.jdesktop.swingx.decorator.AbstractHighlighter;
 import org.jdesktop.swingx.decorator.BorderHighlighter;
 import org.jdesktop.swingx.decorator.ColorHighlighter;
@@ -67,6 +66,7 @@ import org.jdesktop.swingx.decorator.PatternPredicate;
 import org.jdesktop.swingx.decorator.ShadingColorHighlighter;
 import org.jdesktop.swingx.decorator.HighlightPredicate.ColumnHighlightPredicate;
 import org.jdesktop.swingx.renderer.PainterVisualCheck.ValueBasedGradientHighlighter;
+import org.jdesktop.swingx.rollover.RolloverProducer;
 import org.jdesktop.swingx.treetable.FileSystemModel;
 import org.jdesktop.test.AncientSwingTeam;
 
@@ -85,9 +85,9 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
 //      setSystemLF(true);
       HighlighterClientVisualCheck test = new HighlighterClientVisualCheck();
       try {
-//         test.runInteractiveTests();
+         test.runInteractiveTests();
 //         test.runInteractiveTests(".*Tool.*");
-         test.runInteractiveTests(".*JP.*");
+//         test.runInteractiveTests("interactive.*Search.*");
       } catch (Exception e) {
           System.err.println("exception when executing interactive tests:");
           e.printStackTrace();
@@ -128,12 +128,11 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
         
         Font font = table.getFont().deriveFont(Font.BOLD | Font.ITALIC);
         Highlighter simpleStriping = HighlighterFactory.createSimpleStriping();
-        Pattern pattern = Pattern.compile("^M", 0);
-        PatternPredicate patternPredicate = new PatternPredicate(pattern, 1);
+        PatternPredicate patternPredicate = new PatternPredicate("^M", 1);
         ColorHighlighter magenta = new ColorHighlighter(patternPredicate, null,
                 Color.MAGENTA, null, Color.MAGENTA);
-        FontHighlighter derivedFont = new FontHighlighter(font,
-                patternPredicate);
+        FontHighlighter derivedFont = new FontHighlighter(patternPredicate,
+                font);
         Highlighter gradient = new ValueBasedGradientHighlighter();
         Highlighter shading = new ShadingColorHighlighter(
                 new HighlightPredicate.ColumnHighlightPredicate(1));
@@ -160,12 +159,12 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
         source.toggleSortOrder(3);
         Font font = source.getFont().deriveFont(Font.BOLD | Font.ITALIC);
         Highlighter simpleStriping = HighlighterFactory.createSimpleStriping();
-        Pattern pattern = Pattern.compile("^M", 0);
+        String pattern = "^M";
         PatternPredicate patternPredicate = new PatternPredicate(pattern, 0);
         ColorHighlighter magenta = new ColorHighlighter(patternPredicate, null,
                 Color.MAGENTA, null, Color.MAGENTA);
-        FontHighlighter derivedFont = new FontHighlighter(font,
-                patternPredicate);
+        FontHighlighter derivedFont = new FontHighlighter(patternPredicate,
+                font);
         Highlighter gradient = new ValueBasedGradientHighlighter(true);
         Highlighter shading = new ShadingColorHighlighter(
                 new HighlightPredicate.ColumnHighlightPredicate(0));
@@ -188,7 +187,7 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
         // number
         JXList listn = new JXList(createListModel(source, 3));
         listn.setCellRenderer(new DefaultListRenderer(
-                FormatStringValue.NUMBER_TO_STRING, JLabel.RIGHT));
+                StringValues.NUMBER_TO_STRING, JLabel.RIGHT));
         listn.setHighlighters(simpleStriping, gradient);
         lists.add(listn);
 
@@ -232,7 +231,7 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
     public static class FontHighlighter extends AbstractHighlighter {
         
         private Font font;
-        public FontHighlighter(Font font, HighlightPredicate predicate) {
+        public FontHighlighter(HighlightPredicate predicate, Font font) {
             super(predicate);
             this.font = font;
         }
@@ -367,6 +366,7 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
             }
         }
         table.resetSortOrder();
+        // PENDING JW: add and use HighlightPredicate.SELECTED/UN_SELECTED 
         Highlighter hl = new ColorHighlighter() {
 
             @Override
@@ -389,7 +389,7 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
      */
     public void interactiveSearchPanel() {
         JXTable table = new JXTable(tableModel);
-        final ColorHighlighter cl = new ColorHighlighter(new PatternPredicate(null, 0), null,
+        final ColorHighlighter cl = new ColorHighlighter(new PatternPredicate((Pattern) null, 0), null,
                 Color.RED);
         table.addHighlighter(cl);
         JXSearchPanel searchPanel = new JXSearchPanel();
@@ -432,25 +432,7 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
                 break;
             }
         }
-        // PENDING JW: replace by ShadingColorHighlighter?
-        ColorHighlighter shader = new ColorHighlighter(new ColumnHighlightPredicate(hierarchicalColumn), Color.WHITE,
-                null) {
-
-            @Override
-            protected void applyBackground(Component renderer,
-                    ComponentAdapter adapter) {
-                if (adapter.isSelected() || getBackground() == null) return;
-                renderer.setBackground(computeBackgroundSeed(getBackground()));
-            }
-            
-            protected Color computeBackgroundSeed(Color seed) {
-                return new Color(Math.max((int)(seed.getRed()  * 0.95), 0),
-                                 Math.max((int)(seed.getGreen()* 0.95), 0),
-                                 Math.max((int)(seed.getBlue() * 0.95), 0));
-            }
-
-        };
-        treeTable.addHighlighter(shader);
+        treeTable.addHighlighter(new ShadingColorHighlighter(new ColumnHighlightPredicate(hierarchicalColumn)));
         showWithScrollingInFrame(treeTable, "hierarchical column");
         
     }
@@ -504,8 +486,7 @@ public class HighlighterClientVisualCheck extends InteractiveTestCase {
     public void interactiveTablePatternHighlighter() {
         JXTable table = new JXTable(tableModel);
         table.setColumnControlVisible(true);
-        Pattern pattern = Pattern.compile("^M", 0);
-        table.addHighlighter(new ColorHighlighter(new PatternPredicate(pattern, 1), null, 
+        table.addHighlighter(new ColorHighlighter(new PatternPredicate("^M", 1), null, 
                 Color.red));
         showWithScrollingInFrame(table, "Pattern: highlight row if ^M col 1");
     }
