@@ -1,5 +1,5 @@
 /*
- * $Id: PainterVisualCheck.java,v 1.32 2008/04/25 10:44:22 kleopatra Exp $
+ * $Id: PainterVisualCheck.java,v 1.37 2008/08/26 09:35:43 kleopatra Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -25,15 +25,19 @@ import java.awt.Color;
 import java.awt.Component;
 import java.awt.GradientPaint;
 import java.awt.Graphics2D;
+import java.awt.Image;
 import java.awt.Polygon;
+import java.awt.Rectangle;
 import java.awt.Shape;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.awt.geom.Point2D;
+import java.awt.image.BufferedImage;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
+import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -44,15 +48,18 @@ import javax.swing.DefaultListModel;
 import javax.swing.JCheckBox;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
+import javax.swing.JTable;
 import javax.swing.KeyStroke;
 import javax.swing.ListModel;
 import javax.swing.Timer;
 import javax.swing.table.TableModel;
+import javax.swing.tree.TreeModel;
 
 import org.jdesktop.swingx.InteractiveTestCase;
 import org.jdesktop.swingx.JXFrame;
 import org.jdesktop.swingx.JXList;
 import org.jdesktop.swingx.JXTable;
+import org.jdesktop.swingx.JXTree;
 import org.jdesktop.swingx.action.AbstractActionExt;
 import org.jdesktop.swingx.action.ActionContainerFactory;
 import org.jdesktop.swingx.decorator.ComponentAdapter;
@@ -61,7 +68,10 @@ import org.jdesktop.swingx.decorator.Highlighter;
 import org.jdesktop.swingx.decorator.HighlighterFactory;
 import org.jdesktop.swingx.decorator.PainterHighlighter;
 import org.jdesktop.swingx.decorator.HighlightPredicate.ColumnHighlightPredicate;
+import org.jdesktop.swingx.decorator.HighlightPredicate.NotHighlightPredicate;
 import org.jdesktop.swingx.painter.AbstractLayoutPainter;
+import org.jdesktop.swingx.painter.AbstractPainter;
+import org.jdesktop.swingx.painter.BusyPainter;
 import org.jdesktop.swingx.painter.ImagePainter;
 import org.jdesktop.swingx.painter.MattePainter;
 import org.jdesktop.swingx.painter.Painter;
@@ -71,6 +81,7 @@ import org.jdesktop.swingx.painter.AbstractLayoutPainter.VerticalAlignment;
 import org.jdesktop.swingx.painter.effects.InnerGlowPathEffect;
 import org.jdesktop.swingx.table.ColumnControlButton;
 import org.jdesktop.swingx.test.XTestUtils;
+import org.jdesktop.swingx.treetable.FileSystemModel;
 import org.jdesktop.test.AncientSwingTeam;
 
 /**
@@ -95,6 +106,7 @@ public class PainterVisualCheck extends InteractiveTestCase {
         test.runInteractiveTests();
 //         test.runInteractiveTests("interactive.*Gradient.*");
 //         test.runInteractiveTests("interactive.*Icon.*");
+//        test.runInteractiveTests("interactive.*Animated.*");
       } catch (Exception e) {
           System.err.println("exception when executing interactive tests:");
           e.printStackTrace();
@@ -164,11 +176,12 @@ public class PainterVisualCheck extends InteractiveTestCase {
         MattePainter<JComponent> p =  new MattePainter<JComponent>(getTransparentColor(Color.BLUE, 125));
         RelativePainter relativePainter = new RelativePainter<JComponent>(p);
         relativePainter.setXFactor(.5);
-        Highlighter hl = new PainterHighlighter(createComponentTextBasedPredicate("y"), relativePainter);
+        Highlighter hl = new PainterHighlighter(createComponentTextBasedPredicate("y"), 
+                relativePainter);
         table.addHighlighter(hl);
         JXFrame frame = wrapWithScrollingInFrame(table, 
                 "painter-aware renderer with value-based highlighting");
-        addStatusComponent(frame, new JLabel("gradient background of cells with value's containing 'y'"));
+        addMessage(frame, "bar in cells with value containing y");
         show(frame);
     }
    
@@ -303,6 +316,8 @@ public class PainterVisualCheck extends InteractiveTestCase {
                 "value-based image position highlighting");
     }
 
+    
+    
     /**
      * Use highlighter with image painter which is positioned relative to 
      * cell value. 
@@ -331,6 +346,183 @@ public class PainterVisualCheck extends InteractiveTestCase {
         timer.start();
     }
     
+    /**
+     * Use highlighter with BusyPainter.
+     */
+    public void interactiveAnimatedBusyPainterHighlight()  {
+        TableModel model = new AncientSwingTeam();
+        JXTable table = new JXTable(model);
+        table.getColumn(0).setCellRenderer(new DefaultTableRenderer(
+                new HyperlinkProvider()));
+        final BusyPainter busyPainter = new BusyPainter() {
+            /**
+             * Overridden to fix Issue #861-swingx: must notify on change
+             * @param frame
+             */
+            @Override
+            public void setFrame(int frame) {
+                int old = getFrame();
+                super.setFrame(frame);
+                firePropertyChange("frame", old, getFrame());
+            }
+            
+        };
+        // JW: how do we ask for the height of the painter?
+        table.setRowHeight(26);
+        PainterHighlighter iconHighlighter = new PainterHighlighter();
+        iconHighlighter.setHighlightPredicate(HighlightPredicate.ROLLOVER_ROW);
+        iconHighlighter.setPainter(busyPainter);
+        ActionListener l = new ActionListener() {
+            public void actionPerformed(ActionEvent e) {
+                int frame = busyPainter.getFrame();
+                frame = (frame+1)%busyPainter.getPoints();
+                busyPainter.setFrame(frame);
+            }
+            
+        };
+        table.addHighlighter(iconHighlighter);
+        showWithScrollingInFrame(table, 
+                "Animated highlighter: BusyPainter on Rollover");
+        Timer timer = new Timer(100, l);
+        timer.start();
+    }
+    
+    /**
+     * Issue #862-swingx: SwingX rendering components should be PainterAware.
+     * 
+     * Currently this works only with a local version which has WrappingIconPanel
+     * implement the PainterAware by delegating to its content delegate. 
+     */
+    public void interactiveAnimatedIconPainterHighlightTree()  {
+        TreeModel model = new FileSystemModel();
+        JXTree tree = new JXTree(model);
+        tree.setRolloverEnabled(true);
+        
+        tree.setCellRenderer(new DefaultTreeRenderer(StringValues.FILE_NAME));
+        ImagePainter<Component> imagePainter = new ImagePainter<Component>(XTestUtils.loadDefaultImage("green-orb.png"));
+        imagePainter.setHorizontalAlignment(HorizontalAlignment.RIGHT);
+        final RelativePainter painter = new RelativePainter<Component>(imagePainter);
+        PainterHighlighter iconHighlighter = new PainterHighlighter();
+        iconHighlighter.setHighlightPredicate(HighlightPredicate.ROLLOVER_ROW);
+        iconHighlighter.setPainter(painter);
+        ActionListener l = new ActionListener() {
+            public void actionPerformed(ActionEvent e) {
+                double fraction = painter.getXFactor();
+                fraction = fraction > 1 ? 0.0 : fraction + 0.1;
+                painter.setXFactor(fraction);
+            }
+            
+        };
+        tree.addHighlighter(iconHighlighter);
+        showWithScrollingInFrame(tree, 
+                "Animated highlighter: marching icon on rollover");
+        Timer timer = new Timer(100, l);
+        timer.start();
+    }
+
+    
+    /**
+     * Use custom painter and highlighter for per-row image decoration.
+     * 
+     * @throws IOException
+     */
+    public void interactivePerRowImage() throws IOException {
+        
+        JXTable table = new JXTable(new AncientSwingTeam());
+        table.setForeground(Color.MAGENTA);
+        table.setSelectionForeground(Color.BLUE);
+        table.setColumnControlVisible(true);
+        table.setRowHeight(25);
+        final BufferedImage moon = XTestUtils.loadDefaultImage("moon.jpg");
+        final BufferedImage rocket = XTestUtils.loadDefaultImage("500by500.png");
+        HighlightPredicate rocketPredicate = new HighlightPredicate() {
+
+            public boolean isHighlighted(Component renderer,
+                    ComponentAdapter adapter) {
+                return ((Integer) adapter.getValue(3)).intValue() < 50;
+            }
+            
+        };
+        HighlightPredicate moonPredicate = new NotHighlightPredicate(rocketPredicate);
+        table.setHighlighters(
+                new SubImagePainterHighlighter(rocketPredicate, 
+                        new SubImagePainter(rocket))
+                ,
+                new SubImagePainterHighlighter(moonPredicate, 
+                        new SubImagePainter(moon))
+        );
+        JXFrame frame = wrapWithScrollingInFrame(table, "painter in renderer");
+        show(frame);
+    }
+    
+    /**
+     * Custom PainterHighlighter configures a SubImagePainter.
+     * 
+     */
+    public static class SubImagePainterHighlighter extends PainterHighlighter {
+
+        
+        public SubImagePainterHighlighter(HighlightPredicate predicate, SubImagePainter painter) {
+            super(predicate, painter);
+        }
+        
+        @Override
+        protected Component doHighlight(Component component,
+                ComponentAdapter adapter) {
+            Rectangle cellRect = getCellBounds(adapter);
+            ((SubImagePainter) getPainter()).setImageClip(cellRect);
+            return super.doHighlight(component, adapter);
+        }
+        
+        private Rectangle getCellBounds(ComponentAdapter adapter) {
+            // PENDING JW: add method to adapter
+            JXTable table = (JXTable) adapter.getComponent();
+            Rectangle cellRect = table.getCellRect(adapter.row, 
+                    adapter.column, false);
+            return cellRect;
+        }
+
+        @Override
+        protected boolean canHighlight(Component component,
+                ComponentAdapter adapter) {
+            return super.canHighlight(component, adapter) 
+                && (adapter.getComponent() instanceof JTable);
+        }
+
+        
+    }
+    
+    /**
+     * Simple Painter for subimage.
+     */
+    public static class SubImagePainter extends AbstractPainter {
+        BufferedImage image;
+        Rectangle imageClip;
+
+        public SubImagePainter(BufferedImage image) {
+            super(false);
+            this.image = image;
+        }
+        
+        public void setImageClip(Rectangle imageClip) {
+            this.imageClip = imageClip;
+        }
+        
+        @Override
+        protected void doPaint(Graphics2D g, Object object, int width,
+                int height) {
+            if ((imageClip == null) || (imageClip.width <= 0) || (imageClip.height <= 0)) return;
+            if (imageClip.x + width >= image.getWidth()) return;
+            if (imageClip.y + height >= image.getWidth()) return;
+            Image subImage = image.getSubimage(
+                    imageClip.x, imageClip.y, 
+                    width, height);
+            g.drawImage(subImage, 0, 0, width, height, null);
+            
+        }
+        
+    }
+    
 
     //  ----------------- Transparent gradient on default (swingx) rendering label
 
@@ -504,20 +696,27 @@ public class PainterVisualCheck extends InteractiveTestCase {
         }
 
         @Override
-        protected Component doHighlight(Component renderer, ComponentAdapter adapter) {
-            if (adapter.getValue() instanceof Number) {
-                float end = getEndOfGradient((Number) adapter.getValue());
-                if (end > 1) {
-                    renderer.setBackground(Color.RED.darker());
-                    renderer.setForeground(Color.WHITE);
-                } else if (end > 0.02) {
-                    Painter painter = getPainter(end);
-                    ((PainterAware) renderer).setPainter(painter);
-                }
-            }            
+        protected Component doHighlight(Component renderer,
+                ComponentAdapter adapter) {
+            float end = getEndOfGradient((Number) adapter.getValue());
+            if (end > 1) {
+                renderer.setBackground(Color.RED.darker());
+                renderer.setForeground(Color.WHITE);
+            } else if (end > 0.02) {
+                Painter painter = getPainter(end);
+                ((PainterAware) renderer).setPainter(painter);
+            }
             return renderer;
         }
 
+        
+        @Override
+        protected boolean canHighlight(Component component,
+                ComponentAdapter adapter) {
+            return (adapter.getValue() instanceof Number) && 
+                super.canHighlight(component, adapter);
+        }
+
         /**
          * @param yellowTransparent
          */
@@ -547,7 +746,7 @@ public class PainterVisualCheck extends InteractiveTestCase {
                         isRightAligned ? endColor : startColor, 
                         new Point2D.Double(100, 0), 
                         isRightAligned ? startColor : endColor);
-                MattePainter painter = new MattePainter<JComponent>(paint);
+                MattePainter<JComponent> painter = new MattePainter<JComponent>(paint);
                 painter.setPaintStretched(true);
                 getPainter().setPainter(painter);
             } 
@@ -605,20 +804,26 @@ public class PainterVisualCheck extends InteractiveTestCase {
         }
         
         @Override
-        protected Component doHighlight(Component renderer, ComponentAdapter adapter) {
-            if (adapter.getValue() instanceof Number) {
-                float end = getEndOfGradient((Number) adapter.getValue());
-                if (end > 1) {
-                    renderer.setBackground(Color.RED.darker());
-                    renderer.setForeground(Color.WHITE);
-                } else if (end > 0.02) {
-                    Painter painter = getPainter(end);
-                    ((PainterAware) renderer).setPainter(painter);
-                }
-            }            
+        protected Component doHighlight(Component renderer,
+                ComponentAdapter adapter) {
+            float end = getEndOfGradient((Number) adapter.getValue());
+            if (end > 1) {
+                renderer.setBackground(Color.RED.darker());
+                renderer.setForeground(Color.WHITE);
+            } else if (end > 0.02) {
+                Painter painter = getPainter(end);
+                ((PainterAware) renderer).setPainter(painter);
+            }
             return renderer;
         }
 
+        @Override
+        protected boolean canHighlight(Component component,
+                ComponentAdapter adapter) {
+            return (adapter.getValue() instanceof Number) && 
+                super.canHighlight(component, adapter);
+        }
+
         public void setHorizontalAlignment(HorizontalAlignment align) {
             getPainter().setHorizontalAlignment(align);
             fireStateChanged();
