@@ -1,5 +1,5 @@
 /*
- * $Id: RendererIssues.java,v 1.17 2008/04/25 07:47:14 kleopatra Exp $
+ * $Id: RendererIssues.java,v 1.30 2008/12/23 18:12:37 kschaefe Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -26,17 +26,28 @@ import java.awt.Component;
 import java.awt.Font;
 import java.awt.Point;
 import java.awt.Rectangle;
+import java.awt.event.ActionEvent;
 import java.awt.event.MouseEvent;
+import java.io.File;
+import java.util.Calendar;
+import java.util.Date;
 import java.util.logging.Logger;
 
+import javax.swing.AbstractAction;
 import javax.swing.AbstractButton;
 import javax.swing.AbstractListModel;
+import javax.swing.Action;
 import javax.swing.BorderFactory;
+import javax.swing.Box;
 import javax.swing.DefaultListCellRenderer;
 import javax.swing.Icon;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JList;
+import javax.swing.JRadioButton;
+import javax.swing.JTextField;
 import javax.swing.JTree;
 import javax.swing.ListCellRenderer;
 import javax.swing.ListModel;
@@ -46,6 +57,7 @@ import javax.swing.ToolTipManager;
 import javax.swing.UIManager;
 import javax.swing.UnsupportedLookAndFeelException;
 import javax.swing.border.Border;
+import javax.swing.filechooser.FileSystemView;
 import javax.swing.plaf.basic.BasicTreeUI;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.tree.TreeCellRenderer;
@@ -59,15 +71,22 @@ import org.jdesktop.swingx.JXPanel;
 import org.jdesktop.swingx.JXTable;
 import org.jdesktop.swingx.JXTree;
 import org.jdesktop.swingx.JXTreeTable;
-import org.jdesktop.swingx.RolloverProducer;
-import org.jdesktop.swingx.RolloverRenderer;
 import org.jdesktop.swingx.border.DropShadowBorder;
+import org.jdesktop.swingx.color.ColorUtil;
+import org.jdesktop.swingx.decorator.ColorHighlighter;
+import org.jdesktop.swingx.decorator.ComponentAdapter;
 import org.jdesktop.swingx.decorator.HighlightPredicate;
 import org.jdesktop.swingx.decorator.Highlighter;
 import org.jdesktop.swingx.decorator.PainterHighlighter;
+import org.jdesktop.swingx.decorator.PatternPredicate;
 import org.jdesktop.swingx.painter.MattePainter;
+import org.jdesktop.swingx.rollover.RolloverProducer;
+import org.jdesktop.swingx.rollover.RolloverRenderer;
 import org.jdesktop.swingx.test.ComponentTreeTableModel;
 import org.jdesktop.swingx.test.XTestUtils;
+import org.jdesktop.swingx.treetable.FileSystemModel;
+import org.jdesktop.swingx.treetable.TreeTableModel;
+import org.jdesktop.test.AncientSwingTeam;
 
 import com.sun.java.swing.plaf.motif.MotifLookAndFeel;
 
@@ -88,17 +107,259 @@ public class RendererIssues extends InteractiveTestCase {
         setSystemLF(true);
         RendererIssues test = new RendererIssues();
         try {
-            test.runInteractiveTests();
-//          test.runInteractiveTests(".*Text.*");
+//            test.runInteractiveTests();
+          test.runInteractiveTests("interactive.*Alpha.*");
 //          test.runInteractiveTests(".*XLabel.*");
 //          test.runInteractiveTests(".*Color.*");
 //          test.runInteractiveTests("interactive.*ColumnControl.*");
+//          test.runInteractiveTests("interactive.*Hyperlink.*");
         } catch (Exception e) {
             System.err.println("exception when executing interactive tests:");
             e.printStackTrace();
         }
     }
 
+    
+    /**
+     * Issue ??-swingx: Boolean renderer background is slightly darker if 
+     * background color is part-transparent.
+     * 
+     * Not only checkbox as renderer - there seem to be subtle differences 
+     * when painting buttons, labels, ... plus it's laf dependent.
+     * 
+     */
+    public void interactiveAlphaBackground() {
+        Color color = ColorUtil.setAlpha(Color.ORANGE, 60);
+        
+        JCheckBox check = new JCheckBox("what's my color?");
+//        check.setOpaque(true);
+//        check.setContentAreaFilled(true);
+        check.setBackground(color);
+        JLabel label = new JLabel("and mine?");
+        label.setOpaque(true);
+        label.setBackground(color );
+        JButton button = new JButton("the new kid on the block");
+        button.setBackground(color);
+        
+        JRadioButton radio = new JRadioButton("radio, raadio ..");
+        radio.setBackground(color);
+        
+        JTextField field = new JTextField(40);
+        field.setBackground(color);
+        JComponent box = Box.createVerticalBox();
+        box.setOpaque(true);
+        box.setBackground(Color.WHITE);
+        box.add(check);
+        box.add(radio);
+        box.add(label);
+        box.add(button);
+        box.add(field);
+        JXFrame frame = wrapInFrame(box, "alpha in plain ..", true);
+        show(frame, 400, 200);
+        
+    }
+
+    /**
+     * Issue ??-swingx: Boolean renderer background is slightly darker if 
+     * background color is part-transparent.
+     * 
+     */
+    public void interactiveCheckBoxAlpha() {
+        JXTable table = new JXTable(new org.jdesktop.test.AncientSwingTeam());
+        table.addHighlighter(new RowHighlighter(new HighlightPredicate() {
+            public boolean isHighlighted(Component renderer, ComponentAdapter adapter) {
+                return ((Boolean) adapter.getValue(4)).booleanValue();
+            }
+        }));
+        showWithScrollingInFrame(table, "boolean renderer and alpha background");
+        
+    }
+
+    static class RowHighlighter extends ColorHighlighter {
+        Font BOLD_FONT;
+
+        RowHighlighter(HighlightPredicate predicate) {
+            super(predicate, ColorUtil.setAlpha(Color.ORANGE, 60), Color.RED);
+            setSelectedForeground(getForeground());
+        }
+
+        @Override
+        protected Component doHighlight(Component renderer, ComponentAdapter adapter) {
+            if (BOLD_FONT == null) {
+                BOLD_FONT = renderer.getFont().deriveFont(Font.BOLD);
+            }
+            renderer.setFont(BOLD_FONT);
+            return super.doHighlight(renderer, adapter);
+        }
+    }
+
+    
+    /**
+     * example to configure treeTable hierarchical column with
+     * custom icon and content mapping. The nodes are actually of type File.
+     * 
+     * Problem: 
+     * painting on resizing tree column sluggish, especially if the PatternHighlighter
+     * is on. Reason seems to be the FileSystemView - prepare time increases with
+     * number of accesses.
+     */
+    public void interactiveTreeTableCustomIconsPerformance() {
+        // modify the file model to return the file itself for the hierarchical column
+        TreeTableModel model = new FileSystemModel() {
+            
+            @Override
+            public Object getValueAt(Object node, int column) {
+                if (column == 0) {
+                    return node;
+                }
+                return super.getValueAt(node, column);
+            }
+            
+        };
+        final JXTreeTable table = new JXTreeTable(model);
+        table.setAutoResizeMode(JXTable.AUTO_RESIZE_OFF);
+        StringValue sv = new StringValue() {
+
+            public String getString(Object value) {
+                if (value instanceof File) {
+                    return FileSystemView.getFileSystemView().getSystemDisplayName((File) value)
+                       + " Type: " 
+                       + FileSystemView.getFileSystemView().getSystemTypeDescription((File) value)
+                    ; 
+                } 
+                return StringValues.TO_STRING.getString(value);
+            }
+            
+        };
+        IconValue iv = new IconValue() {
+
+            public Icon getIcon(Object value) {
+                if (value instanceof File) {
+                    return  FileSystemView.getFileSystemView().getSystemIcon((File) value);
+                } 
+                return null;
+            }};
+        final DefaultTreeRenderer treeRenderer = new DefaultTreeRenderer(iv, sv);
+        table.setTreeCellRenderer(treeRenderer);
+        // string based. Note: this example is locale dependent
+        String folderDescription = ".*ordner.*";
+        PatternPredicate predicate = new PatternPredicate(folderDescription, 0, -1);
+        final Highlighter hl = new ColorHighlighter(predicate, null, Color.RED);
+        Calendar calendar = Calendar.getInstance();
+        calendar.add(Calendar.YEAR, -1);
+        final Date lastYear = calendar.getTime();
+        // install value based highlighter 
+        HighlightPredicate valueBased = new HighlightPredicate() {
+
+            public boolean isHighlighted(Component renderer,
+                    ComponentAdapter adapter) {
+                if (!(adapter.getValue() instanceof File)) return false;
+                File file = (File) adapter.getValue();
+                Date date = new Date(file.lastModified());
+                return date.after(lastYear);
+            }
+            
+        };
+        final ColorHighlighter back =  new ColorHighlighter(valueBased, Color.YELLOW, null);
+        JXFrame frame =showWithScrollingInFrame(table, "TreeTable: performance bottleneck is FileSystemView");
+        Action toggleBack = new AbstractAction("toggleBackHighlighter") {
+            boolean hasBack;
+            public void actionPerformed(ActionEvent e) {
+                if (hasBack) {
+                    table.removeHighlighter(back);
+                } else {
+                    table.addHighlighter(back);
+                }
+                hasBack = !hasBack;
+                
+            }
+            
+        };
+        addAction(frame, toggleBack);
+        Action togglePattern = new AbstractAction("togglePatternHighlighter") {
+            boolean hasBack;
+            public void actionPerformed(ActionEvent e) {
+                if (hasBack) {
+                    table.removeHighlighter(hl);
+                } else {
+                    table.addHighlighter(hl);
+                }
+                hasBack = !hasBack;
+                
+            }
+            
+        };
+        addAction(frame, togglePattern);
+        // accessing the FileSystemView is slooooww
+        // increasingly costly over time, shows particularly 
+        // when the patternHighlighter is on
+        // (probably because that increases the number 
+        // of queries to the systemView
+        final JLabel timeL = new JLabel("stop-watch");
+        Action timer = new AbstractAction("start") {
+            public void actionPerformed(ActionEvent e) {
+                timeL.setText("started");
+                long time = System.currentTimeMillis();
+                for (int i = 0; i < 2000; i++) {
+                   table.prepareRenderer(table.getCellRenderer(0, 0), 0, 0); 
+                }
+                timeL.setText("stopped: " + (System.currentTimeMillis() - time));
+            }
+        };
+        addAction(frame, timer);
+        
+        addStatusComponent(frame, timeL);
+        addStatusMessage(frame, "node is File - string/value based highlighters same");
+    }
+
+
+    /**
+     * Playing with rollover for visual clue if cell editable.
+     * The old problem: cursor shoudn't be altered by the rollover
+     * controller but by the rollover renderer.
+     */
+    public void interactiveRolloverEffects() {
+        JXTable table = new JXTable(new AncientSwingTeam());
+        table.setDefaultRenderer(Boolean.class, new DefaultTableRenderer(new RolloverCheckBox()));
+        showWithScrollingInFrame(table, "checkbox rollover effect");
+    }
+    
+    public static class RolloverCheckBox extends CheckBoxProvider 
+        implements RolloverRenderer {
+        boolean wasEditable;
+
+        
+        @Override
+        protected void configureState(CellContext context) {
+            super.configureState(context);
+            if (context.getComponent() !=  null) {
+                Point p = (Point) context.getComponent()
+                        .getClientProperty(RolloverProducer.ROLLOVER_KEY);
+                if (/*hasFocus || */(p != null && (p.x >= 0) && 
+                        (p.x == context.getColumn()) && (p.y == context.getRow()))) {
+                     rendererComponent.getModel().setRollover(true);
+                } else {
+                    rendererComponent.getModel().setRollover(false);
+                }
+            }
+        }
+
+        @Override
+        protected void format(CellContext context) {
+            // TODO Auto-generated method stub
+            super.format(context);
+            wasEditable = context.isEditable();
+        }
+
+        public void doClick() {
+        }
+
+        public boolean isEnabled() {
+            return wasEditable;
+        }
+        
+    }
+    
     public void interactiveToolTipList() {
         final JXTree table = new JXTree(new ComponentTreeTableModel(new JXFrame()));
         table.expandAll();
@@ -138,6 +399,9 @@ public class RendererIssues extends InteractiveTestCase {
                 int row = locationToIndex(event.getPoint());
                 Rectangle r = getCellBounds(row, row);
                 if (r != null) {
+                    if (!getComponentOrientation().isLeftToRight()) {
+                        r.translate(r.width, 0);
+                    }
                     return r.getLocation();
                 }
                 return super.getToolTipLocation(event);
@@ -147,10 +411,11 @@ public class RendererIssues extends InteractiveTestCase {
             
         };
         JXFrame frame = wrapWithScrollingInFrame(list, "list tooltip");
+        addComponentOrientationToggle(frame);
         show(frame, 300, 300);
     }
     
-    public void interactiveToolTip() {
+    public void interactiveToolTipTable() {
         JXTreeTable treeTable = new JXTreeTable(new ComponentTreeTableModel(new JXFrame()));
         treeTable.expandAll();
         JXTable table = new JXTable(treeTable.getModel()) {
@@ -237,6 +502,7 @@ public class RendererIssues extends InteractiveTestCase {
         ToolTipManager toolTipManager = ToolTipManager.sharedInstance();
         toolTipManager.registerComponent(tree);
         JXFrame frame = showWithScrollingInFrame(tree, "tooltip");
+        addComponentOrientationToggle(frame);
         show(frame, 400, 400);
     }
 
@@ -250,7 +516,7 @@ public class RendererIssues extends InteractiveTestCase {
         MattePainter painter = new MattePainter(Color.YELLOW);
         Highlighter hl = new PainterHighlighter(HighlightPredicate.ROLLOVER_ROW, painter);
         tree.addHighlighter(hl);
-        ComponentProvider provider = new NormalButtonProvider(StringValue.TO_STRING, JLabel.LEADING);
+        ComponentProvider provider = new NormalButtonProvider(StringValues.TO_STRING, JLabel.LEADING);
         tree.setCellRenderer(new DefaultTreeRenderer(provider));
         tree.setRolloverEnabled(true);
         showWithScrollingInFrame(tree, "Fancy..");
@@ -320,7 +586,8 @@ public class RendererIssues extends InteractiveTestCase {
     }
 
 //--------------- unit tests
- 
+
+    
     /**
      * Issue #794-swingx: tooltip must be reset.
      * 
@@ -360,6 +627,7 @@ public class RendererIssues extends InteractiveTestCase {
        WrappingProvider provider = new WrappingProvider(iv);
        WrappingIconPanel comp = provider.getRendererComponent(context);
        assertEquals(custom, comp.getIcon());
+       fail("feature request: per node type iconValue");
     }
 
     /**
