@@ -1,5 +1,5 @@
 /*
- * $Id: RendererVisualCheck.java,v 1.49 2008/04/17 11:57:10 kleopatra Exp $
+ * $Id: RendererVisualCheck.java,v 1.56 2008/12/23 18:12:37 kschaefe Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -46,7 +46,6 @@ import java.util.Calendar;
 import java.util.Collections;
 import java.util.Date;
 import java.util.List;
-import java.util.regex.Pattern;
 
 import javax.swing.AbstractAction;
 import javax.swing.AbstractListModel;
@@ -80,7 +79,6 @@ import javax.swing.tree.DefaultTreeModel;
 import javax.swing.tree.TreeCellRenderer;
 import javax.swing.tree.TreeModel;
 
-import org.jdesktop.swingx.EditorPaneLinkVisitor;
 import org.jdesktop.swingx.InteractiveTestCase;
 import org.jdesktop.swingx.JXEditorPaneTest;
 import org.jdesktop.swingx.JXFrame;
@@ -90,10 +88,7 @@ import org.jdesktop.swingx.JXList;
 import org.jdesktop.swingx.JXTable;
 import org.jdesktop.swingx.JXTree;
 import org.jdesktop.swingx.JXTreeTable;
-import org.jdesktop.swingx.LinkModel;
-import org.jdesktop.swingx.LinkRenderer;
 import org.jdesktop.swingx.action.AbstractActionExt;
-import org.jdesktop.swingx.action.LinkModelAction;
 import org.jdesktop.swingx.decorator.AbstractHighlighter;
 import org.jdesktop.swingx.decorator.BorderHighlighter;
 import org.jdesktop.swingx.decorator.ColorHighlighter;
@@ -101,7 +96,12 @@ import org.jdesktop.swingx.decorator.ComponentAdapter;
 import org.jdesktop.swingx.decorator.HighlightPredicate;
 import org.jdesktop.swingx.decorator.Highlighter;
 import org.jdesktop.swingx.decorator.HighlighterFactory;
+import org.jdesktop.swingx.decorator.PainterHighlighter;
 import org.jdesktop.swingx.decorator.PatternPredicate;
+import org.jdesktop.swingx.hyperlink.EditorPaneLinkVisitor;
+import org.jdesktop.swingx.hyperlink.LinkModel;
+import org.jdesktop.swingx.hyperlink.LinkModelAction;
+import org.jdesktop.swingx.painter.BusyPainter;
 import org.jdesktop.swingx.table.ColumnControlButton;
 import org.jdesktop.swingx.test.ComponentTreeTableModel;
 import org.jdesktop.swingx.test.XTestUtils;
@@ -130,7 +130,21 @@ public class RendererVisualCheck extends InteractiveTestCase {
             e.printStackTrace();
         }
     }
+
     
+    /**
+     * Issue #897-swingx: Opacity issues of JRendererCheckBox - striping lost.
+     * 
+     *  Reported against Nimbus, but similar in other LAFs if combined
+     *  with Painter.
+     */
+    public void interactiveCheckBoxRenderer() {
+        JXTable table = new JXTable(new AncientSwingTeam());
+        table.addHighlighter(HighlighterFactory.createSimpleStriping());
+        table.addHighlighter(new PainterHighlighter(HighlightPredicate.ROLLOVER_ROW, new BusyPainter()));
+        showWithScrollingInFrame(table, "Checkbox: striping lost on rollover");
+    }
+
     /**
      * List/tree filled with TreeNodes wrapping a File.
      * 
@@ -147,18 +161,11 @@ public class RendererVisualCheck extends InteractiveTestCase {
                        + " Type: " 
                        + FileSystemView.getFileSystemView().getSystemTypeDescription((File) value); 
                 } 
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
-        IconValue iv = new IconValue() {
-
-            public Icon getIcon(Object value) {
-                if (value instanceof File) {
-                    return  FileSystemView.getFileSystemView().getSystemIcon((File) value);
-                } 
-                return null;
-            }};
+        IconValue iv = IconValues.FILE_ICON;
         table.setCellRenderer(new DefaultListRenderer(new MappedValue(sv, iv)));
         final JXTree tree = new JXTree(createFileNodeModel());
         final DefaultTreeRenderer treeRenderer = new DefaultTreeRenderer(iv, sv);
@@ -166,7 +173,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
         tree.setCellRenderer(treeRenderer);
         // string based. Note: this example is locale dependent
         String folderDescription = ".*ordner.*";
-        PatternPredicate predicate = new PatternPredicate(Pattern.compile(folderDescription, 0), 0, -1);
+        PatternPredicate predicate = new PatternPredicate(folderDescription, 0, -1);
         Highlighter hl = new ColorHighlighter(predicate, null, Color.RED);
         table.addHighlighter(hl);
         tree.addHighlighter(hl);
@@ -309,7 +316,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
                        + FileSystemView.getFileSystemView().getSystemTypeDescription((File) value)
                     ; 
                 } 
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -325,9 +332,12 @@ public class RendererVisualCheck extends InteractiveTestCase {
         table.setTreeCellRenderer(treeRenderer);
         final JXTree tree = new JXTree(model);
         tree.setCellRenderer(treeRenderer);
+        tree.setRolloverEnabled(true);
+        tree.addHighlighter(new BorderHighlighter(HighlightPredicate.ROLLOVER_ROW, 
+                BorderFactory.createLineBorder(Color.BLUE)));
         // string based. Note: this example is locale dependent
         String folderDescription = ".*ordner.*";
-        PatternPredicate predicate = new PatternPredicate(Pattern.compile(folderDescription, 0), 0, -1);
+        PatternPredicate predicate = new PatternPredicate(folderDescription, 0, -1);
         Highlighter hl = new ColorHighlighter(predicate, null, Color.RED);
         table.addHighlighter(hl);
         tree.addHighlighter(hl);
@@ -753,7 +763,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
         public String getString(Object value) {
             try {
                 PropertyDescriptor desc = getPropertyDescriptor(value.getClass(), property);
-                return TO_STRING.getString(getValue(value, desc));
+                return StringValues.TO_STRING.getString(getValue(value, desc));
             } catch (Exception e) {
                 // nothing much we can do here...
                 
@@ -809,9 +819,6 @@ public class RendererVisualCheck extends InteractiveTestCase {
         LinkModelAction action = new LinkModelAction<LinkModel>(visitor);
         ComponentProvider<JXHyperlink> controller = new HyperlinkProvider(action, LinkModel.class);
         table.setDefaultRenderer(LinkModel.class, new DefaultTableRenderer(controller));
-        LinkModelAction action2 = new LinkModelAction<LinkModel>(visitor);
-        // TODO: obsolete - need to think about what to do with editable link cells?
-        table.setDefaultEditor(LinkModel.class, new LinkRenderer(action2, LinkModel.class));
         JFrame frame = wrapWithScrollingInFrame(table, visitor.getOutputComponent(), "show link renderer in table");
         frame.setVisible(true);
 
@@ -868,7 +875,7 @@ public class RendererVisualCheck extends InteractiveTestCase {
                 if (value instanceof AbstractActionExt) {
                     return ((AbstractActionExt) value).getName();
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
