@@ -1,5 +1,5 @@
 /*
- * $Id: RenderingTest.java,v 1.30 2008/04/25 11:00:13 kleopatra Exp $
+ * $Id: RenderingTest.java,v 1.40 2008/12/23 18:12:38 kschaefe Exp $
  *
  * Copyright 2006 Sun Microsystems, Inc., 4150 Network Circle,
  * Santa Clara, California 95054, U.S.A. All rights reserved.
@@ -43,13 +43,18 @@ import org.jdesktop.swingx.JXHyperlink;
 import org.jdesktop.swingx.JXPanel;
 import org.jdesktop.swingx.JXTable;
 import org.jdesktop.swingx.JXTreeTable;
-import org.jdesktop.swingx.action.LinkAction;
+import org.jdesktop.swingx.hyperlink.LinkAction;
+import org.jdesktop.swingx.icon.EmptyIcon;
 import org.jdesktop.swingx.painter.ShapePainter;
 import org.jdesktop.swingx.table.TableColumnExt;
 import org.jdesktop.swingx.test.ComponentTreeTableModel;
 import org.jdesktop.swingx.test.XTestUtils;
 import org.jdesktop.test.PropertyChangeReport;
 import org.jdesktop.test.TestUtils;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+
 
 /**
  * Tests swingx rendering infrastructure: ComponentProvider, CellContext, 
@@ -58,17 +63,71 @@ import org.jdesktop.test.TestUtils;
  * 
  * @author Jeanette Winzenburg
  */
+@RunWith(JUnit4.class)
 public class RenderingTest extends TestCase {
     @SuppressWarnings("unused")
     private static final Logger LOG = Logger.getLogger(RenderingTest.class
             .getName());
 
+    /**
+     * Issue #766-swingx: flickering cursor on drop over.
+     * 
+     * test hack configuration (arrrggg ...)
+     */
+    @Test
+    public void testWrappingIconPanelDropHackDefault() {
+        JXPanel sanity = new JXPanel();
+        assertEquals("visible by default", true, sanity.isVisible());
+        WrappingIconPanel panel = new WrappingIconPanel();
+        assertEquals("invisible by default", false, panel.isVisible());
+        panel.setDropHackEnabled(false);
+        assertEquals("disabled hack", true, panel.isVisible());
+    }
+    
+    /**
+     * Issue #766-swingx: flickering cursor on drop over.
+     * 
+     * test hack configuration (arrrggg ...)
+     */
+    @Test
+    public void testWrappingIconPanelDropHackConstructor() {
+        JXPanel sanity = new JXPanel();
+        assertEquals("visible by default", true, sanity.isVisible());
+        WrappingIconPanel panel = new WrappingIconPanel(false);
+        assertEquals("invisible by default", true, panel.isVisible());
+        panel.setDropHackEnabled(true);
+        assertEquals("disabled hack", false, panel.isVisible());
+    }
+    
+    /**
+     * Issue #863-swingx: SwingX renderering components must be PainterAware.
+     * Here: test Hyperlink
+     */
+    @Test
+    public void testHyperlinkPainterAware() {
+        HyperlinkProvider provider = new HyperlinkProvider();
+        assertTrue("hyperlink as rendering comp must be PainterAware", provider.getRendererComponent(null) instanceof PainterAware);
+    }
+
+    
+    /**
+     * Issue #863-swingx: SwingX renderering components must be PainterAware.
+     * Here: test WrappingIconPanel
+     */
+    @Test
+    public void testWrappingIconPanelPainterAware() {
+        DefaultTreeRenderer renderer = new DefaultTreeRenderer();
+        JComponent rendererComponent = renderer.getComponentProvider().getRendererComponent(null);
+        assertTrue("wrappingIconPanel as rendering comp must be PainterAware", rendererComponent instanceof PainterAware);
+    }
+    
     /**
      * Issue #840-swingx: hyperlink foreground unreadable for dark selection colors.
      * 
      * Test that selected foreground is same as table. 
      * 
      */
+    @Test
     public void testHyperlinkProviderForeground() {
         JXTable table = new JXTable(20, 2);
         HyperlinkProvider provider = new HyperlinkProvider();
@@ -89,6 +148,7 @@ public class RenderingTest extends TestCase {
      * Issue #842-swingx: HyperlinkProvider getString doesn't serve its contract.
      * 
      */
+    @Test
     public void testHyperlinkStringValue() {
         LinkAction linkAction = new LinkAction() {
 
@@ -110,15 +170,23 @@ public class RenderingTest extends TestCase {
     
 
     
+    /**
+     * Issue ?? swingx: support to configure the auto-unwrap of tree/table/xx/nodes.
+     * 
+     * Initial default is true.
+     */
+    @Test
     public void testWrappingProviderUnwrapContructor() {
-        WrappingProvider provider = new WrappingProvider(new LabelProvider(), false);
-        assertFalse(provider.getUnwrapUserObject());
+        LabelProvider delegate = new LabelProvider();
+        WrappingProvider provider = new WrappingProvider(delegate, false);
+        assertWrappingProviderState(provider, null, null, delegate, false);
     }
     /**
      * Issue ?? swingx: support to configure the auto-unwrap of tree/table/xx/nodes.
      * 
      * Initial default is true.
      */
+    @Test
     public void testWrappingProviderUserObjectUnwrapInitial() {
         WrappingProvider provider = new WrappingProvider();
         assertEquals(true, provider.getUnwrapUserObject());
@@ -128,6 +196,7 @@ public class RenderingTest extends TestCase {
      * Issue ?? swingx: support to configure the auto-unwrap of tree/table/xx/nodes.
      * setter sets
      */
+    @Test
     public void testWrappingProviderUserObjectUnwrapSet() {
         WrappingProvider provider = new WrappingProvider();
         boolean unwrap = !provider.getUnwrapUserObject();
@@ -139,6 +208,7 @@ public class RenderingTest extends TestCase {
      * Issue ?? swingx: support to configure the auto-unwrap of tree/table/xx/nodes.
      * Respect unwrap flag in getString.
      */
+    @Test
     public void testWrappingProviderUserObjectUnwrapRespectString() {
         StringValue sv = new StringValue() {
 
@@ -146,7 +216,7 @@ public class RenderingTest extends TestCase {
                 if (value instanceof Point) {
                     return "x of Point: " + ((Point) value).x;
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -163,6 +233,7 @@ public class RenderingTest extends TestCase {
      * Issue ?? swingx: support to configure the auto-unwrap of tree/table/xx/nodes.
      * Respect unwrap flag in configuring a renderer.
      */
+    @Test
     public void testWrappingProviderUserObjectUnwrapRespectRenderer() {
         StringValue sv = new StringValue() {
 
@@ -170,7 +241,7 @@ public class RenderingTest extends TestCase {
                 if (value instanceof Point) {
                     return "x of Point: " + ((Point) value).x;
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -195,6 +266,7 @@ public class RenderingTest extends TestCase {
      * column)
      * 
      */
+    @Test
     public void testToolTipManagerTreeTableTreeRenderer() {
         JXTreeTable treeTable = new JXTreeTable(new ComponentTreeTableModel(new JXPanel()));
         JComponent label = (JComponent) treeTable.prepareRenderer(treeTable.getCellRenderer(0, 0), 0, 0);
@@ -212,6 +284,7 @@ public class RenderingTest extends TestCase {
      * 
      * Here: Hyperlink in provider
      */
+    @Test
     public void testToolTipManagerHyperlinkProvider() {
         LinkAction linkAction = new LinkAction() {
 
@@ -242,6 +315,7 @@ public class RenderingTest extends TestCase {
      * 
      * Here: JRendererCheckBox-
      */
+    @Test
     public void testToolTipManagerRendererCheckBox() {
        JRendererCheckBox label = new JRendererCheckBox();
        assertNull("sanity - no tooltip", label.getToolTipText());
@@ -249,7 +323,10 @@ public class RenderingTest extends TestCase {
        PropertyChangeReport report = new PropertyChangeReport();
        label.addPropertyChangeListener(report);
        label.setToolTipText(tip);
-       TestUtils.assertPropertyChangeEvent(report, JComponent.TOOL_TIP_TEXT_KEY, null, tip);
+       // JRendererCheckBox is optimized to not fire any property changes
+       assertEquals(0, report.getEventCount());
+       // nevertheless, we want the tip set ;-)
+       assertEquals(tip, label.getToolTipText());
        assertToolTipManagerNotRegistered(label);
     }
 
@@ -259,6 +336,7 @@ public class RenderingTest extends TestCase {
      * Here: JRendererLabel.
      * 
      */
+    @Test
     public void testToolTipManagerRendererLabel() {
        JRendererLabel label = new JRendererLabel();
        assertNull("sanity - no tooltip", label.getToolTipText());
@@ -280,6 +358,7 @@ public class RenderingTest extends TestCase {
      * ToolTipManager registers itself as mouseListener with the component.
      * 
      */
+    @Test
     public void testToolTipManagerJLabel() {
        JLabel label = new JLabel();
        assertNull("sanity - no tooltip", label.getToolTipText());
@@ -338,6 +417,7 @@ public class RenderingTest extends TestCase {
      * Issue #768-swingx: cleanup access to string representation of provider.
      * 
      */
+    @Test
     public void testLabelProviderGetString() {
         StringValue sv = new StringValue() {
 
@@ -357,6 +437,7 @@ public class RenderingTest extends TestCase {
      * Issue #768-swingx: cleanup access to string representation of provider.
      * 
      */
+    @Test
     public void testButtonProviderGetString() {
         StringValue sv = new StringValue() {
 
@@ -376,6 +457,7 @@ public class RenderingTest extends TestCase {
      * Issue #768-swingx: cleanup access to string representation of provider.
      * 
      */
+    @Test
     public void testWrappingProviderGetString() {
         StringValue sv = new StringValue() {
 
@@ -396,6 +478,7 @@ public class RenderingTest extends TestCase {
      * WrappingProvider must do the same "unwrapping" magic in getString as in 
      * getRendereringComponent.
      */
+    @Test
     public void testWrappingProviderGetStringFromNode() {
         StringValue sv = new StringValue() {
 
@@ -403,7 +486,7 @@ public class RenderingTest extends TestCase {
                 if (value instanceof Point) {
                     return "x of Point: " + ((Point) value).x;
                 }
-                return TO_STRING.getString(value);
+                return StringValues.TO_STRING.getString(value);
             }
             
         };
@@ -418,6 +501,7 @@ public class RenderingTest extends TestCase {
      * Issue #768-swingx: cleanup access to string representation of provider.
      * 
      */
+    @Test
     public void testWrappingProviderGetStringNotNullValue() {
         StringValue sv = new StringValue() {
 
@@ -438,9 +522,10 @@ public class RenderingTest extends TestCase {
      * enhance WrappingProvider to allow real null values. 
      * 
      */
+    @Test
     public void testWrappingProviderNullIcon() {
        CellContext context = new TreeCellContext();
-       WrappingProvider provider = new WrappingProvider(IconValue.NONE);
+       WrappingProvider provider = new WrappingProvider(IconValues.NONE);
        WrappingIconPanel comp = provider.getRendererComponent(context);
        assertEquals(null, comp.getIcon());
     }
@@ -450,6 +535,7 @@ public class RenderingTest extends TestCase {
      * Added pref/min/max size to list of properties which 
      * must be reset by the DefaultVisuals.
      */
+    @Test
     public void testResetPreferredSize() {
         DefaultVisuals<JComponent> visuals = new DefaultVisuals<JComponent>();
         JComponent label = new  JLabel("somevalue");
@@ -470,16 +556,20 @@ public class RenderingTest extends TestCase {
      * PENDING JW: revisit .. Icon.EMPTY vs. Icon.NONE: what exactly is the expected 
      * behaviour?
      */
+    @Test
     public void testLabelProviderRespectStringValueNoIcon() {
         ImageIcon icon = (ImageIcon) XTestUtils.loadDefaultIcon();
         icon.setDescription("description");
         LabelProvider provider = new LabelProvider(
-                new MappedValue(StringValue.TO_STRING, IconValue.EMPTY));
+                new MappedValue(StringValues.TO_STRING, IconValues.NONE));
         TableCellContext context = new TableCellContext();
         context.value = icon;
         JLabel label = provider.getRendererComponent(context);
-        assertNull("icon must be null", label.getIcon());
-        assertEquals("label text must be default to-string", StringValue.TO_STRING.getString(icon), label.getText());
+        Icon i = label.getIcon();
+        assertTrue("icon must be empty", i instanceof EmptyIcon);
+        assertEquals("icon must have no width", 0, i.getIconWidth());
+        assertEquals("icon must have no height", 0, i.getIconHeight());
+        assertEquals("label text must be default to-string", StringValues.TO_STRING.getString(icon), label.getText());
     }
     
     /**
@@ -488,16 +578,17 @@ public class RenderingTest extends TestCase {
      * Here: must show the icon and empty text.
      *
      */
+    @Test
     public void testLabelProviderRespectIconValueNoString() {
         ImageIcon icon = (ImageIcon) XTestUtils.loadDefaultIcon();
         icon.setDescription("description");
         LabelProvider provider = new LabelProvider(
-                new MappedValue(StringValue.EMPTY, IconValue.ICON));
+                new MappedValue(StringValues.EMPTY, IconValues.ICON));
         TableCellContext context = new TableCellContext();
         context.value = icon;
         JLabel label = provider.getRendererComponent(context);
         assertEquals(icon, label.getIcon());
-        assertEquals("label text must be empty", StringValue.EMPTY.getString(icon), label.getText());
+        assertEquals("label text must be empty", StringValues.EMPTY.getString(icon), label.getText());
     }
     
     /**
@@ -506,21 +597,23 @@ public class RenderingTest extends TestCase {
      * Here: must show both description and icon.
      *
      */
+    @Test
     public void testLabelProviderRespectStringIconValueBoth() {
         ImageIcon icon = (ImageIcon) XTestUtils.loadDefaultIcon();
         icon.setDescription("description");
         LabelProvider provider = new LabelProvider(
-                new MappedValue(StringValue.TO_STRING, IconValue.ICON));
+                new MappedValue(StringValues.TO_STRING, IconValues.ICON));
         TableCellContext context = new TableCellContext();
         context.value = icon;
         JLabel label = provider.getRendererComponent(context);
         assertEquals(icon, label.getIcon());
-        assertEquals(StringValue.TO_STRING.getString(icon), label.getText());
+        assertEquals(StringValues.TO_STRING.getString(icon), label.getText());
     }
 
     /**
      * WrappingProvider: test custom icon
      */
+    @Test
     public void testWrappingProviderIcon() {
         final Icon icon = XTestUtils.loadDefaultIcon();
         IconValue iv = new IconValue() {
@@ -531,11 +624,14 @@ public class RenderingTest extends TestCase {
         CellContext context = new TreeCellContext();
         WrappingIconPanel iconPanel = provider.getRendererComponent(context);
         assertEquals(icon, iconPanel.getIcon());
+        // NOTE: do not test type of wrapper's stringValue - it's a mappedValue if icon present!
+        assertEquals("", provider.getStringValue().getString(icon));
     }
     
     /**
      * WrappingProvider: test custom icon
      */
+    @Test
     public void testWrappingProviderIconAndContent() {
         final Icon icon = XTestUtils.loadDefaultIcon();
         IconValue iv = new IconValue() {
@@ -543,49 +639,99 @@ public class RenderingTest extends TestCase {
                 return icon;
             }};
             
-        WrappingProvider provider = new WrappingProvider(iv, FormatStringValue.DATE_TO_STRING);
+        WrappingProvider provider = new WrappingProvider(iv, StringValues.DATE_TO_STRING);
         CellContext context = new TreeCellContext();
         WrappingIconPanel iconPanel = provider.getRendererComponent(context);
         assertEquals(icon, iconPanel.getIcon());
-        
+        // NOTE: do not test type of wrapper's stringValue - it's a mappedValue if icon present!
+        assertEquals("", provider.getStringValue().getString(icon));
     }
     
     /**
      * WrappingProvider: 
      * test wrappee and its state after instantiation.
      */
-    public void testWrappingProviderWrappee() {
-        WrappingProvider provider = new WrappingProvider();
-        // sanity ...
-        assertTrue(provider.getWrappee() instanceof LabelProvider);
-        assertEquals("wrappee's StringValue must be default", 
-                new LabelProvider().getStringValue(),
-                provider.getWrappee().getStringValue()); 
+    @Test
+    public void testWrappingProviderWrappeeConstructors() {
+        IconValue iv = IconValues.FILE_ICON;
+        LabelProvider delegate = new LabelProvider(FormatStringValue.DATE_TO_STRING);
+        assertWrappingProviderState(new WrappingProvider(delegate),
+                null, null, delegate, true);
+        assertWrappingProviderState(new WrappingProvider(delegate, false), 
+                null, null, delegate, false);
+        assertWrappingProviderState(new WrappingProvider(iv, delegate, false), 
+                iv, null, delegate, false);
+        assertWrappingProviderState(new WrappingProvider(iv, (ComponentProvider) null, false), 
+                iv, null, null, false);
+        assertWrappingProviderState(new WrappingProvider(null, (ComponentProvider) null, false), 
+                null, null, null, false);
+    }
+   
+    /**
+     * WrappingProvider: 
+     * test wrappee and its state after instantiation.
+     */
+    @Test
+    public void testWrappingProviderWrappeeStringValueConstructors() {
+        IconValue iv = IconValues.FILE_ICON;
         StringValue sv = FormatStringValue.DATE_TO_STRING;
-        WrappingProvider customStringValue = new WrappingProvider(sv);
-        assertEquals("wrappee's StringValue must be configured to given", sv, 
-                customStringValue.getWrappee().getStringValue());
-        WrappingProvider iconValueAndCustomStringValue = new WrappingProvider(null, sv);
-        assertEquals("wrappee's StringValue must be configured to given", sv, 
-                iconValueAndCustomStringValue.getWrappee().getStringValue());
+        assertWrappingProviderState(new WrappingProvider(iv),
+                iv, null, null, true);
+        assertWrappingProviderState(new WrappingProvider(iv, sv), 
+                iv, sv, null, true);
+        assertWrappingProviderState(new WrappingProvider(sv), 
+                null, sv, null, true);
+        assertWrappingProviderState(new WrappingProvider(null, sv), 
+                null, sv, null, true);
+        assertWrappingProviderState(new WrappingProvider(iv, null), 
+                iv, null, null, true);
+        assertWrappingProviderState(new WrappingProvider(null, null), 
+                null, null, null, true);
+//        assertWrappingProviderState(new WrappingProvider(false, iv), 
+//                iv, null, null, false);
     }
     
     /**
      * WrappingProvider: 
-     * test provider's own state after instantiation.
+     * test provider's state after instantiation with empty constructor.
      */
-    public void testWrappingProviderDefaults() {
-        WrappingProvider provider = new WrappingProvider();
-        assertTrue("default wrappee must be LabelProvider but was " + 
-                     provider.getWrappee().getClass(), 
-                provider.getWrappee() instanceof LabelProvider);
-        assertEquals("default StringValue must be empty", StringValue.EMPTY, 
-                provider.getStringValue());
+    @Test
+    public void testWrappingProviderEmptyConstructor() {
+        assertWrappingProviderState(new WrappingProvider(), 
+                null, null, null, true);
+//        assertWrappingProviderState(new WrappingProvider(false), 
+//                null, null, null, false);
     }
     
+    private void assertWrappingProviderState(WrappingProvider provider, 
+            IconValue iv, StringValue sv, ComponentProvider delegate, boolean unwrap) {
+        if (iv == null) {
+            assertEquals("default StringValue must be empty", StringValue.EMPTY, 
+                    provider.getStringValue());
+        } else {
+            assertTrue("provider's StringValue must be a MappedValue containing the IconValue, but" +
+            		"was " + provider.getStringValue().getClass(),
+                    provider.getStringValue() instanceof MappedValue);
+            // can't access MappedValue's delegates - usually don't need to
+//            assertEquals(iv, ((MappedValue) provider.getStringValue()).iconDelegate);
+        }
+        if (delegate == null) {
+            assertTrue("default wrappee must be LabelProvider but was " + 
+                    provider.getWrappee().getClass(), 
+               provider.getWrappee() instanceof LabelProvider);
+        } else {
+            assertEquals("wrappee must be set", delegate, provider.getWrappee());
+        }
+        if (sv != null) {
+            assertEquals("wrappee's StringValue must be configured to given", 
+                    sv, provider.getWrappee().getStringValue());
+        }
+        assertEquals(unwrap, provider.getUnwrapUserObject());
+    }
     /**
      * Test text and boolean taken from MappedValue
      */
+    @Test
     public void testButtonProviderCustomValue() {
         // some object to map
         String identifier = "dummyID";
@@ -620,6 +766,7 @@ public class RenderingTest extends TestCase {
      * here: constructor with null stringValue and align
      *
      */
+    @Test
     public void testButtonProviderDefaultsTwoConstructor() {
         CheckBoxProvider provider = new CheckBoxProvider(null, JLabel.RIGHT);
         TableCellContext context = new TableCellContext();
@@ -647,6 +794,7 @@ public class RenderingTest extends TestCase {
      * here: constructor with null stringValue
      *
      */
+    @Test
     public void testButtonProviderDefaultsOneConstructor() {
         CheckBoxProvider provider = new CheckBoxProvider(null);
         TableCellContext context = new TableCellContext();
@@ -674,6 +822,7 @@ public class RenderingTest extends TestCase {
      * here: parameterless constructor
      *
      */
+    @Test
     public void testButtonProviderDefaultsEmptyConstructor() {
         CheckBoxProvider provider = new CheckBoxProvider();
         TableCellContext context = new TableCellContext();
@@ -697,10 +846,11 @@ public class RenderingTest extends TestCase {
      * test ButtonProvider default constructor and properties.
      *
      */
+    @Test
     public void testButtonProviderConstructor() {
         ComponentProvider provider = new CheckBoxProvider();
         assertEquals(JLabel.CENTER, provider.getHorizontalAlignment());
-        assertEquals(StringValue.EMPTY, provider.getStringValue());
+        assertEquals(StringValues.EMPTY, provider.getStringValue());
        
     }
 
@@ -708,6 +858,7 @@ public class RenderingTest extends TestCase {
      * Test provider property reset: borderPainted.
      *
      */
+    @Test
     public void testButtonProviderBorderPainted() {
         CheckBoxProvider provider = new CheckBoxProvider();
         TableCellContext context = new TableCellContext();
@@ -721,6 +872,7 @@ public class RenderingTest extends TestCase {
      * Test provider property reset: horizontal.
      *
      */
+    @Test
     public void testButtonProviderHorizontalAlignment() {
         CheckBoxProvider provider = new CheckBoxProvider();
         CellContext context = new TableCellContext();
@@ -736,13 +888,14 @@ public class RenderingTest extends TestCase {
      * 
      *
      */
+    @Test
     public void testConstructorClients() {
         JXTable table = new JXTable();
         // Number
         DefaultTableRenderer numberRenderer = (DefaultTableRenderer) table.getDefaultRenderer(Number.class);
         JLabel label = (JLabel) numberRenderer.getTableCellRendererComponent(table, null, false, false, 0, 0);
         assertEquals(JLabel.RIGHT, label.getHorizontalAlignment());
-        assertEquals(FormatStringValue.NUMBER_TO_STRING, numberRenderer.componentController.getStringValue());
+        assertEquals(StringValues.NUMBER_TO_STRING, numberRenderer.componentController.getStringValue());
         // icon
         DefaultTableRenderer iconRenderer = (DefaultTableRenderer) table.getDefaultRenderer(Icon.class);
         JLabel iconLabel = (JLabel) iconRenderer.getTableCellRendererComponent(table, null, false, false, 0, 0);
@@ -755,6 +908,7 @@ public class RenderingTest extends TestCase {
     /**
      * Test constructors: convenience constructor.
      */
+    @Test
     public void testConstructorConvenience() {
         FormatStringValue sv = new FormatStringValue(DateFormat.getTimeInstance());
         int align = JLabel.RIGHT;
@@ -766,25 +920,28 @@ public class RenderingTest extends TestCase {
     /**
      * Test constructors: parameterless.
      */
+    @Test
     public void testConstructorDefault() {
         LabelProvider provider = new LabelProvider();
         assertEquals(JLabel.LEADING, provider.getHorizontalAlignment());
-        assertEquals(StringValue.TO_STRING, provider.getStringValue());
+        assertEquals(StringValues.TO_STRING, provider.getStringValue());
     }
     
     /**
      * Test constructors: convenience constructor.
      */
+    @Test
     public void testConstructorAlignment() {
         int align = JLabel.RIGHT;
         LabelProvider provider = new LabelProvider(align);
         assertEquals(align, provider.getHorizontalAlignment());
-        assertEquals(StringValue.TO_STRING, provider.getStringValue());
+        assertEquals(StringValues.TO_STRING, provider.getStringValue());
     }
     
     /**
      * Test constructors: convenience constructor.
      */
+    @Test
     public void testConstructorStringValue() {
         FormatStringValue sv = new FormatStringValue(DateFormat.getTimeInstance());
         LabelProvider provider = new LabelProvider(sv);
@@ -796,6 +953,7 @@ public class RenderingTest extends TestCase {
      * test that default visual config clears the tooltip.
      *
      */
+    @Test
     public void testResetTooltip() {
         DefaultVisuals<JComponent> visuals = new DefaultVisuals<JComponent>();
         JComponent label = new  JLabel("somevalue");
@@ -808,6 +966,7 @@ public class RenderingTest extends TestCase {
      * Test if all collaborators can cope with null component on CellContext.
      *
      */
+    @Test
     public void testEmptyContext() {
         // test LabelProvider
         // same for list and table
@@ -832,14 +991,15 @@ public class RenderingTest extends TestCase {
      * Test doc'ed constructor behaviour of default tree renderer.
      *
      */
+    @Test
     public void testDefaultTreeRendererConstructors() {
         DefaultTreeRenderer renderer = new DefaultTreeRenderer();
         assertTrue(renderer.componentController instanceof WrappingProvider);
-        renderer = new DefaultTreeRenderer(FormatStringValue.DATE_TO_STRING);
+        renderer = new DefaultTreeRenderer(StringValues.DATE_TO_STRING);
         assertTrue(renderer.componentController instanceof WrappingProvider);
         // wrong assumption - we are wrapping...
 //        assertSame(FormatStringValue.DATE_TO_STRING, renderer.componentController.formatter);
-        assertSame(FormatStringValue.DATE_TO_STRING, ((WrappingProvider) renderer.componentController).wrappee.formatter);
+        assertSame(StringValues.DATE_TO_STRING, ((WrappingProvider) renderer.componentController).wrappee.formatter);
         ComponentProvider controller = new CheckBoxProvider();
         renderer = new DefaultTreeRenderer(controller);
         assertSame(controller, renderer.componentController);
@@ -849,12 +1009,13 @@ public class RenderingTest extends TestCase {
      * Test doc'ed constructor behaviour of default list renderer.
      *
      */
+    @Test
     public void testDefaultListRendererConstructors() {
         DefaultListRenderer renderer = new DefaultListRenderer();
         assertTrue(renderer.componentController instanceof LabelProvider);
-        renderer = new DefaultListRenderer(FormatStringValue.DATE_TO_STRING);
+        renderer = new DefaultListRenderer(StringValues.DATE_TO_STRING);
         assertTrue(renderer.componentController instanceof LabelProvider);
-        assertSame(FormatStringValue.DATE_TO_STRING, renderer.componentController.formatter);
+        assertSame(StringValues.DATE_TO_STRING, renderer.componentController.formatter);
         ComponentProvider controller = new CheckBoxProvider();
         renderer = new DefaultListRenderer(controller);
         assertSame(controller, renderer.componentController);
@@ -864,12 +1025,13 @@ public class RenderingTest extends TestCase {
      * Test doc'ed constructor behaviour of default table renderer.
      *
      */
+    @Test
     public void testDefaultTableRendererConstructors() {
         DefaultTableRenderer renderer = new DefaultTableRenderer();
         assertTrue(renderer.componentController instanceof LabelProvider);
-        renderer = new DefaultTableRenderer(FormatStringValue.DATE_TO_STRING);
+        renderer = new DefaultTableRenderer(StringValues.DATE_TO_STRING);
         assertTrue(renderer.componentController instanceof LabelProvider);
-        assertSame(FormatStringValue.DATE_TO_STRING, renderer.componentController.formatter);
+        assertSame(StringValues.DATE_TO_STRING, renderer.componentController.formatter);
         ComponentProvider controller = new CheckBoxProvider();
         renderer = new DefaultTableRenderer(controller);
         assertSame(controller, renderer.componentController);
@@ -880,6 +1042,7 @@ public class RenderingTest extends TestCase {
      * with null context. Here: test getRenderingComponent in WrappingProvider.
      *
      */
+    @Test
     public void testGetWrappingComponentNullContext() {
         WrappingProvider provider = new WrappingProvider();
         assertEquals(provider.rendererComponent, provider.getRendererComponent(null));
@@ -889,6 +1052,7 @@ public class RenderingTest extends TestCase {
      * public methods of <code>ComponentProvider</code> must cope
      * with null context. Here: test getRenderingComponent in LabelProvider.
      */
+    @Test
     public void testGetComponentNullContext() {
         ComponentProvider controller = new LabelProvider();
         assertEquals(controller.rendererComponent, controller.getRendererComponent(null));
@@ -899,6 +1063,7 @@ public class RenderingTest extends TestCase {
      * NPE on null context.
      *
      */
+    @Test
     public void testConfigureVisualsNullContext() {
         DefaultVisuals<JLabel> controller = new DefaultVisuals<JLabel>();
         try {
@@ -915,6 +1080,7 @@ public class RenderingTest extends TestCase {
      * NPE on null component.
      *
      */
+    @Test
     public void testConfigureVisualsNullComponent() {
         DefaultVisuals<JLabel> controller = new DefaultVisuals<JLabel>();
         try {
@@ -932,6 +1098,7 @@ public class RenderingTest extends TestCase {
      * Fail-fast NPE in label.paintComponentWithPainter.
      *
      */
+    @Test
     public void testLabelNPEPaintComponentOpaqueWithPainter() {
         JRendererLabel label = new JRendererLabel();
         label.setOpaque(true);
@@ -950,6 +1117,7 @@ public class RenderingTest extends TestCase {
      * Fail-fast NPE in paintPainter.
      *
      */
+    @Test
     public void testLabelNPEPaintComponentWithPainter() {
         JRendererLabel label = new JRendererLabel();
         label.setOpaque(false);
@@ -969,6 +1137,7 @@ public class RenderingTest extends TestCase {
      * NPE in label.paintComponentWithPainter finally block.
      *
      */
+    @Test
     public void testButtonNPEPaintComponentOpaqueWithPainter() {
         JRendererCheckBox  checkBox = new JRendererCheckBox();
         checkBox.setOpaque(true);
@@ -988,6 +1157,7 @@ public class RenderingTest extends TestCase {
      * label.paintComponentWithPainter finally block.
      * 
      */
+    @Test
     public void testButtonNPEPaintComponentWithPainter() {
         JRendererCheckBox checkBox = new JRendererCheckBox();
         checkBox.setOpaque(false);
